"use strict";
import bodyParser from "body-parser";
import cors from 'cors';
import express from "express";
import fs from "fs";
import i18n from "i18n";
import { resolve } from "path";
const path = require('path');
const auth = require('basic-auth');
const swaggerUi = require('swagger-ui-express');
const app = express();
app.use(express.static(__dirname));

//Cors Policy
var corsOptions = {
  origin: "http://localhost:6012"
};
app.use(express.static("public"));
app.use(cors(corsOptions));

// Load envs from .env file
if (fs.existsSync("./.env")) {
  require("dotenv").config();
}

// Set the view engine to EJS
app.set('view engine', 'ejs');

// Set the views directory
app.set('views', __dirname + '/views');

import common from './helpers/common';
const { validateApiKey } = new common();

import * as swaggerDefinition from './swagger/config';

// Localization setup
i18n.configure({
  locales: ['sq','am','ar','bg','ca','zh','zh','cs','da','de','en','es','fr','hu','he','el','id','it','ja','ko','ms','nb','nl','pl','pt','ro','ru','sk','fi','sv','th','tr','lv','lt','pa','sw','uk','ur','vi','fa','ku','ga','ps','yo','ha','ig','ti','prs'],
  directory: resolve(__dirname, "../locales"),
  defaultLocale: "en",
  queryParameter: "lang",
  objectNotation: true
});
app.use(i18n.init);
app.use(bodyParser.urlencoded({ limit: '100mb', extended: true }));

app.use(bodyParser.json({ limit: '100mb' }))

// parse application/json
app.use(bodyParser.json())

app.get('/', function (req, res) {
  res.send("Welcome to MyManu ");
});

app.get('/activate', (req, res) => {
  const filePath = path.join(__dirname, '../activate.html');
  res.sendFile(filePath);
});

app.get('/client', (req, res) => {
  const filePath = path.join(__dirname, '../client.html');
  const sockethost = process.env.SOCKETHOST;
  const nodeEnv = process.env.NODE_ENV;

  fs.readFile(filePath, 'utf8', (err, data) => {
    if (err) {
      return res.status(500).send('Error reading file');
    }

    const modifiedData = data
      .replace('{{sockethost}}', sockethost)
      .replace('{{nodeEnv}}', nodeEnv);

    res.setHeader('Content-Type', 'text/html');
    res.send(modifiedData);
  });
});

const swaggerAuthenticate = (req, res, next) => {
	const user = auth(req);
	const validUser = process.env.SWAGGER_BASIC_AUTH_USERNAME; // Replace this with your valid username
	const validPassword = process.env.SWAGGER_BASIC_AUTH_PASSWORD; // Replace this with your valid password

	if (!user || user.name !== validUser || user.pass !== validPassword) {
		res.set('WWW-Authenticate', 'Basic realm=Authorization Required');
		return res.status(401).send('Authentication required.');
	}
	next();
};

// initialize swagger
app.use('/swagger', swaggerAuthenticate,swaggerUi.serve, swaggerUi.setup(swaggerDefinition));

app.get('/swagger.json', swaggerAuthenticate,function (req, res) {
  res.setHeader('Content-Type', 'application/json');
  res.send(swaggerDefinition);
});

let allowCrossDomain = function (req, res, next) {
  if ("OPTIONS" === req.method) {
    res.header("Access-Control-Allow-Origin", "*");
    res.header("Access-Control-Allow-Methods", "GET,HEAD,OPTIONS,POST,PUT");
    res.header("Access-Control-Allow-Headers", "Origin, X-Requested-With, Content-Type,Accept, x-client-key, x-client-token, x-client-secret, Authorization");
    res.send(200);
  } else {
    next();
  }
};



app.use(allowCrossDomain);

var AllRouter = require('./routes/v1');

app.use('/api', AllRouter);


console.log(`WebSocket server is listening at http://localhost:${process.env.PORT}`);
module.exports = app;
