"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const body_parser_1 = __importDefault(require("body-parser"));
const cors_1 = __importDefault(require("cors"));
const express_1 = __importDefault(require("express"));
const fs_1 = __importDefault(require("fs"));
const i18n_1 = __importDefault(require("i18n"));
const path_1 = require("path");
const path = require('path');
const auth = require('basic-auth');
const swaggerUi = require('swagger-ui-express');
const app = (0, express_1.default)();
app.use(express_1.default.static(__dirname));
//Cors Policy
var corsOptions = {
    origin: "http://localhost:6012"
};
app.use(express_1.default.static("public"));
app.use((0, cors_1.default)(corsOptions));
// Load envs from .env file
if (fs_1.default.existsSync("./.env")) {
    require("dotenv").config();
}
// Set the view engine to EJS
app.set('view engine', 'ejs');
// Set the views directory
app.set('views', __dirname + '/views');
const common_1 = __importDefault(require("./helpers/common"));
const { validateApiKey } = new common_1.default();
const swaggerDefinition = __importStar(require("./swagger/config"));
// Localization setup
i18n_1.default.configure({
    locales: ['sq', 'am', 'ar', 'bg', 'ca', 'zh', 'zh', 'cs', 'da', 'de', 'en', 'es', 'fr', 'hu', 'he', 'el', 'id', 'it', 'ja', 'ko', 'ms', 'nb', 'nl', 'pl', 'pt', 'ro', 'ru', 'sk', 'fi', 'sv', 'th', 'tr', 'lv', 'lt', 'pa', 'sw', 'uk', 'ur', 'vi', 'fa', 'ku', 'ga', 'ps', 'yo', 'ha', 'ig', 'ti', 'prs'],
    directory: (0, path_1.resolve)(__dirname, "../locales"),
    defaultLocale: "en",
    queryParameter: "lang",
    objectNotation: true
});
app.use(i18n_1.default.init);
app.use(body_parser_1.default.urlencoded({ limit: '100mb', extended: true }));
app.use(body_parser_1.default.json({ limit: '100mb' }));
// parse application/json
app.use(body_parser_1.default.json());
app.get('/', function (req, res) {
    res.send("Welcome to MyManu ");
});
app.get('/activate', (req, res) => {
    const filePath = path.join(__dirname, '../activate.html');
    res.sendFile(filePath);
});
app.get('/client', (req, res) => {
    const filePath = path.join(__dirname, '../client.html');
    const sockethost = process.env.SOCKETHOST;
    const nodeEnv = process.env.NODE_ENV;
    fs_1.default.readFile(filePath, 'utf8', (err, data) => {
        if (err) {
            return res.status(500).send('Error reading file');
        }
        const modifiedData = data
            .replace('{{sockethost}}', sockethost)
            .replace('{{nodeEnv}}', nodeEnv);
        res.setHeader('Content-Type', 'text/html');
        res.send(modifiedData);
    });
});
const swaggerAuthenticate = (req, res, next) => {
    const user = auth(req);
    const validUser = process.env.SWAGGER_BASIC_AUTH_USERNAME; // Replace this with your valid username
    const validPassword = process.env.SWAGGER_BASIC_AUTH_PASSWORD; // Replace this with your valid password
    if (!user || user.name !== validUser || user.pass !== validPassword) {
        res.set('WWW-Authenticate', 'Basic realm=Authorization Required');
        return res.status(401).send('Authentication required.');
    }
    next();
};
// initialize swagger
app.use('/swagger', swaggerAuthenticate, swaggerUi.serve, swaggerUi.setup(swaggerDefinition));
app.get('/swagger.json', swaggerAuthenticate, function (req, res) {
    res.setHeader('Content-Type', 'application/json');
    res.send(swaggerDefinition);
});
let allowCrossDomain = function (req, res, next) {
    if ("OPTIONS" === req.method) {
        res.header("Access-Control-Allow-Origin", "*");
        res.header("Access-Control-Allow-Methods", "GET,HEAD,OPTIONS,POST,PUT");
        res.header("Access-Control-Allow-Headers", "Origin, X-Requested-With, Content-Type,Accept, x-client-key, x-client-token, x-client-secret, Authorization");
        res.send(200);
    }
    else {
        next();
    }
};
app.use(allowCrossDomain);
var AllRouter = require('./routes/v1');
app.use('/api', AllRouter);
console.log(`WebSocket server is listening at http://localhost:${process.env.PORT}`);
module.exports = app;
//# sourceMappingURL=app.js.map