"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const express_validator_1 = require("express-validator");
const models = require('./../../models/index');
const { Op } = require("sequelize");
module.exports.UserRegister = [
    (0, express_validator_1.body)('name').trim().notEmpty().withMessage('UsernameRequired'),
    (0, express_validator_1.body)('name').trim().isLength({ min: 2 }).withMessage('FullnameMinLengthRequired'),
    (0, express_validator_1.body)('name').trim().isLength({ max: 30 }).withMessage('FullnameMaxLengthRequired'),
    (0, express_validator_1.body)('application_type').trim().notEmpty().withMessage('ApplicationTypeRequired'),
    (0, express_validator_1.body)('device_type').trim().notEmpty().withMessage('DeviceTypeRequired'),
    (0, express_validator_1.body)('password').trim().notEmpty().withMessage('PasswordRequired'),
    (0, express_validator_1.body)('password').trim().isLength({ min: 8 }).withMessage('PasswordMinLengthRequired'),
    (0, express_validator_1.body)('password').matches(/^(?=.*\d)(?=.*[a-z])(?=.*[A-Z])(?=.*[\W_]).{8,}$/).withMessage('PasswordComplexityRequired'),
    // body('password').matches(/^(?=.*\d)(?=.*[a-z])(?=.*[A-Z])(?=.*[!@#$%^&*]).{8,}$/).withMessage('PasswordComplexityRequired'),
    (0, express_validator_1.body)('email').trim().notEmpty().withMessage('UserEmailRequired'),
    (0, express_validator_1.body)('email').trim().isEmail().withMessage('ValidEmailFormat'),
    (0, express_validator_1.body)('email').trim().custom((value, { req }) => __awaiter(void 0, void 0, void 0, function* () {
        return new Promise((resolve, reject) => {
            return models.User.findOne({
                where: {
                    user_email: { [Op.eq]: value },
                    status: { [Op.eq]: 1 }
                }
            }).then(user => {
                if (user && user !== null && user !== undefined) {
                    return reject();
                }
                else {
                    return resolve();
                }
            }).catch((err) => {
                return reject();
            });
        });
    })).withMessage('ExistUser')
];
module.exports.UserLogin = [
    (0, express_validator_1.body)('email').trim().notEmpty().withMessage('UserEmailRequired'),
    (0, express_validator_1.body)('email').trim().isEmail().withMessage('ValidEmailFormat'),
    (0, express_validator_1.body)('password').trim().notEmpty().withMessage('PasswordRequired'),
    (0, express_validator_1.body)('application_type').trim().notEmpty().withMessage('ApplicationTypeRequired'),
    (0, express_validator_1.body)('device_type').trim().notEmpty().withMessage('Device type is required'),
];
module.exports.email = [
    (0, express_validator_1.body)('email').trim().notEmpty().withMessage('UserEmailRequired'),
    (0, express_validator_1.body)('email').trim().isEmail().withMessage('ValidEmailFormat'),
];
module.exports.resetPassword = [
    (0, express_validator_1.body)('email').trim().notEmpty().withMessage('UserEmailRequired'),
    (0, express_validator_1.body)('email').trim().isEmail().withMessage('ValidEmailFormat'),
    (0, express_validator_1.body)('password').trim().notEmpty().withMessage('PasswordRequired'),
    (0, express_validator_1.body)('password').trim().isLength({ min: 8 }).withMessage('PasswordMinLengthRequired'),
    (0, express_validator_1.body)('password').matches(/^(?=.*\d)(?=.*[a-z])(?=.*[A-Z])(?=.*[\W_]).{8,}$/).withMessage('PasswordComplexityRequired'),
    // body('password').matches(/^(?=.*\d)(?=.*[a-z])(?=.*[A-Z])(?=.*[!@#$%^&*]).{8,}$/).withMessage('PasswordComplexityRequired'),
];
module.exports.UserLogout = [
    (0, express_validator_1.body)('application_type').trim().notEmpty().withMessage('ApplicationTypeRequired')
];
//# sourceMappingURL=user.validation.js.map