'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const sequelize_1 = require("sequelize");
module.exports = (sequelize, DataTypes) => {
    class GroupMessage extends sequelize_1.Model {
        /**
         * Helper method for defining associations.
         * This method is not a part of Sequelize lifecycle.
         * The `models/index` file will call this method automatically.
         */
        static associate(models) {
            // define association here
            GroupMessage.belongsTo(models.User, { as: 'userInfo', foreignKey: 'user_id' });
            GroupMessage.belongsTo(models.User, { as: 'senderInfo', foreignKey: 'sender_id' });
            GroupMessage.belongsTo(models.GroupMaster, { as: 'groupInfo', foreignKey: 'group_id' });
            GroupMessage.belongsTo(GroupMessage, {
                as: 'reply',
                foreignKey: 'reply_message_id', // This references the 'reply_message_id' field in the same table
            });
        }
    }
    GroupMessage.init({
        group_message_id: {
            allowNull: false,
            autoIncrement: true,
            primaryKey: true,
            type: DataTypes.INTEGER
        },
        group_id: {
            type: DataTypes.INTEGER,
            allowNull: false,
            references: {
                model: "GroupMaster",
                key: "group_id",
            },
        },
        user_id: {
            type: DataTypes.INTEGER,
            allowNull: false,
            references: {
                model: "User",
                key: "user_id",
            },
        },
        sender_id: {
            type: DataTypes.INTEGER,
            allowNull: false,
            references: {
                model: "User",
                key: "user_id",
            },
        },
        group_message: {
            type: DataTypes.TEXT,
            allowNull: false,
        },
        is_deleted: {
            type: DataTypes.INTEGER,
            allowNull: false,
            defaultValue: 0
            // 0 = not deleted, 1 = deleted	
        },
        public_deleted_flag: {
            type: DataTypes.INTEGER,
            allowNull: false,
            defaultValue: 0
            // 0 = not deleted, 1 = deleted	
        },
        deleted_by: {
            type: DataTypes.TEXT,
            allowNull: true,
        },
        reply_message_id: {
            type: DataTypes.INTEGER,
            allowNull: true,
        },
        tags: {
            type: DataTypes.STRING,
            allowNull: true,
        },
        created_date: {
            allowNull: false,
            type: DataTypes.INTEGER
        },
        updated_date: {
            allowNull: true,
            type: DataTypes.INTEGER
        },
        language_code: {
            type: DataTypes.STRING,
            allowNull: false,
        }
    }, {
        sequelize,
        modelName: "GroupMessage",
        tableName: 'group_message',
        timestamps: false
    });
    return GroupMessage;
};
//# sourceMappingURL=group_message.js.map