"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const models = require('./../models/index');
const common_1 = __importDefault(require("../helpers/common"));
const responseCodes_1 = require("../helpers/responseCodes");
const { writeCsvFile } = new common_1.default();
const csvParser = require('csv-parser');
const fs = require('fs');
const moment = require('moment');
class DataMigrateService {
    constructor() {
        this.UploadCSV = this.UploadCSV.bind(this);
        this.UploadCSVGroupMessage = this.UploadCSVGroupMessage.bind(this);
        this.UploadCSVUsers = this.UploadCSVUsers.bind(this);
        this.UploadCSVFriendMessage = this.UploadCSVFriendMessage.bind(this);
        this.UploadCSVFriendGroup = this.UploadCSVFriendGroup.bind(this);
        this.UploadCSVFriendMaster = this.UploadCSVFriendMaster.bind(this);
        this.UploadCSVAdvertisement = this.UploadCSVAdvertisement.bind(this);
        this.UploadCSVAdminuser = this.UploadCSVAdminuser.bind(this);
        this.UploadCSVSerialnumber = this.UploadCSVSerialnumber.bind(this);
        this.UploadCSVServicefeature = this.UploadCSVServicefeature.bind(this);
        this.UploadCSVService = this.UploadCSVService.bind(this);
        this.UploadCSVPhrasecategory = this.UploadCSVPhrasecategory.bind(this);
        this.UploadCSVPhrasesubcategory = this.UploadCSVPhrasesubcategory.bind(this);
        this.UploadCSVPhrase = this.UploadCSVPhrase.bind(this);
        this.SetStartingValue = this.SetStartingValue.bind(this);
    }
    //upload csv for group member table to get old php  database
    UploadCSV(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const createdDateKey = 'created_date';
                const updatedDateKey = 'updated_date';
                const tempFilePath = 'file.csv'; // Replace with the actual path
                yield writeCsvFile(req.file.buffer, tempFilePath);
                // Read from the temporary file instead of the buffer
                const readStream = fs.createReadStream(tempFilePath);
                // Read the CSV file and insert data into the database
                readStream
                    .pipe(csvParser())
                    .on('data', (row) => __awaiter(this, void 0, void 0, function* () {
                    try {
                        const createdDateString = row[createdDateKey];
                        const updatedDateString = row[updatedDateKey];
                        const createdDateTimestamp = moment(createdDateString, 'YYYY-MM-DD HH:mm:ss').unix();
                        const updatedDateTimestamp = updatedDateString
                            ? moment(updatedDateString, 'YYYY-MM-DD HH:mm:ss').unix()
                            : null;
                        const groupName = row.group_name || '';
                        const groupId = parseInt(row.group_id);
                        const groupImage = row.group_image || '';
                        const groupType = row.group_type || 1;
                        const groupqrImage = row.group_qr_image || '';
                        const ownerId = row.group_owner_id ? parseInt(row.group_owner_id) : null;
                        const memberIds = row.group_member_id ? row.group_member_id.split(',').map((id) => parseInt(id)).filter(id => !isNaN(id)) : [];
                        // Create a new group record in the GroupMaster table
                        const groupRecord = yield models.GroupMaster.create({ group_id: groupId, group_name: groupName, group_image: groupImage, group_owner_id: ownerId, group_type: groupType, group_qr_image: groupqrImage, created_date: createdDateTimestamp, updated_date: updatedDateTimestamp, });
                        const currentGroupId = groupRecord.group_id; // Get the current group's ID
                        if (memberIds.length > 0) {
                            // Create group member records in the GroupMember table for each memberId
                            const groupMemberData = memberIds.map((memberId) => ({
                                group_id: currentGroupId,
                                user_id: memberId,
                                created_date: createdDateTimestamp,
                                updated_date: updatedDateTimestamp,
                            }));
                            // Insert groupMemberData into the database
                            yield models.GroupMember.bulkCreate(groupMemberData);
                        }
                    }
                    catch (error) {
                        console.error('Error inserting data:', error);
                    }
                }))
                    .on('end', () => {
                    fs.unlinkSync(tempFilePath);
                    return callback(null, { status: responseCodes_1.HttpCodes['API_SUCCESS'], msg: 'DataUploadSuccess', code: responseCodes_1.HttpCodes['OK'], data: [], });
                });
            }
            catch (error) {
                console.log(error.message, 'removeFriendMessage');
                return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
            }
        });
    }
    //upload csv for group message table to get old php  database
    UploadCSVGroupMessage(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const createdDateKey = 'created_date';
                const updatedDateKey = 'updated_date';
                const tempFilePath = 'file.csv'; // Replace with the actual path
                yield writeCsvFile(req.file.buffer, tempFilePath);
                // Read from the temporary file instead of the buffer
                const readStream = fs.createReadStream(tempFilePath);
                // Read the CSV file and collect data for bulk insertion
                readStream
                    .pipe(csvParser())
                    .on('data', (row) => __awaiter(this, void 0, void 0, function* () {
                    try {
                        // Extract the group_id from your CSV data
                        const groupId = parseInt(row.group_id);
                        // Check if the group_id exists in the GroupMaster table
                        const groupExists = yield models.GroupMaster.findOne({
                            where: { group_id: groupId },
                        });
                        if (groupExists) {
                            // The group_id exists in the GroupMaster table, proceed with message insertion
                            const createdDateString = row[createdDateKey];
                            const updatedDateString = row[updatedDateKey];
                            const createdDateTimestamp = moment(createdDateString, 'YYYY-MM-DD HH:mm:ss').unix();
                            const updatedDateTimestamp = updatedDateString
                                ? moment(updatedDateString, 'YYYY-MM-DD HH:mm:ss').unix()
                                : null;
                            yield models.GroupMessage.create({
                                group_message_id: parseInt(row.group_message_id),
                                group_id: groupId,
                                sender_id: row.sender_id || null,
                                user_id: row.user_id || null,
                                group_message: row.group_message || '',
                                is_deleted: row.is_deleted || 0,
                                public_deleted_flag: row.public_deleted_flag || 0,
                                deleted_by: row.deleted_by == "NULL" ? null : row.deleted_by,
                                reply_message_id: row.reply_message_id == "NULL" ? null : row.reply_message_id,
                                tags: row.tags ? row.tags : '[]',
                                created_date: createdDateTimestamp,
                                updated_date: updatedDateTimestamp,
                                language_code: 'en-US'
                            });
                        }
                        else {
                            // The group_id doesn't exist in the GroupMaster table, skip this row
                            console.log(`Group with ID ${groupId} does not exist in GroupMaster. Skipping...`);
                        }
                    }
                    catch (error) {
                        console.error('Error collecting data:', error);
                    }
                }))
                    .on('end', () => __awaiter(this, void 0, void 0, function* () {
                    try {
                        // Bulk insert messages only if there are messages to insert
                        fs.unlinkSync(tempFilePath);
                        return callback(null, { status: responseCodes_1.HttpCodes['API_SUCCESS'], msg: 'DataUploadSuccess', code: responseCodes_1.HttpCodes['OK'], data: [], });
                    }
                    catch (err) {
                        console.error('Error inserting data:', err);
                        return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
                    }
                }));
            }
            catch (error) {
                console.log(error.message, 'removeFriendMessage');
                return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
            }
        });
    }
    //upload csv for user table to get old php  database
    UploadCSVUsers(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const createdDateKey = 'created_date';
                const updatedDateKey = 'updated_date';
                const isloginDateKey = 'is_login';
                const isLoginTranslateDateKey = 'is_login_translate';
                const tempFilePath = 'file.csv'; // Replace with the actual path
                yield writeCsvFile(req.file.buffer, tempFilePath);
                // Read from the temporary file instead of the buffer
                const readStream = fs.createReadStream(tempFilePath);
                const messagesToInsert = []; // Collect messages to insert in bulk
                // Read the CSV file and collect data for bulk insertion
                readStream
                    .pipe(csvParser())
                    .on('data', (row) => __awaiter(this, void 0, void 0, function* () {
                    try {
                        // Extract the group_id from your CSV data
                        // The group_id exists in the GroupMaster table, proceed with message insertion
                        const createdDateString = row[createdDateKey];
                        const updatedDateString = row[updatedDateKey];
                        const isloginDateString = row[isloginDateKey];
                        const isLoginTranslateDateString = row[isLoginTranslateDateKey];
                        const createdDateTimestamp = createdDateString ? moment(createdDateString, 'YYYY-MM-DD HH:mm:ss').unix() : null;
                        const updatedDateTimestamp = updatedDateString
                            ? moment(updatedDateString, 'YYYY-MM-DD HH:mm:ss').unix()
                            : null;
                        const isloginDateTimestamp = isloginDateString ? moment(isloginDateString, 'YYYY-MM-DD HH:mm:ss').unix() : null;
                        const isLoginTranslateDateDateTimestamp = isLoginTranslateDateString
                            ? moment(isLoginTranslateDateString, 'YYYY-MM-DD HH:mm:ss').unix()
                            : null;
                        yield models.User.create({
                            user_id: parseInt(row.user_id),
                            user_name: row.user_name,
                            user_email: row.user_email,
                            user_password: row.user_password,
                            profile_picture: row.profile_picture == "NULL" ? '' : row.profile_picture,
                            user_login_type: row.user_login_type == "NULL" ? 0 : parseInt(row.user_login_type),
                            title: row.title == "NULL" ? '' : row.title,
                            registered_from: row.registered_from == "NULL" ? '' : row.registered_from,
                            facebook_id: row.facebook_id == "NULL" ? '' : row.facebook_id,
                            google_plus_id: row.google_plus_id == "NULL" ? '' : row.google_plus_id,
                            twitter_id: row.twitter_id == "NULL" ? '' : row.twitter_id,
                            activation_key: row.activation_key == "NULL" ? '' : row.activation_key,
                            is_verified: row.is_verified == "NULL" ? 0 : parseInt(row.is_verified),
                            is_translate_app: row.is_translate_app == "NULL" ? 0 : parseInt(row.is_translate_app),
                            is_mymanuplay_app: row.is_mymanuplay_app == "NULL" ? 0 : parseInt(row.is_mymanuplay_app),
                            push_notification: row.push_notification == "NULL" ? 1 : parseInt(row.push_notification),
                            device_token: row.device_token == "NULL" ? '' : row.device_token,
                            device_token_translate: row.device_token_translate == "NULL" ? '' : row.device_token_translate,
                            device_type: row.device_type == "NULL" ? 0 : parseInt(row.device_type),
                            device_type_translate: row.device_type_translate == "NULL" ? 0 : parseInt(row.device_type_translate),
                            is_deleted: row.is_deleted == "NULL" ? 1 : parseInt(row.is_deleted),
                            status: row.status == "NULL" ? 1 : parseInt(row.status),
                            is_login: isNaN(isloginDateTimestamp) ? null : isloginDateTimestamp,
                            is_login_translate: isNaN(isLoginTranslateDateDateTimestamp) ? null : isLoginTranslateDateDateTimestamp,
                            login_access_token: '',
                            login_access_token_translate: '',
                            is_post_activity: row.is_post_activity == "NULL" ? 0 : parseInt(row.is_post_activity),
                            block_for_chat: row.block_for_chat == "NULL" ? 1 : parseInt(row.block_for_chat),
                            language_code: 'en-US',
                            region: row.region == "NULL" ? '' : row.region,
                            user_qr_image: row.user_qr_image == "NULL" ? '' : row.user_qr_image,
                            subscription_plan: row.subscription_plan == "NULL" ? '' : row.subscription_plan,
                            subscription_plan_device_type: row.subscription_plan_device_type == "NULL" ? '' : row.subscription_plan_device_type,
                            subscribed_on: row.subscribed_on == "NULL" ? null : parseInt(row.subscribed_on),
                            voice_preference: row.voice_preference == "NULL" ? '' : row.voice_preference,
                            created_date: isNaN(createdDateTimestamp) ? null : createdDateTimestamp,
                            updated_date: isNaN(updatedDateTimestamp) ? null : updatedDateTimestamp,
                            is_deleted_translate: row.is_deleted_translate == "NULL" ? null : parseInt(row.is_deleted_translate),
                            otp: row.otp ? row.otp : null,
                        });
                    }
                    catch (error) {
                        console.error('Error collecting data:', error);
                    }
                }))
                    .on('end', () => __awaiter(this, void 0, void 0, function* () {
                    try {
                        // Bulk insert messages only if there are messages to insert
                        fs.unlinkSync(tempFilePath);
                        return callback(null, { status: responseCodes_1.HttpCodes['API_SUCCESS'], msg: 'DataUploadSuccess', code: responseCodes_1.HttpCodes['OK'], data: [], });
                    }
                    catch (err) {
                        console.error('Error inserting data:', err);
                        return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
                    }
                }));
            }
            catch (error) {
                console.log(error.message, 'removeFriendMessage');
                return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
            }
        });
    }
    //upload csv for friend message table to get old php  database
    UploadCSVFriendMessage(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const createdDateKey = 'created_date';
                const updatedDateKey = 'updated_date';
                const isloginDateKey = 'is_login';
                const isLoginTranslateDateKey = 'is_login_translate';
                const tempFilePath = 'file.csv'; // Replace with the actual path
                yield writeCsvFile(req.file.buffer, tempFilePath);
                // Read from the temporary file instead of the buffer
                const readStream = fs.createReadStream(tempFilePath);
                // Read the CSV file and collect data for bulk insertion
                readStream
                    .pipe(csvParser())
                    .on('data', (row) => __awaiter(this, void 0, void 0, function* () {
                    try {
                        // Extract the group_id from your CSV data
                        // The group_id exists in the GroupMaster table, proceed with message insertion
                        const createdDateString = row[createdDateKey];
                        const updatedDateString = row[updatedDateKey];
                        const createdDateTimestamp = createdDateString ? moment(createdDateString, 'YYYY-MM-DD HH:mm:ss').unix() : null;
                        const updatedDateTimestamp = updatedDateString
                            ? moment(updatedDateString, 'YYYY-MM-DD HH:mm:ss').unix()
                            : null;
                        const friendMessageEntry = yield models.FriendGroup.findOne({
                            where: {
                                friend_group_id: parseInt(row.friend_group_id),
                            },
                        });
                        // Check if a valid friend_message entry was found.
                        if (friendMessageEntry) {
                            // Combination exists, proceed with FriendMessage creation.}
                            yield models.FriendMessage.create({
                                friend_message_id: parseInt(row.friend_message_id),
                                friend_group_id: parseInt(row.friend_group_id),
                                sender_id: parseInt(row.sender_id),
                                receiver_id: parseInt(row.receiver_id),
                                message: row.message ? row.message : '',
                                sender_deleted: parseInt(row.sender_deleted) ? parseInt(row.sender_deleted) : 0,
                                receiver_deleted: parseInt(row.receiver_deleted) ? parseInt(row.receiver_deleted) : 0,
                                reply_message_id: parseInt(row.reply_message_id) ? parseInt(row.reply_message_id) : 0,
                                created_date: isNaN(createdDateTimestamp) ? null : createdDateTimestamp,
                                updated_date: isNaN(updatedDateTimestamp) ? null : updatedDateTimestamp,
                                language_code: 'en-US',
                                receiver_message: row.message ? row.message : '',
                                receiver_language_code: 'en-US',
                            });
                        }
                        else {
                            // Combination doesn't exist, skip FriendMessage creation.
                            console.log("Combination not found in friend_message. Skipping FriendMessage creation.", row.friend_group_id);
                        }
                    }
                    catch (error) {
                        console.error('Error collecting data:', error);
                    }
                }))
                    .on('end', () => __awaiter(this, void 0, void 0, function* () {
                    try {
                        // Bulk insert messages only if there are messages to insert
                        fs.unlinkSync(tempFilePath);
                        return callback(null, { status: responseCodes_1.HttpCodes['API_SUCCESS'], msg: 'DataUploadSuccess', code: responseCodes_1.HttpCodes['OK'], data: [], });
                    }
                    catch (err) {
                        console.error('Error inserting data:', err);
                        return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
                    }
                }));
            }
            catch (error) {
                console.log(error.message, 'removeFriendMessage');
                return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
            }
        });
    }
    //upload csv for friend group table to get old php  database
    UploadCSVFriendGroup(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const createdDateKey = 'created_date';
                const updatedDateKey = 'updated_date';
                const tempFilePath = 'file.csv'; // Replace with the actual path
                yield writeCsvFile(req.file.buffer, tempFilePath);
                // Read from the temporary file instead of the buffer
                const readStream = fs.createReadStream(tempFilePath);
                // Read the CSV file and collect data for bulk insertion
                readStream
                    .pipe(csvParser())
                    .on('data', (row) => __awaiter(this, void 0, void 0, function* () {
                    try {
                        // Extract the group_id from your CSV data
                        // The group_id exists in the GroupMaster table, proceed with message insertion
                        const createdDateString = row[createdDateKey];
                        const updatedDateString = row[updatedDateKey];
                        const createdDateTimestamp = createdDateString ? moment(createdDateString, 'YYYY-MM-DD HH:mm:ss').unix() : null;
                        const updatedDateTimestamp = updatedDateString
                            ? moment(updatedDateString, 'YYYY-MM-DD HH:mm:ss').unix() : null;
                        const friendMasterEntry = yield models.FriendMaster.findOne({ where: { invite_from_id: parseInt(row.owner_id), invite_to_id: parseInt(row.member_id), is_friend: 1, }, });
                        if (friendMasterEntry) {
                            let data = yield models.FriendGroup.create({
                                friend_group_id: parseInt(row.friend_group_id),
                                friend_group_name: row.friend_group_name,
                                owner_id: parseInt(row.owner_id),
                                member_id: parseInt(row.member_id),
                                created_date: isNaN(createdDateTimestamp) ? null : createdDateTimestamp,
                                updated_date: isNaN(updatedDateTimestamp) ? null : updatedDateTimestamp,
                            });
                        }
                        else {
                            // Combination doesn't exist or is_friend is not 1, skip FriendGroup creation.
                            console.log("Combination not found in friend_master or is_friend is not 1. Skipping FriendGroup creation.", row.owner_id, row.member_id, "friend_group_id", row.friend_group_id);
                        }
                    }
                    catch (error) {
                        console.error('Error collecting data:', error);
                    }
                }))
                    .on('end', () => __awaiter(this, void 0, void 0, function* () {
                    try {
                        // Bulk insert messages only if there are messages to insert
                        fs.unlinkSync(tempFilePath);
                        return callback(null, { status: responseCodes_1.HttpCodes['API_SUCCESS'], msg: 'DataUploadSuccess', code: responseCodes_1.HttpCodes['OK'], data: [], });
                    }
                    catch (err) {
                        console.error('Error inserting data:', err);
                        return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
                    }
                }));
            }
            catch (error) {
                console.log(error.message, 'removeFriendMessage');
                return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
            }
        });
    }
    //upload csv for friend master table to get old php  database
    UploadCSVFriendMaster(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const createdDateKey = 'created_date';
                const updatedDateKey = 'updated_date';
                const tempFilePath = 'file.csv'; // Replace with the actual path
                yield writeCsvFile(req.file.buffer, tempFilePath);
                // Read from the temporary file instead of the buffer
                const readStream = fs.createReadStream(tempFilePath);
                // Read the CSV file and collect data for bulk insertion
                readStream
                    .pipe(csvParser())
                    .on('data', (row) => __awaiter(this, void 0, void 0, function* () {
                    try {
                        // Extract the group_id from your CSV data
                        // The group_id exists in the GroupMaster table, proceed with message insertion
                        const createdDateString = row[createdDateKey];
                        const updatedDateString = row[updatedDateKey];
                        const createdDateTimestamp = createdDateString ? moment(createdDateString, 'YYYY-MM-DD HH:mm:ss').unix() : null;
                        const updatedDateTimestamp = updatedDateString
                            ? moment(updatedDateString, 'YYYY-MM-DD HH:mm:ss').unix() : null;
                        let data = yield models.FriendMaster.create({
                            invite_id: parseInt(row.invite_id),
                            invite_from_id: parseInt(row.invite_from_id) || null,
                            invite_to_id: parseInt(row.invite_to_id) || null,
                            is_invite_sent: parseInt(row.is_invite_sent) || 0,
                            is_friend: parseInt(row.is_friend) || 0,
                            created_date: isNaN(createdDateTimestamp) ? null : createdDateTimestamp,
                            updated_date: isNaN(updatedDateTimestamp) ? null : updatedDateTimestamp,
                        });
                    }
                    catch (error) {
                        console.error('Error collecting data:', error);
                    }
                }))
                    .on('end', () => __awaiter(this, void 0, void 0, function* () {
                    try {
                        // Bulk insert messages only if there are messages to insert
                        fs.unlinkSync(tempFilePath);
                        return callback(null, { status: responseCodes_1.HttpCodes['API_SUCCESS'], msg: 'DataUploadSuccess', code: responseCodes_1.HttpCodes['OK'], data: [], });
                    }
                    catch (err) {
                        console.error('Error inserting data:', err);
                        return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
                    }
                }));
            }
            catch (error) {
                console.log(error.message, 'removeFriendMessage');
                return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
            }
        });
    }
    //upload csv for advertisement table to get old php  database
    UploadCSVAdvertisement(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const createdDateKey = 'created_date';
                const updatedDateKey = 'updated_date';
                const tempFilePath = 'file.csv'; // Replace with the actual path
                yield writeCsvFile(req.file.buffer, tempFilePath);
                // Read from the temporary file instead of the buffer
                const readStream = fs.createReadStream(tempFilePath);
                // Read the CSV file and collect data for bulk insertion
                readStream
                    .pipe(csvParser())
                    .on('data', (row) => __awaiter(this, void 0, void 0, function* () {
                    try {
                        // Extract the group_id from your CSV data
                        // The group_id exists in the GroupMaster table, proceed with message insertion
                        const createdDateString = row[createdDateKey];
                        const updatedDateString = row[updatedDateKey];
                        const createdDateTimestamp = createdDateString ? moment(createdDateString, 'YYYY-MM-DD HH:mm:ss').unix() : null;
                        const updatedDateTimestamp = updatedDateString
                            ? moment(updatedDateString, 'YYYY-MM-DD HH:mm:ss').unix() : null;
                        let data = yield models.AdvertisementMaster.create({
                            advertisement_id: parseInt(row.advertisement_id),
                            advertisement_image: row.advertisement_image || '',
                            advertisement_link: row.advertisement_link || '',
                            sort_order: parseInt(row.sort_order) || null,
                            status: parseInt(row.status) || 1,
                            is_discover: parseInt(row.is_discover) || 1,
                            title: row.title || '',
                            description: row.description || '',
                            created_date: isNaN(createdDateTimestamp) ? null : createdDateTimestamp,
                            updated_date: isNaN(updatedDateTimestamp) ? null : updatedDateTimestamp,
                        });
                    }
                    catch (error) {
                        console.error('Error collecting data:', error);
                    }
                }))
                    .on('end', () => __awaiter(this, void 0, void 0, function* () {
                    try {
                        // Bulk insert messages only if there are messages to insert
                        fs.unlinkSync(tempFilePath);
                        return callback(null, { status: responseCodes_1.HttpCodes['API_SUCCESS'], msg: 'DataUploadSuccess', code: responseCodes_1.HttpCodes['OK'], data: [], });
                    }
                    catch (err) {
                        console.error('Error inserting data:', err);
                        return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
                    }
                }));
            }
            catch (error) {
                console.log(error.message, 'removeFriendMessage');
                return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
            }
        });
    }
    //upload csv for admin user table to get old php  database
    UploadCSVAdminuser(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const createdDateKey = 'created_date';
                const updatedDateKey = 'updated_date';
                const tempFilePath = 'file.csv'; // Replace with the actual path
                yield writeCsvFile(req.file.buffer, tempFilePath);
                // Read from the temporary file instead of the buffer
                const readStream = fs.createReadStream(tempFilePath);
                // Read the CSV file and collect data for bulk insertion
                readStream
                    .pipe(csvParser())
                    .on('data', (row) => __awaiter(this, void 0, void 0, function* () {
                    try {
                        // Extract the group_id from your CSV data
                        // The group_id exists in the GroupMaster table, proceed with message insertion
                        const createdDateString = row[createdDateKey];
                        const updatedDateString = row[updatedDateKey];
                        const createdDateTimestamp = createdDateString ? moment(createdDateString, 'YYYY-MM-DD HH:mm:ss').unix() : null;
                        const updatedDateTimestamp = updatedDateString
                            ? moment(updatedDateString, 'YYYY-MM-DD HH:mm:ss').unix()
                            : null;
                        let data = yield models.Admin.create({
                            admin_id: parseInt(row.admin_id),
                            fullname: row.fullname || '',
                            role_id: parseInt(row.role_id) || null,
                            emailid: row.emailid || '',
                            password: row.password || '',
                            status: parseInt(row.status) || 1,
                            login_access_token: '',
                            otp: row.otp ? row.otp : null,
                            created_date: isNaN(createdDateTimestamp) ? null : createdDateTimestamp,
                            updated_date: isNaN(updatedDateTimestamp) ? null : updatedDateTimestamp,
                        });
                    }
                    catch (error) {
                        console.error('Error collecting data:', error);
                    }
                }))
                    .on('end', () => __awaiter(this, void 0, void 0, function* () {
                    try {
                        // Bulk insert messages only if there are messages to insert
                        fs.unlinkSync(tempFilePath);
                        return callback(null, { status: responseCodes_1.HttpCodes['API_SUCCESS'], msg: 'DataUploadSuccess', code: responseCodes_1.HttpCodes['OK'], data: [], });
                    }
                    catch (err) {
                        console.error('Error inserting data:', err);
                        return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
                    }
                }));
            }
            catch (error) {
                console.log(error.message, 'removeFriendMessage');
                return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
            }
        });
    }
    //upload csv for serial number table to get old php  database
    UploadCSVSerialnumber(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const createdDateKey = 'created_date';
                const updatedDateKey = 'updated_date';
                const tempFilePath = 'file.csv'; // Replace with the actual path
                yield writeCsvFile(req.file.buffer, tempFilePath);
                // Read from the temporary file instead of the buffer
                const readStream = fs.createReadStream(tempFilePath);
                // Read the CSV file and collect data for bulk insertion
                readStream
                    .pipe(csvParser())
                    .on('data', (row) => __awaiter(this, void 0, void 0, function* () {
                    try {
                        // Extract the group_id from your CSV data
                        // The group_id exists in the GroupMaster table, proceed with message insertion
                        const createdDateString = row[createdDateKey];
                        const updatedDateString = row[updatedDateKey];
                        const createdDateTimestamp = createdDateString ? moment(createdDateString, 'YYYY-MM-DD HH:mm:ss').unix() : null;
                        const updatedDateTimestamp = updatedDateString
                            ? moment(updatedDateString, 'YYYY-MM-DD HH:mm:ss').unix()
                            : null;
                        let data = yield models.SerialNumber.create({
                            id: parseInt(row.id),
                            serial_number: row.serial_number || '',
                            device_type: row.device_type || '',
                            created_date: isNaN(createdDateTimestamp) ? null : createdDateTimestamp,
                        });
                    }
                    catch (error) {
                        console.error('Error collecting data:', error);
                    }
                }))
                    .on('end', () => __awaiter(this, void 0, void 0, function* () {
                    try {
                        // Bulk insert messages only if there are messages to insert
                        fs.unlinkSync(tempFilePath);
                        return callback(null, { status: responseCodes_1.HttpCodes['API_SUCCESS'], msg: 'DataUploadSuccess', code: responseCodes_1.HttpCodes['OK'], data: [], });
                    }
                    catch (err) {
                        console.error('Error inserting data:', err);
                        return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
                    }
                }));
            }
            catch (error) {
                console.log(error.message, 'removeFriendMessage');
                return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
            }
        });
    }
    //upload csv for service feature table to get old php  database
    UploadCSVServicefeature(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const createdDateKey = 'created_date';
                const updatedDateKey = 'updated_date';
                const tempFilePath = 'file.csv'; // Replace with the actual path
                yield writeCsvFile(req.file.buffer, tempFilePath);
                // Read from the temporary file instead of the buffer
                const readStream = fs.createReadStream(tempFilePath);
                // Read the CSV file and collect data for bulk insertion
                readStream
                    .pipe(csvParser())
                    .on('data', (row) => __awaiter(this, void 0, void 0, function* () {
                    try {
                        // Extract the group_id from your CSV data
                        // The group_id exists in the GroupMaster table, proceed with message insertion
                        const createdDateString = row[createdDateKey];
                        const updatedDateString = row[updatedDateKey];
                        const createdDateTimestamp = createdDateString ? moment(createdDateString, 'YYYY-MM-DD HH:mm:ss').unix() : null;
                        const updatedDateTimestamp = updatedDateString
                            ? moment(updatedDateString, 'YYYY-MM-DD HH:mm:ss').unix()
                            : null;
                        let data = yield models.ServiceFeature.create({
                            feature_id: parseInt(row.feature_id),
                            feature: row.feature || '',
                            created_date: isNaN(createdDateTimestamp) ? null : createdDateTimestamp,
                            updated_date: isNaN(updatedDateTimestamp) ? null : updatedDateTimestamp,
                        });
                    }
                    catch (error) {
                        console.error('Error collecting data:', error);
                    }
                }))
                    .on('end', () => __awaiter(this, void 0, void 0, function* () {
                    try {
                        // Bulk insert messages only if there are messages to insert
                        fs.unlinkSync(tempFilePath);
                        return callback(null, { status: responseCodes_1.HttpCodes['API_SUCCESS'], msg: 'DataUploadSuccess', code: responseCodes_1.HttpCodes['OK'], data: [], });
                    }
                    catch (err) {
                        console.error('Error inserting data:', err);
                        return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
                    }
                }));
            }
            catch (error) {
                console.log(error.message, 'removeFriendMessage');
                return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
            }
        });
    }
    //upload csv for service table to get old php  database
    UploadCSVService(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const createdDateKey = 'created_date';
                const updatedDateKey = 'updated_date';
                const tempFilePath = 'file.csv';
                yield writeCsvFile(req.file.buffer, tempFilePath);
                // Read from the temporary file instead of the buffer
                const readStream = fs.createReadStream(tempFilePath);
                // Read the CSV file and collect data for bulk insertion
                readStream
                    .pipe(csvParser())
                    .on('data', (row) => __awaiter(this, void 0, void 0, function* () {
                    try {
                        // The group_id exists in the GroupMaster table, proceed with message insertion
                        const createdDateString = row[createdDateKey];
                        const updatedDateString = row[updatedDateKey];
                        const createdDateTimestamp = createdDateString ? moment(createdDateString, 'YYYY-MM-DD HH:mm:ss').unix() : null;
                        const updatedDateTimestamp = updatedDateString
                            ? moment(updatedDateString, 'YYYY-MM-DD HH:mm:ss').unix()
                            : null;
                        let data = yield models.Services.create({
                            id: parseInt(row.id),
                            service_title: row.service_title || '',
                            service_image: row.service_image || '',
                            service_price: row.service_price || '',
                            service_short_description: row.service_short_description || '',
                            service_description: row.service_description || '',
                            service_status: parseInt(row.service_status) || 1,
                            created_date: isNaN(createdDateTimestamp) ? null : createdDateTimestamp,
                            updated_date: isNaN(updatedDateTimestamp) ? null : updatedDateTimestamp,
                        });
                        const currentServiceId = data.id; // Get the current group's ID
                        const featureIds = row.feature_id ? row.feature_id.split(',').map((id) => parseInt(id)).filter(id => !isNaN(id)) : [];
                        if (featureIds.length > 0) {
                            // Create group member records in the ServiceFeatureData table for each featureId
                            const ServiceFeatureData = featureIds.map((featureId) => ({
                                service_id: currentServiceId,
                                feature_id: featureId,
                                created_date: createdDateTimestamp,
                                updated_date: updatedDateTimestamp,
                            }));
                            // Insert ServiceFeatureData into the database
                            yield models.ServiceFeatureData.bulkCreate(ServiceFeatureData);
                        }
                        else {
                            // Handle the case where there are no valid featureIds (e.g., log a message or take appropriate action)
                            console.warn('No valid featureIds found for this service.');
                        }
                    }
                    catch (error) {
                        console.error('Error collecting data:', error);
                    }
                }))
                    .on('end', () => __awaiter(this, void 0, void 0, function* () {
                    try {
                        // Bulk insert messages only if there are messages to insert
                        fs.unlinkSync(tempFilePath);
                        return callback(null, { status: responseCodes_1.HttpCodes['API_SUCCESS'], msg: 'DataUploadSuccess', code: responseCodes_1.HttpCodes['OK'], data: [], });
                    }
                    catch (err) {
                        console.error('Error inserting data:', err);
                        return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
                    }
                }));
            }
            catch (error) {
                console.log(error.message, 'removeFriendMessage');
                return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
            }
        });
    }
    //upload csv for phrase category table to get old php  database
    UploadCSVPhrasecategory(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const createdDateKey = 'created_date';
                const updatedDateKey = 'updated_date';
                const tempFilePath = 'file.csv'; // Replace with the actual path
                yield writeCsvFile(req.file.buffer, tempFilePath);
                // Read from the temporary file instead of the buffer
                const readStream = fs.createReadStream(tempFilePath);
                // Read the CSV file and collect data for bulk insertion
                readStream
                    .pipe(csvParser())
                    .on('data', (row) => __awaiter(this, void 0, void 0, function* () {
                    try {
                        // Extract the group_id from your CSV data
                        // The group_id exists in the GroupMaster table, proceed with message insertion
                        const createdDateString = row[createdDateKey];
                        const updatedDateString = row[updatedDateKey];
                        const createdDateTimestamp = createdDateString ? moment(createdDateString, 'YYYY-MM-DD HH:mm:ss').unix() : null;
                        const updatedDateTimestamp = updatedDateString
                            ? moment(updatedDateString, 'YYYY-MM-DD HH:mm:ss').unix()
                            : null;
                        let data = yield models.PhrasesCategory.create({
                            phrase_cat_id: parseInt(row.phrase_cat_id),
                            phrase_category: row.phrase_category || '',
                            phrase_image: row.phrase_image || '',
                            created_date: isNaN(createdDateTimestamp) ? null : createdDateTimestamp,
                            updated_date: isNaN(updatedDateTimestamp) ? null : updatedDateTimestamp,
                        });
                    }
                    catch (error) {
                        console.error('Error collecting data:', error);
                    }
                }))
                    .on('end', () => __awaiter(this, void 0, void 0, function* () {
                    try {
                        // Bulk insert messages only if there are messages to insert
                        fs.unlinkSync(tempFilePath);
                        return callback(null, { status: responseCodes_1.HttpCodes['API_SUCCESS'], msg: 'DataUploadSuccess', code: responseCodes_1.HttpCodes['OK'], data: [], });
                    }
                    catch (err) {
                        console.error('Error inserting data:', err);
                        return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
                    }
                }));
            }
            catch (error) {
                console.log(error.message, 'removeFriendMessage');
                return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
            }
        });
    }
    //upload csv for phrase sub category table to get old php  database
    UploadCSVPhrasesubcategory(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const createdDateKey = 'created_date';
                const updatedDateKey = 'updated_date';
                const tempFilePath = 'file.csv'; // Replace with the actual path
                yield writeCsvFile(req.file.buffer, tempFilePath);
                // Read from the temporary file instead of the buffer
                const readStream = fs.createReadStream(tempFilePath);
                // Read the CSV file and collect data for bulk insertion
                readStream
                    .pipe(csvParser())
                    .on('data', (row) => __awaiter(this, void 0, void 0, function* () {
                    try {
                        // Extract the group_id from your CSV data
                        // The group_id exists in the GroupMaster table, proceed with message insertion
                        const createdDateString = row[createdDateKey];
                        const updatedDateString = row[updatedDateKey];
                        const createdDateTimestamp = createdDateString ? moment(createdDateString, 'YYYY-MM-DD HH:mm:ss').unix() : null;
                        const updatedDateTimestamp = updatedDateString
                            ? moment(updatedDateString, 'YYYY-MM-DD HH:mm:ss').unix()
                            : null;
                        let data = yield models.PhrasesSubCategory.create({
                            phrase_sub_cat_id: parseInt(row.phrase_sub_cat_id),
                            phrase_cat_id: parseInt(row.phrase_cat_id) || null,
                            sub_category: row.sub_category || '',
                            created_date: isNaN(createdDateTimestamp) ? null : createdDateTimestamp,
                            updated_date: isNaN(updatedDateTimestamp) ? null : updatedDateTimestamp,
                        });
                    }
                    catch (error) {
                        console.error('Error collecting data:', error);
                    }
                }))
                    .on('end', () => __awaiter(this, void 0, void 0, function* () {
                    try {
                        // Bulk insert messages only if there are messages to insert
                        fs.unlinkSync(tempFilePath);
                        return callback(null, { status: responseCodes_1.HttpCodes['API_SUCCESS'], msg: 'DataUploadSuccess', code: responseCodes_1.HttpCodes['OK'], data: [], });
                    }
                    catch (err) {
                        console.error('Error inserting data:', err);
                        return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
                    }
                }));
            }
            catch (error) {
                console.log(error.message, 'removeFriendMessage');
                return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
            }
        });
    }
    //upload csv for phrase table to get old php  database
    UploadCSVPhrase(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const createdDateKey = 'created_date';
                const updatedDateKey = 'updated_date';
                const tempFilePath = 'file.csv'; // Replace with the actual path
                yield writeCsvFile(req.file.buffer, tempFilePath);
                // Read from the temporary file instead of the buffer
                const readStream = fs.createReadStream(tempFilePath);
                // Read the CSV file and collect data for bulk insertion
                readStream
                    .pipe(csvParser())
                    .on('data', (row) => __awaiter(this, void 0, void 0, function* () {
                    try {
                        // Extract the group_id from your CSV data
                        // The group_id exists in the GroupMaster table, proceed with message insertion
                        const createdDateString = row[createdDateKey];
                        const updatedDateString = row[updatedDateKey];
                        const createdDateTimestamp = createdDateString ? moment(createdDateString, 'YYYY-MM-DD HH:mm:ss').unix() : null;
                        const updatedDateTimestamp = updatedDateString
                            ? moment(updatedDateString, 'YYYY-MM-DD HH:mm:ss').unix()
                            : null;
                        let data = yield models.Phrases.create({
                            phrase_id: parseInt(row.phrase_id),
                            phrase_cat_id: parseInt(row.phrase_cat_id),
                            phrase_sub_cat_id: parseInt(row.phrase_sub_cat_id),
                            phrase: row.phrase || '',
                            created_date: isNaN(createdDateTimestamp) ? null : createdDateTimestamp,
                            updated_date: isNaN(updatedDateTimestamp) ? null : updatedDateTimestamp,
                        });
                    }
                    catch (error) {
                        console.error('Error collecting data:', error);
                    }
                }))
                    .on('end', () => __awaiter(this, void 0, void 0, function* () {
                    try {
                        // Bulk insert messages only if there are messages to insert
                        fs.unlinkSync(tempFilePath);
                        return callback(null, { status: responseCodes_1.HttpCodes['API_SUCCESS'], msg: 'DataUploadSuccess', code: responseCodes_1.HttpCodes['OK'], data: [], });
                    }
                    catch (err) {
                        console.error('Error inserting data:', err);
                        return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
                    }
                }));
            }
            catch (error) {
                console.log(error.message, 'removeFriendMessage');
                return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
            }
        });
    }
    //To accommodate existing data in the PostgreSQL table, set initial values for new entries
    SetStartingValue(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const tablesToSetStartingValue = [
                    { modelName: 'Admin', columnName: 'admin_id' },
                    { modelName: 'AdvertisementMaster', columnName: 'advertisement_id' },
                    { modelName: 'User', columnName: 'user_id' },
                    { modelName: 'FriendGroup', columnName: 'friend_group_id' },
                    { modelName: 'FriendMaster', columnName: 'invite_id' },
                    { modelName: 'FriendMessage', columnName: 'friend_message_id' },
                    { modelName: 'GroupMaster', columnName: 'group_id' },
                    { modelName: 'GroupMember', columnName: 'id' },
                    { modelName: 'GroupMessage', columnName: 'group_message_id' },
                    { modelName: 'SerialNumber', columnName: 'id' },
                    { modelName: 'ServiceFeature', columnName: 'feature_id' },
                    { modelName: 'Services', columnName: 'id' },
                    { modelName: 'ServiceFeatureData', columnName: 'id' },
                    { modelName: 'PhrasesCategory', columnName: 'phrase_cat_id' },
                    { modelName: 'PhrasesSubCategory', columnName: 'phrase_sub_cat_id' },
                    { modelName: 'Phrases', columnName: 'phrase_id' },
                ];
                let allSequencesSet = true; // Assume all sequences will be set
                for (const table of tablesToSetStartingValue) {
                    const { modelName, columnName } = table;
                    if (!modelName || !columnName) {
                        return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'BothDataRequired.', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
                    }
                    const Model = models[modelName]; // Replace `sequelize` with your Sequelize instance
                    if (!Model) {
                        throw new Error(`Model ${modelName} not found.`);
                    }
                    const lastRecord = yield Model.findOne({
                        order: [[columnName, 'DESC']], // Use the specified columnName for ordering
                    });
                    let nextValue;
                    if (lastRecord) {
                        // Calculate the next value for the sequence
                        nextValue = lastRecord[columnName] + 1;
                        const tableName = Model.getTableName();
                        const sequenceName = `${tableName}_${columnName}_seq`;
                        // Update the sequence
                        yield Model.sequelize.query(`ALTER SEQUENCE "${sequenceName}" RESTART WITH ${nextValue};`);
                        console.log(`Auto-increment sequence for ${tableName} set to start from ${nextValue}`);
                    }
                    else {
                        nextValue = 1;
                        allSequencesSet = false; // Not all sequences were set
                        console.error('No records found in the table.');
                    }
                }
                if (allSequencesSet) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_SUCCESS'], msg: `sequencesetsuccess`, code: responseCodes_1.HttpCodes['OK'], data: [], });
                }
                else {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'sequencesetfailure', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
                }
            }
            catch (error) {
                console.log(error.message, 'set start value');
                return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [], });
            }
        });
    }
}
exports.default = DataMigrateService;
//# sourceMappingURL=datamigration.services.js.map