"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const models = require('./../models/index');
const common_1 = __importDefault(require("../helpers/common"));
const responseCodes_1 = require("../helpers/responseCodes");
const { getEpoch, GenerateQR } = new common_1.default();
const { Sequelize } = require('sequelize'); // Import Sequelize object
class DeviceService {
    constructor() {
        this.RegisterDevice = this.RegisterDevice.bind(this);
        this.GetAdvertisement = this.GetAdvertisement.bind(this);
        this.GetTranslateUser = this.GetTranslateUser.bind(this);
        this.GenerateUserQR = this.GenerateUserQR.bind(this);
        this.UpdateDeviceToken = this.UpdateDeviceToken.bind(this);
    }
    // device registration
    RegisterDevice(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                let user_email = req.body.email.toLowerCase();
                let user_id = req.body.user_id;
                let serial_number = req.body.serial_number;
                let device_type = req.body.device_type;
                let application_type = parseInt(req.body.application_type);
                if (application_type !== 2) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                if (!user_email) {
                    return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'InvalidEmail', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                if (device_type !== 'CLIK_+' && device_type !== 'CLIK_S' && device_type !== 'TITAN') {
                    return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'InvalidDeviceType', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                const validateSerial = yield models.SerialNumber.findOne({
                    where: {
                        serial_number: serial_number,
                        device_type: device_type
                    },
                });
                if (!validateSerial) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'InvalidSerialNumber', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                // Check if the user has already registered a device
                const checkUserData = yield models.DeviceRegister.findOne({
                    where: {
                        user_id: user_id
                    }
                });
                if (checkUserData) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'AlreadyRegisteredDevice', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                const checkSerialNumber = yield models.SerialNumber.findOne({
                    where: {
                        serial_number: serial_number,
                        device_type: device_type
                    }
                });
                if (!checkSerialNumber) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SerialNumberDeviceInvalid', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                const insertArray = {
                    serial_number: serial_number,
                    device_type: device_type,
                    user_id: user_id,
                    email_address: user_email,
                    created_date: yield getEpoch(),
                    updated_date: yield getEpoch(),
                };
                const registerDeviceData = yield models.DeviceRegister.create(insertArray);
                if (registerDeviceData) {
                    /* Code to make user premium start */
                    const getUserData = yield models.User.findAll({ where: { user_id: user_id } });
                    const getDeviceType = getUserData[0].device_type_translate;
                    let deviceType = '';
                    if (getDeviceType === 1) {
                        deviceType = 'android';
                    }
                    else if (getDeviceType === 2) {
                        deviceType = 'ios';
                    }
                    const subscribedOn = yield getEpoch();
                    // const subscribedOn = new Date().toISOString().split('T')[0];
                    const updateArray = {
                        subscription_plan: 'register_as_premium',
                        subscription_plan_device_type: deviceType,
                        subscribed_on: subscribedOn
                    };
                    const updateSubscription = yield models.User.update(updateArray, { where: { user_id: user_id } });
                    const getUserUpdatedData = yield models.User.findAll({ where: { user_id: user_id } });
                    const getUserInfo = {
                        subscription_plan: getUserUpdatedData[0].subscription_plan,
                        subscription_plan_device_type: getUserUpdatedData[0].subscription_plan_device_type
                    };
                    /* Code to make user premium end */
                    return callback(null, { 'status': responseCodes_1.HttpCodes['API_SUCCESS'], 'msg': 'DeviceRegisteredsuccess', code: responseCodes_1.HttpCodes['OK'], data: getUserInfo });
                }
                else {
                    return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
            }
            catch (error) {
                console.log(error.message, "Register");
                return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'DeviceRegisterFailed', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
            }
        });
    }
    // get advertisement
    GetAdvertisement(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const orderBy = 'sort_order';
                const order = 'ASC';
                const getAdvertisementData = yield models.AdvertisementMaster.findAll({
                    attributes: ['advertisement_id', 'advertisement_image', 'advertisement_link', 'is_discover', 'title', 'description', 'created_date'],
                    where: { status: 1 },
                    order: [[orderBy, order]],
                    raw: true,
                });
                if (getAdvertisementData.length > 0) {
                    const advertisements = getAdvertisementData.map((advert) => ({
                        advertisement_id: advert.advertisement_id,
                        advertisement_image: advert.advertisement_image,
                        advertisement_link: advert.advertisement_link,
                        is_discover: advert.is_discover,
                        title: advert.title || '',
                        description: advert.description || '',
                        created_date: advert.created_date,
                    }));
                    return callback(null, { 'status': responseCodes_1.HttpCodes['API_SUCCESS'], 'msg': 'ListAdvertisement', code: responseCodes_1.HttpCodes['OK'], data: advertisements, host: process.env.TRANSLATIONHOST });
                }
                else {
                    return callback(null, { 'status': responseCodes_1.HttpCodes['API_SUCCESS'], 'msg': 'NoAdvertisementFound', code: responseCodes_1.HttpCodes['OK'], data: [], host: process.env.TRANSLATIONHOST });
                }
            }
            catch (err) {
                console.error('Error fetching advertisement data:', err);
                return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'ErrorFetchingData', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
            }
        });
    }
    //get all translate users
    GetTranslateUser(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { search, offset } = req.query;
                const application_type = parseInt(req.query.application_type);
                const user_id = req.body.user_id;
                if (isNaN(application_type) || application_type !== 2) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                let offsetValue = parseInt(offset);
                if (isNaN(offsetValue)) {
                    offsetValue = 0;
                }
                // Get Translate User
                const searchTerm = search ? { user_name: { [models.Sequelize.Op.iLike]: `%${search}%` } } : null;
                const whereArray = {
                    user_id: { [models.Sequelize.Op.ne]: user_id },
                    is_translate_app: 1,
                    status: 1,
                    is_verified: 1,
                    is_deleted: 1
                };
                const orderBy = 'user_id';
                const order = 'DESC';
                const filter = {
                    // attributes: ['user_id', 'profile_picture', 'user_name', 'language_code'],
                    attributes: [
                        'user_id',
                        [Sequelize.literal('COALESCE("profile_picture", \'\')'), 'profile_picture'],
                        [Sequelize.literal('COALESCE("user_name", \'\')'), 'user_name'],
                        [Sequelize.literal('COALESCE("language_code", \'\')'), 'language_code']
                    ],
                    where: Object.assign(Object.assign({}, whereArray), searchTerm),
                    offset: offsetValue,
                    order: [[orderBy, order]]
                };
                const getTranslateUserData = yield models.User.findAll(filter);
                if (getTranslateUserData.length > 0) {
                    const userListData = yield Promise.all(getTranslateUserData.map((userData) => __awaiter(this, void 0, void 0, function* () {
                        const getFMData = yield models.FriendMaster.findAll({
                            where: {
                                [models.Sequelize.Op.or]: [
                                    { invite_from_id: userData.user_id, invite_to_id: user_id },
                                    { invite_from_id: user_id, invite_to_id: userData.user_id },
                                ],
                            },
                        });
                        // Set the default values
                        let is_invite_sent = 0;
                        let is_friend = 0;
                        let friend_group_id = null;
                        if (getFMData.length > 0) {
                            is_invite_sent = getFMData[0].is_invite_sent || 0;
                            is_friend = getFMData[0].is_friend || 0;
                            const getFriendGroup = yield models.FriendMessage.findAll({
                                attributes: ['friend_group_id'],
                                where: {
                                    [models.Sequelize.Op.or]: [
                                        { sender_id: user_id },
                                        { receiver_id: user_id },
                                    ],
                                    [models.Sequelize.Op.or]: [
                                        { sender_id: userData.user_id },
                                        { receiver_id: userData.user_id },
                                    ],
                                },
                                order: [['created_date', 'DESC']],
                            });
                            friend_group_id = getFriendGroup.length > 0 ? getFriendGroup[0].friend_group_id : null;
                        }
                        userData.dataValues.is_invite_sent = is_invite_sent;
                        userData.dataValues.is_friend = is_friend;
                        userData.dataValues.friend_group_id = friend_group_id;
                        return userData;
                    })));
                    const filteredUserListData = userListData.filter(userData => userData !== null);
                    return callback(null, { 'status': responseCodes_1.HttpCodes['API_SUCCESS'], 'msg': 'TranslateAppUserList', code: responseCodes_1.HttpCodes['OK'], data: filteredUserListData, 'offset': offsetValue });
                }
                else {
                    return callback(null, { 'status': responseCodes_1.HttpCodes['API_SUCCESS'], 'msg': 'NoDataFound', code: responseCodes_1.HttpCodes['OK'], data: [], 'offset': offsetValue });
                }
            }
            catch (error) {
                console.log(error.message, "GetTranslateUser");
                return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'ErrorFetchingData', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
            }
        });
    }
    //genertate user qr
    GenerateUserQR(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const application_type = parseInt(req.body.application_type);
                const user_id = req.body.user_id;
                const qrType = 1; // for user qr 
                if (isNaN(application_type) || application_type !== 2) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                let userDBData = {};
                const getUserData = yield models.User.findOne({ where: { user_id: user_id, } });
                if (getUserData) {
                    let userQR = getUserData.user_qr_image;
                    if (!userQR) {
                        const userInfo = {
                            user_id: getUserData.user_id,
                            user_name: getUserData.user_name,
                            user_email: getUserData.user_email,
                            profile_picture: getUserData.profile_picture || '',
                            title: getUserData.title || '',
                            language_code: getUserData.language_code || '',
                        };
                        const userData = JSON.stringify(userInfo);
                        const generatedFile = yield GenerateQR(user_id, userData, qrType);
                        if ('status' in generatedFile && generatedFile.status) {
                            const updateUserQR = yield models.User.update({ user_qr_image: generatedFile.data }, { where: { user_id: user_id } });
                            if (updateUserQR[0] == 1) {
                                userDBData['user_id'] = getUserData.user_id;
                                userDBData['QR_code'] = generatedFile.data;
                                return callback(null, { status: responseCodes_1.HttpCodes['API_SUCCESS'], msg: 'QRGeneratedsuccess', code: responseCodes_1.HttpCodes.OK, data: userDBData });
                            }
                            else {
                                return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                            }
                        }
                        else {
                            return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'UserQRNotGenerated', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: {} });
                        }
                    }
                    else {
                        userDBData['user_id'] = getUserData.user_id;
                        userDBData['QR_code'] = getUserData.user_qr_image;
                        return callback(null, { status: responseCodes_1.HttpCodes['API_SUCCESS'], msg: 'QRGeneratedsuccess', code: responseCodes_1.HttpCodes.OK, data: userDBData });
                    }
                }
                else {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
            }
            catch (error) {
                console.error(error, "error while genrate user qr");
                return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'ErrorFetchingData', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
            }
        });
    }
    //update device token
    UpdateDeviceToken(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const application_type = parseInt(req.body.application_type);
                const user_id = req.body.user_id;
                const application_version = req.body.application_version;
                const device_token = req.body.device_token;
                if (isNaN(application_type) || application_type !== 2) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                const updateData = yield models.User.update({
                    device_token_translate: device_token,
                    updated_date: yield getEpoch()
                }, { where: { user_id: user_id } });
                if (updateData[0] == 1) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_SUCCESS'], msg: 'TokenUpdateSuccess', code: responseCodes_1.HttpCodes.OK, data: [] });
                }
                else {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
            }
            catch (error) {
                console.log("errror", error);
                return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
            }
        });
    }
}
exports.default = DeviceService;
//# sourceMappingURL=device.services.js.map