"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const models = require("./../models/index");
const common_1 = __importDefault(require("../helpers/common"));
const { getEpoch, documentUploadToS3 } = new common_1.default();
const responseCodes_1 = require("../helpers/responseCodes");
const libre = require('libreoffice-convert');
class DocumentServices {
    constructor() {
        this.insertDocument = this.insertDocument.bind(this);
        this.GetDocuments = this.GetDocuments.bind(this);
        this.DocToPdfConvert = this.DocToPdfConvert.bind(this);
        this.DeleteDocument = this.DeleteDocument.bind(this);
    }
    //insert all document
    insertDocument(req, callback) {
        var _a, _b, _c;
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const user_id = req.user;
                const from_language_code = (_a = req === null || req === void 0 ? void 0 : req.body) === null || _a === void 0 ? void 0 : _a.from_language_code;
                const to_language_code = (_b = req === null || req === void 0 ? void 0 : req.body) === null || _b === void 0 ? void 0 : _b.to_language_code;
                const application_type = parseInt(req.body.application_type);
                const title = (_c = req === null || req === void 0 ? void 0 : req.body) === null || _c === void 0 ? void 0 : _c.title;
                if (application_type !== 2) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                const bucketName = process.env.S3_BUCKET_NAME;
                const folderName = 'documents/';
                let originalDocumentValue = null;
                let translatedDocumentValue = null;
                let originalFile = null;
                let translatedFile = null;
                // Find the original and translated files based on field names
                for (const file of req.files) {
                    if (file.fieldname === 'document_file') {
                        originalFile = file;
                    }
                    else if (file.fieldname === 'translate_document') {
                        translatedFile = file;
                    }
                }
                if (originalFile && translatedFile) {
                    const uploadOriginalDocument = yield documentUploadToS3(originalFile.originalname, bucketName, folderName, originalFile.buffer);
                    const uploadTranslatedDocument = yield documentUploadToS3(translatedFile.originalname, bucketName, folderName, translatedFile.buffer);
                    if (!uploadOriginalDocument || !uploadTranslatedDocument) {
                        return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'UploadProperDocument', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                    }
                    originalDocumentValue = uploadOriginalDocument.data;
                    translatedDocumentValue = uploadTranslatedDocument.data;
                }
                else {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'BothDocumentsRequired', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                let insertDocument = yield models.Documents.create({
                    user_id: user_id,
                    title: title,
                    original_document: originalDocumentValue,
                    translate_document: translatedDocumentValue,
                    from_language_code: from_language_code,
                    to_language_code: to_language_code,
                    created_date: yield getEpoch(),
                });
                if (insertDocument) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_SUCCESS'], msg: 'DocumentUpload', code: responseCodes_1.HttpCodes.OK, data: insertDocument });
                }
                else {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
            }
            catch (error) {
                console.log(error, 'error.....');
                return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
            }
        });
    }
    //get  all documnets as per user
    GetDocuments(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const orderBy = 'sort_order';
                const order = 'ASC';
                const application_type = parseInt(req.query.application_type);
                if (application_type !== 2) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                const getDocumentData = yield models.Documents.findAll({
                    attributes: ['document_id', 'title', 'original_document', 'translate_document', 'from_language_code', 'to_language_code', 'created_date'],
                    where: { user_id: req.user },
                    raw: true,
                });
                if (getDocumentData.length > 0) {
                    const Documents = getDocumentData.map((doc) => ({
                        document_id: doc.document_id,
                        title: doc.title || '',
                        original_document: doc.original_document,
                        translate_document: doc.translate_document,
                        from_language_code: doc.from_language_code,
                        to_language_code: doc.to_language_code,
                        created_date: doc.created_date,
                    }));
                    return callback(null, { 'status': responseCodes_1.HttpCodes['API_SUCCESS'], 'msg': 'ListDocuments', code: responseCodes_1.HttpCodes['OK'], data: Documents });
                }
                else {
                    return callback(null, { 'status': responseCodes_1.HttpCodes['API_SUCCESS'], 'msg': 'NoDocumentFound', code: responseCodes_1.HttpCodes['OK'], data: [] });
                }
            }
            catch (err) {
                console.error('Error fetching advertisement data:', err);
                return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'ErrorFetchingData', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
            }
        });
    }
    //convert doc to pdf 
    DocToPdfConvert(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const docFile = req.file;
                if (!docFile || !docFile.buffer) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'Invalid file object or file buffer is missing.', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                // Validate the file type
                if (docFile.mimetype !== 'application/msword'
                    && docFile.mimetype !== 'application/vnd.openxmlformats-officedocument.wordprocessingml.document'
                    && docFile.mimetype !== 'application/wps-office.doc'
                    && docFile.mimetype !== 'application/docx') {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'Invalid file type. Only Word documents (.doc) are allowed.', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: {} });
                }
                const bucketName = process.env.S3_BUCKET_NAME;
                const folderName = 'documents/';
                const pdfFileName = docFile.originalname.replace(/\.[^/.]+$/, '') + '.pdf';
                const docBuffer = req.file.buffer; // Use req.file.buffer as the file buffer
                // const outputFilePath = path.join(__dirname, '');
                libre.convert(docBuffer, '.pdf', undefined, (err, result) => __awaiter(this, void 0, void 0, function* () {
                    if (err) {
                        console.error('Conversion error:', err);
                        return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'ConversionError', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: {} });
                    }
                    else {
                        // const uploadTranslatedDocument = await documentUploadToS3(pdfFileName, bucketName, folderName, result);
                        // if (!uploadTranslatedDocument) {
                        //     return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'UploadProperDocument', code: HttpCodes['BAD_REQUEST'], data: [] });
                        // }
                        // Send the binary response with the appropriate headers
                        return callback(null, {
                            status: responseCodes_1.HttpCodes['API_SUCCESS'], msg: 'DocumentUpload', code: responseCodes_1.HttpCodes.OK,
                            // data: uploadTranslatedDocument.data,
                            data: result
                            // headers: {
                            //     'Content-Type': 'application/pdf',
                            //     'Content-Disposition': 'inline; filename=output-sample.pdf', // Set the filename as needed
                            // },
                        });
                    }
                }));
            }
            catch (error) {
                console.log(error, 'error.....');
                return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: {} });
            }
        });
    }
    // delete document
    DeleteDocument(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const document_id = req.body.document_id;
                const user_id = req.body.user_id;
                const application_type = parseInt(req.body.application_type);
                // Check if application type is valid or not
                if (application_type !== 2) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                const getData = yield models.Documents.findOne({
                    where: { document_id: document_id }
                });
                if (!getData) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'documentDoesNotExist', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                const removeDocInfo = yield models.Documents.destroy({
                    where: { document_id: document_id }
                });
                if (removeDocInfo) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_SUCCESS'], msg: 'DocDeletedSuccessfully', code: responseCodes_1.HttpCodes.OK, data: [] });
                }
                else {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
            }
            catch (error) {
                console.log(error, 'error.....');
                return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
            }
        });
    }
}
exports.default = DocumentServices;
//# sourceMappingURL=document.services.js.map