"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const models = require('./../models/index');
const common_1 = __importDefault(require("../helpers/common"));
const responseCodes_1 = require("../helpers/responseCodes");
const bcrypt = require('bcrypt');
const { getEpoch, SendNotification, sendJunoNotificationIOS } = new common_1.default();
const db = require("../models/index");
const Op = db.Sequelize.Op;
const { Sequelize } = require('sequelize'); // Import Sequelize object
class FriendmasterService {
    constructor() {
        this.GetMyFriendMessage = this.GetMyFriendMessage.bind(this);
        this.GetAllFriendRequest = this.GetAllFriendRequest.bind(this);
        this.AcceptFriendRequest = this.AcceptFriendRequest.bind(this);
        this.RejectFriendRequest = this.RejectFriendRequest.bind(this);
        this.GetFriends = this.GetFriends.bind(this);
        this.SendFriendRequest = this.SendFriendRequest.bind(this);
        this.RemoveFriend = this.RemoveFriend.bind(this);
        this.GetFriendMessage = this.GetFriendMessage.bind(this);
        this.SendMessage = this.SendMessage.bind(this);
        this.RemoveFriendMessage = this.RemoveFriendMessage.bind(this);
    }
    //get my friend message 
    GetMyFriendMessage(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { search, offset } = req.query;
                const application_type = parseInt(req.query.application_type);
                let user_id = req.body.user_id;
                let offsetValue = parseInt(offset);
                if (isNaN(offsetValue)) {
                    offsetValue = 0;
                }
                if (application_type !== 2) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: responseCodes_1.HttpCodes['BAD_REQUEST'] });
                }
                const friendGroups = yield models.FriendGroup.findAll({
                    where: {
                        [Op.or]: [
                            {
                                member_id: {
                                    [Op.ne]: user_id
                                },
                            },
                            {
                                owner_id: {
                                    [Op.ne]: user_id
                                },
                            },
                        ],
                    },
                    attributes: ['friend_group_id', 'member_id', 'owner_id'],
                    include: [
                        {
                            model: models.User,
                            as: 'member',
                            attributes: ['user_id', 'user_name', 'profile_picture', 'language_code'],
                        },
                        {
                            model: models.User,
                            as: 'owner',
                            attributes: ['user_id', 'user_name', 'profile_picture', 'language_code'],
                        },
                        {
                            model: models.FriendMessage,
                            as: 'messages',
                            required: true,
                            attributes: [],
                        },
                    ],
                    // group: ['friend_group_id'],
                });
                const modifiedFriendDataWithGroup = friendGroups.map(friendData => {
                    var tmp = {};
                    if (friendData.member.user_id == user_id) {
                        tmp = friendData.owner.dataValues;
                        tmp['friend_group_id'] = friendData.friend_group_id;
                        return tmp;
                    }
                    else if (friendData.owner.user_id == user_id) {
                        tmp = friendData.member.dataValues;
                        tmp['friend_group_id'] = friendData.friend_group_id;
                        return tmp;
                    }
                }).filter(Boolean);
                if (modifiedFriendDataWithGroup.length > 0) {
                    modifiedFriendDataWithGroup['offsetValue'] = offsetValue;
                    return callback(null, { status: responseCodes_1.HttpCodes['API_SUCCESS'], msg: 'GetMyFriendMessage', code: responseCodes_1.HttpCodes['OK'], data: modifiedFriendDataWithGroup, offset: offsetValue, });
                }
                else {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_SUCCESS'], msg: 'NoFriendMessage', code: responseCodes_1.HttpCodes['OK'], data: [], offset: offsetValue, });
                }
            }
            catch (error) {
                console.log(error.message, "getMyFriendMessage");
                return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'GetMyFriendMessageFailed', code: responseCodes_1.HttpCodes['BAD_REQUEST'] });
            }
        });
    }
    // get all friend request
    GetAllFriendRequest(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const application_type = parseInt(req.query.application_type);
                let user_id = req.body.user_id;
                if (application_type !== 2) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: responseCodes_1.HttpCodes['BAD_REQUEST'] });
                }
                const getFriendRequest = yield models.FriendMaster.findAll({
                    where: { invite_to_id: user_id, is_invite_sent: 1, is_friend: null || 0 },
                });
                if (!getFriendRequest || getFriendRequest.length === 0) {
                    return callback(null, { 'status': responseCodes_1.HttpCodes['API_SUCCESS'], 'msg': 'NoDataFound', code: responseCodes_1.HttpCodes['OK'], data: [] });
                }
                const FriendRequestList = yield models.FriendMaster.findAll({
                    where: { invite_to_id: user_id, is_invite_sent: 1, is_friend: null || 0 },
                    include: [
                        {
                            model: models.User,
                            as: 'sender',
                            attributes: ['user_name', 'profile_picture', 'language_code'],
                        },
                    ],
                    order: [
                        ['created_date', 'DESC'],
                    ],
                });
                const modifiedFriendDataWithGroup = FriendRequestList.map(friendData => {
                    var _a, _b;
                    const mergedData = Object.assign(Object.assign({}, friendData === null || friendData === void 0 ? void 0 : friendData["dataValues"]), (_b = (_a = friendData === null || friendData === void 0 ? void 0 : friendData["dataValues"]) === null || _a === void 0 ? void 0 : _a['sender']) === null || _b === void 0 ? void 0 : _b["dataValues"]);
                    delete mergedData.sender;
                    return mergedData;
                });
                if (modifiedFriendDataWithGroup.length > 0) {
                    return callback(null, { 'status': responseCodes_1.HttpCodes['API_SUCCESS'], 'msg': 'FriendRequestList', code: responseCodes_1.HttpCodes['OK'], data: modifiedFriendDataWithGroup });
                }
                else {
                    return callback(null, { 'status': responseCodes_1.HttpCodes['API_SUCCESS'], 'msg': 'NoFriendMessage', code: responseCodes_1.HttpCodes['OK'], data: [] });
                }
            }
            catch (error) {
                console.log(error.message, "getMyFriendRequest");
                return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'GetMyFriendMessageFailed', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
            }
        });
    }
    //accept friend request 
    AcceptFriendRequest(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const application_type = parseInt(req.body.application_type);
                let invite_id = req.body.invite_id;
                let user_id = req.body.user_id;
                if (isNaN(application_type) || application_type !== 2) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                const getInviteData = yield models.FriendMaster.findOne({
                    where: { invite_id: invite_id },
                });
                if (getInviteData) {
                    const dbInvite_to_id = getInviteData.invite_to_id;
                    const dbInvite_from_id = getInviteData.invite_from_id;
                    let getSenderData = yield models.User.findOne({
                        where: { user_id: dbInvite_to_id },
                    });
                    let senderName = getSenderData.user_name;
                    let senderProfilePicture = getSenderData.profile_picture;
                    const senderProfile = senderProfilePicture ? senderProfilePicture : '';
                    let getReceiverData = yield models.User.findOne({
                        where: { user_id: dbInvite_from_id },
                    });
                    const fmUpdateData = yield models.FriendMaster.update({ is_invite_sent: 0, is_friend: 1, updated_date: yield getEpoch() }, { where: { invite_id: invite_id } });
                    if (fmUpdateData[0] !== 1) {
                        return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                    }
                    let friendGroupId;
                    const characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
                    const charactersLength = characters.length;
                    const groupNameLength = 12;
                    let randomString = '';
                    for (let i = 0; i < groupNameLength; i++) {
                        randomString += characters[Math.floor(Math.random() * charactersLength)];
                    }
                    const friend_group_name = randomString;
                    const group = yield models.FriendGroup.create({
                        friend_group_name: friend_group_name,
                        owner_id: dbInvite_from_id,
                        member_id: dbInvite_to_id,
                        created_date: yield getEpoch(),
                        updated_date: yield getEpoch(),
                    });
                    friendGroupId = group.friend_group_id;
                    const receiverDeviceType = getReceiverData.device_type_translate;
                    const receiverDeviceToken = getReceiverData.device_token_translate;
                    if (receiverDeviceToken) {
                        const message = `${senderName} accepted your friend request`;
                        const title = 'Notification';
                        const notificationType = 'friend_request_accept';
                        const payloadData = {
                            type: 'friend_request_accept',
                            message,
                            profile_picture: senderProfile,
                            language_code: getSenderData.language_code ? getSenderData.language_code : ''
                        };
                        const payload = JSON.stringify(payloadData);
                        let sendNotification = true;
                        if (receiverDeviceType === 1) {
                            // Send Android Notification
                            sendNotification = yield SendNotification(receiverDeviceToken, message, title, payload, notificationType);
                        }
                        else if (receiverDeviceType === 2) {
                            // Send iOS Notification
                            sendNotification = yield sendJunoNotificationIOS(receiverDeviceToken, message, title, payload);
                        }
                        else {
                            sendNotification = false;
                        }
                        if (sendNotification) {
                            return callback(null, { 'status': responseCodes_1.HttpCodes['API_SUCCESS'], 'msg': 'FriendRequestAccepted', code: responseCodes_1.HttpCodes['OK'], data: [] });
                        }
                        else {
                            return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                        }
                    }
                    else {
                        return callback(null, { 'status': responseCodes_1.HttpCodes['API_SUCCESS'], 'msg': 'FriendRequestAccepted', code: responseCodes_1.HttpCodes['OK'], data: [] });
                    }
                }
                else {
                    return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'InviteIdNotExist', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
            }
            catch (error) {
                console.log("error", error);
                return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
            }
        });
    }
    //reject friend request
    RejectFriendRequest(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const application_type = parseInt(req.body.application_type);
                let user_id = req.body.user_id;
                if (application_type !== 2) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: responseCodes_1.HttpCodes['BAD_REQUEST'] });
                }
                let invite_id = req.body.invite_id;
                const getInviteData = yield models.FriendMaster.findOne({
                    where: { invite_id: invite_id },
                });
                if (!getInviteData) {
                    return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'InviteIdNotExist', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                //Remove Friend
                const rejectFriend = yield models.FriendMaster.destroy({
                    where: { invite_id: invite_id },
                });
                if (rejectFriend) {
                    return callback(null, { 'status': responseCodes_1.HttpCodes['API_SUCCESS'], 'msg': 'RejectRequestList', code: responseCodes_1.HttpCodes['OK'], data: [] });
                }
                else {
                    return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
            }
            catch (error) {
                console.log(error.message, "reject");
                return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'RejectRequestFailed', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
            }
        });
    }
    //get friends
    GetFriends(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { offset } = req.query;
                const application_type = parseInt(req.query.application_type);
                let user_id = req.body.user_id;
                if (application_type !== 2) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: responseCodes_1.HttpCodes['BAD_REQUEST'] });
                }
                let offsetValue = parseInt(offset);
                if (isNaN(offsetValue)) {
                    offsetValue = 0;
                }
                const getFriendsData = yield models.FriendMaster.findAll({
                    include: [
                        {
                            model: models.User,
                            as: 'sender',
                            where: {
                                is_translate_app: 1,
                                status: 1,
                                is_verified: 1,
                                is_deleted: 1,
                            },
                            attributes: ['user_id', 'user_name', 'language_code', 'profile_picture', 'device_token_translate'],
                        },
                        {
                            model: models.User,
                            as: 'inviteTo',
                            where: {
                                is_translate_app: 1,
                                status: 1,
                                is_verified: 1,
                                is_deleted: 1,
                            },
                            attributes: ['user_id', 'user_name', 'language_code', 'profile_picture', 'device_token_translate']
                        },
                    ],
                    where: {
                        is_friend: 1,
                        [Op.or]: [
                            { invite_from_id: user_id },
                            { invite_to_id: user_id },
                        ],
                    },
                    limit: 10,
                    offset: offsetValue,
                    order: [['created_date', 'DESC']],
                });
                if (getFriendsData && getFriendsData.length > 0) {
                    let getFriendDataResponse = [];
                    for (let i = 0; i < getFriendsData.length; i++) {
                        const friendGroup = yield models.FriendGroup.findOne({
                            where: {
                                [Op.or]: [
                                    { owner_id: getFriendsData[i]['invite_from_id'], member_id: getFriendsData[i]['invite_to_id'] },
                                    { owner_id: getFriendsData[i]['invite_to_id'], member_id: getFriendsData[i]['invite_from_id'] }
                                ]
                            }
                        });
                        var userKey = (user_id == getFriendsData[i]['sender']['user_id'] ? 'inviteTo' : 'sender');
                        getFriendDataResponse.push({
                            invite_id: getFriendsData[i]['invite_id'],
                            user_id: getFriendsData[i][userKey]['user_id'] != null ? getFriendsData[i][userKey]['user_id'] : '',
                            user_name: getFriendsData[i][userKey]['user_name'] != null ? getFriendsData[i][userKey]['user_name'] : '',
                            // is_friend: getFriendsData[i]['is_friend'],
                            language_code: getFriendsData[i][userKey]['language_code'] != null ? getFriendsData[i][userKey]['language_code'] : '',
                            profile_picture: getFriendsData[i][userKey]['profile_picture'] != null ? getFriendsData[i][userKey]['profile_picture'] : '',
                            friendship_date: getFriendsData[i]['created_date'],
                            quickblox_id: getFriendsData[i][userKey]['quickblox_id'] != null ? getFriendsData[i][userKey]['quickblox_id'] : '',
                            device_token_translate: getFriendsData[i][userKey]['device_token_translate'] != null ? getFriendsData[i][userKey]['device_token_translate'] : '',
                            friend_group_id: friendGroup != null ? (friendGroup['friend_group_id'] != null ? friendGroup['friend_group_id'] : null) : null,
                        });
                    }
                    return callback(null, { 'status': responseCodes_1.HttpCodes['API_SUCCESS'], 'msg': 'FriendList', code: responseCodes_1.HttpCodes['OK'], data: getFriendDataResponse });
                }
                else {
                    if (!getFriendsData || getFriendsData.length === 0) {
                        return callback(null, { 'status': responseCodes_1.HttpCodes['API_SUCCESS'], 'msg': 'NoDataFound', code: responseCodes_1.HttpCodes['OK'], data: [] });
                    }
                }
            }
            catch (error) {
                console.log(error.message, "GetFriends");
                return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'FriendListFailed', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
            }
        });
    }
    //send friend request
    SendFriendRequest(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const application_type = parseInt(req.body.application_type);
                const user_id = req.body.user_id;
                if (application_type !== 2) {
                    return callback(null, { status: responseCodes_1.HttpCodes.API_FAILURE, msg: 'InvalidApplicationType', code: responseCodes_1.HttpCodes.BAD_REQUEST });
                }
                const invite_to_id = req.body.invite_to_id;
                const checkRequestExist = yield models.FriendMaster.findAll({
                    where: {
                        [models.Sequelize.Op.or]: [
                            {
                                invite_from_id: invite_to_id,
                                invite_to_id: user_id,
                            },
                            {
                                invite_from_id: user_id,
                                invite_to_id: invite_to_id,
                            },
                        ],
                    },
                });
                if (!checkRequestExist || checkRequestExist.length === 0) {
                    const senderData = yield models.User.findOne({
                        where: { user_id },
                    });
                    if (!senderData) {
                        return callback(null, { status: responseCodes_1.HttpCodes.API_FAILURE, msg: 'SenderDataNotFound', code: responseCodes_1.HttpCodes.BAD_REQUEST });
                    }
                    const senderName = senderData.user_name;
                    const senderProfilePicture = senderData.profile_picture;
                    const senderProfile = senderProfilePicture || '';
                    const receiverData = yield models.User.findOne({
                        where: { user_id: invite_to_id },
                    });
                    if (!receiverData) {
                        return callback(null, { status: responseCodes_1.HttpCodes.API_FAILURE, msg: 'InviteToReferenceNotExist', code: responseCodes_1.HttpCodes.BAD_REQUEST, data: [] });
                    }
                    const insert_invite_id = yield models.FriendMaster.create({
                        invite_from_id: user_id,
                        invite_to_id: invite_to_id,
                        is_invite_sent: 1,
                        is_friend: 0,
                        created_date: yield getEpoch(),
                        updated_date: yield getEpoch(),
                    });
                    if (!insert_invite_id) {
                        return callback(null, { status: responseCodes_1.HttpCodes.API_FAILURE, msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes.BAD_REQUEST, data: [] });
                    }
                    const receiverDeviceType = receiverData.device_type_translate;
                    const receiverDeviceToken = receiverData.device_token_translate;
                    if (receiverDeviceToken) {
                        const message = `${senderName} has sent you a friend request.`;
                        const title = 'Notification';
                        const notificationType = 'friend_request_sent';
                        const payloadData = {
                            type: 'friend_request_sent',
                            message,
                            invite_id: insert_invite_id,
                            profile_picture: senderProfile,
                            language_code: senderData.language_code ? senderData.language_code : ''
                        };
                        const payload = JSON.stringify(payloadData);
                        let sendNotification = true;
                        // Send Android Notification
                        if (receiverDeviceType === 1) {
                            // sendJunoNotificationAndroid(receiverDeviceToken, message, title, payload, notificationType); // Implement this function accordingly
                            sendNotification = yield SendNotification(receiverDeviceToken, message, title, payload, notificationType);
                        }
                        else if (receiverDeviceType === 2) {
                            sendNotification = yield sendJunoNotificationIOS(receiverDeviceToken, message, title, payload); // Implement this function accordingly
                        }
                        else {
                            sendNotification = false;
                        }
                        if (sendNotification) {
                            return callback(null, { 'status': responseCodes_1.HttpCodes['API_SUCCESS'], 'msg': 'RequestSent', code: responseCodes_1.HttpCodes['OK'], data: [] });
                        }
                        else {
                            return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                        }
                    }
                    return callback(null, { status: responseCodes_1.HttpCodes.API_SUCCESS, msg: 'RequestSent', code: responseCodes_1.HttpCodes.OK, data: [] });
                }
                else {
                    return callback(null, { status: responseCodes_1.HttpCodes.API_SUCCESS, msg: 'AlreadySentRequest', code: responseCodes_1.HttpCodes.OK, data: [] });
                }
            }
            catch (error) {
                console.log(error.message, "send friend req>>>>>>");
                return callback(null, { status: responseCodes_1.HttpCodes.API_FAILURE, msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes.BAD_REQUEST, data: [] });
            }
        });
    }
    //remove friend
    RemoveFriend(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const application_type = parseInt(req.body.application_type);
                let user_id = req.body.user_id;
                let invite_id = parseInt(req.body.invite_id);
                if (application_type !== 2) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: responseCodes_1.HttpCodes['BAD_REQUEST'] });
                }
                const getInviteData = yield models.FriendMaster.findOne({
                    where: { invite_id: invite_id },
                });
                if (!getInviteData) {
                    return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'InviteIdNotExist', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                const friendGroup = yield models.FriendGroup.findOne({
                    where: {
                        [Op.or]: [
                            { owner_id: getInviteData.invite_from_id, member_id: getInviteData.invite_to_id },
                            { owner_id: getInviteData.invite_to_id, member_id: getInviteData.invite_from_id },
                        ],
                    },
                });
                //Remove Friend
                const removeFriend = yield models.FriendMaster.destroy({
                    where: { invite_id: invite_id },
                });
                if (removeFriend) {
                    if (friendGroup) {
                        yield models.FriendMessage.destroy({
                            where: { friend_group_id: friendGroup.friend_group_id },
                        });
                        yield models.FriendGroup.destroy({
                            where: { friend_group_id: friendGroup.friend_group_id },
                        });
                    }
                    else {
                        console.log("frind group not found");
                    }
                    const getFriendRequest = yield models.FriendMaster.findAll({
                        where: { invite_to_id: user_id },
                    });
                    const friendRequest = [];
                    for (let i = 0; i < getFriendRequest.length; i++) {
                        const inviteFromId = getFriendRequest[i]['invite_from_id'];
                        const getSenderInfo = yield models.User.findAll({
                            where: { user_id: inviteFromId },
                        });
                        if (getSenderInfo && getSenderInfo.length > 0) {
                            const senderInfo = getSenderInfo[0];
                            friendRequest.push({
                                invite_id: getFriendRequest[i]['invite_id'],
                                invite_from_id: getFriendRequest[i]['invite_from_id'],
                                invite_to_id: getFriendRequest[i]['invite_to_id'],
                                is_invite_sent: getFriendRequest[i]['is_invite_sent'],
                                is_friend: getFriendRequest[i]['is_friend'],
                                sender_id: senderInfo['user_id'],
                                user_name: senderInfo['user_name'],
                                profile_picture: senderInfo['profile_picture'] || '',
                                language_code: senderInfo['language_code'] || '',
                            });
                        }
                    }
                    return callback(null, { 'status': responseCodes_1.HttpCodes['API_SUCCESS'], 'msg': 'RemoveFreindList', code: responseCodes_1.HttpCodes['OK'], data: friendRequest });
                }
                else {
                    return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
            }
            catch (error) {
                console.log(error.message, "removeFriend");
                return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'RemoveFriendFailed', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
            }
        });
    }
    //remove friend
    GetFriendMessage(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { search, offset } = req.query;
                const application_type = parseInt(req.query.application_type);
                let user_id = req.body.user_id;
                let friend_id = parseInt(req.query.friend_id);
                let offsetValue = parseInt(offset);
                if (isNaN(offsetValue)) {
                    offsetValue = 0;
                }
                if (isNaN(friend_id) || !Number.isInteger(friend_id)) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'InvalidFriendId', code: responseCodes_1.HttpCodes['BAD_REQUEST'] });
                }
                if (application_type !== 2) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: responseCodes_1.HttpCodes['BAD_REQUEST'] });
                }
                const getFriendMessages = yield models.FriendMessage.findAll({
                    attributes: [
                        'message',
                        'created_date',
                        'friend_group_id',
                        [Sequelize.col('FriendMessage.language_code'), 'msg_language_code'],
                        'receiver_message',
                        'receiver_language_code',
                        'friend_message_id',
                        'reply_message_id',
                        'friend_group_id',
                        'receiver_id'
                    ], where: {
                        [Op.and]: [
                            {
                                [Op.or]: [
                                    { sender_id: user_id, sender_deleted: 0 },
                                    { receiver_id: user_id, receiver_deleted: 0 }
                                ]
                            },
                            {
                                [Op.or]: [
                                    { sender_id: friend_id },
                                    { receiver_id: friend_id }
                                ]
                            }
                        ]
                    },
                    include: [
                        {
                            model: models.User,
                            as: 'sender',
                            attributes: ['user_id', 'profile_picture', 'user_name', 'language_code']
                        },
                        {
                            model: models.FriendMessage,
                            as: 'reply',
                            attributes: ['friend_message_id', 'message', 'created_date'],
                            include: [
                                {
                                    model: models.User,
                                    as: 'sender',
                                    attributes: ['user_id', 'profile_picture', 'user_name'],
                                    required: false
                                }
                            ],
                            required: false
                        }
                    ],
                    order: [['created_date', 'ASC']],
                    offset: offsetValue
                });
                if (getFriendMessages.length > 0) {
                    return callback(null, { status: responseCodes_1.HttpCodes.API_SUCCESS, msg: 'GetFriendMessage', code: responseCodes_1.HttpCodes.OK, data: getFriendMessages, offset: offsetValue });
                }
                else {
                    return callback(null, { status: responseCodes_1.HttpCodes.API_SUCCESS, msg: 'NoFriendMessage', code: responseCodes_1.HttpCodes.OK, data: [], offset: offsetValue });
                }
            }
            catch (error) {
                console.log(error.message, "getMyFriendMessage");
                return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'GetFriendMessageFailed', code: responseCodes_1.HttpCodes['BAD_REQUEST'] });
            }
        });
    }
    //get friend message
    SendMessage(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const application_type = parseInt(req.body.application_type);
                const sender_id = req.body.sender_id;
                const receiver_id = req.body.receiver_id;
                const message = req.body.message;
                const language_code = req.body.language_code;
                const receiver_message = req.body.receiver_message;
                const receiver_language_code = req.body.receiver_language_code;
                const reply_message_id = req.body.reply_message_id;
                if (isNaN(application_type) || application_type !== 2) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: {} });
                }
                const checkSenderExist = yield models.User.findOne({
                    where: { user_id: sender_id },
                });
                const checkReceiverExist = yield models.User.findOne({
                    where: { user_id: receiver_id },
                });
                if (!checkSenderExist) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SenderReferencenotExist', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: {} });
                }
                if (!checkReceiverExist) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'ReceiverReferencenotExist', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: {} });
                }
                const checkRequestExist = yield models.FriendMaster.findAll({
                    where: {
                        [Op.or]: [
                            { invite_from_id: sender_id, invite_to_id: receiver_id },
                            { invite_to_id: sender_id, invite_from_id: receiver_id },
                        ],
                        is_friend: 1
                    },
                });
                if (checkRequestExist.length === 0) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'ReceiverSenderNotFriends', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: {} });
                }
                const friendGroupData = yield models.FriendGroup.findAll({
                    where: {
                        [Op.or]: [
                            { owner_id: sender_id, member_id: receiver_id },
                            { member_id: sender_id, owner_id: receiver_id },
                        ]
                    },
                });
                let friendGroupId;
                const characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
                const charactersLength = characters.length;
                const groupNameLength = 12;
                let randomString = '';
                for (let i = 0; i < groupNameLength; i++) {
                    randomString += characters[Math.floor(Math.random() * charactersLength)];
                }
                const friend_group_name = randomString;
                if (friendGroupData.length > 0) {
                    friendGroupId = friendGroupData[0].friend_group_id;
                }
                else {
                    const group = yield models.FriendGroup.create({
                        friend_group_name: friend_group_name,
                        owner_id: sender_id,
                        member_id: receiver_id,
                        created_date: yield getEpoch(),
                        updated_date: yield getEpoch(),
                    });
                    friendGroupId = group.friend_group_id;
                }
                const insertFriendMessage = yield models.FriendMessage.create({
                    friend_group_id: friendGroupId,
                    sender_id: sender_id,
                    receiver_id: receiver_id,
                    message: message,
                    reply_message_id: reply_message_id || 0,
                    language_code: language_code,
                    receiver_message: receiver_message,
                    receiver_language_code: receiver_language_code,
                    created_date: yield getEpoch(),
                    updated_date: yield getEpoch(),
                });
                let getReceiverData = yield models.User.findOne({
                    where: { user_id: receiver_id },
                });
                let getSenderData = yield models.User.findOne({
                    where: { user_id: sender_id },
                });
                const replyInfo = reply_message_id
                    ? yield models.FriendMessage.findOne({
                        attributes: ['friend_message_id', 'message', 'created_date'],
                        where: { friend_message_id: reply_message_id },
                        include: [
                            {
                                model: models.User,
                                as: 'sender',
                                attributes: ['user_id', 'profile_picture', 'user_name', 'language_code'],
                                required: false
                            }
                        ]
                    })
                    : null;
                const senderInfo = {
                    profile_picture: getSenderData.profile_picture,
                    user_name: getSenderData.user_name,
                    language_code: getSenderData.language_code,
                    user_id: insertFriendMessage.sender_id,
                };
                let friend_message_obj = {
                    friend_message_id: 0,
                    friend_group_id: 0,
                    receiver_id: 0,
                    user_id: 0,
                    message: '',
                    msg_language_code: '',
                    receiver_message: '',
                    receiver_language_code: '',
                    created_date: null,
                    reply_message_id: 0,
                    sender: null,
                    reply: null // Initialize the reply object as null
                };
                friend_message_obj = {
                    friend_message_id: insertFriendMessage.friend_message_id,
                    friend_group_id: insertFriendMessage.friend_group_id,
                    receiver_id: insertFriendMessage.receiver_id,
                    user_id: insertFriendMessage.sender_id,
                    message: insertFriendMessage.message,
                    msg_language_code: insertFriendMessage.language_code,
                    receiver_message: insertFriendMessage.receiver_message,
                    receiver_language_code: insertFriendMessage.receiver_language_code,
                    created_date: yield getEpoch(),
                    reply_message_id: insertFriendMessage.reply_message_id,
                    sender: senderInfo,
                    reply: replyInfo
                };
                if (insertFriendMessage) {
                    let senderName = getSenderData.user_name;
                    let senderProfilePicture = getSenderData.profile_picture;
                    const senderProfile = senderProfilePicture ? senderProfilePicture : '';
                    const receiverDeviceType = getReceiverData.device_type_translate;
                    const receiverDeviceToken = getReceiverData.device_token_translate;
                    if (receiverDeviceToken) {
                        const message = `${senderName} has sent you a message`;
                        const title = 'Notification';
                        const notificationType = 'friend_chat';
                        const payloadData = {
                            type: 'friend_chat',
                            message,
                            friend_message_id: insertFriendMessage.friend_message_id,
                            user_id: insertFriendMessage.sender_id,
                            user_name: senderName,
                            profile_picture: senderProfile,
                            language_code: getSenderData.language_code ? getSenderData.language_code : ''
                        };
                        const payload = JSON.stringify(payloadData);
                        let sendNotification = true;
                        if (receiverDeviceType === 1) {
                            // Send Android Notification
                            sendNotification = yield SendNotification(receiverDeviceToken, message, title, payload, notificationType);
                        }
                        else if (receiverDeviceType === 2) {
                            // Send iOS Notification
                            sendNotification = yield sendJunoNotificationIOS(receiverDeviceToken, message, title, payload);
                        }
                        else {
                            sendNotification = false;
                        }
                        if (sendNotification) {
                            return callback(null, { 'status': responseCodes_1.HttpCodes['API_SUCCESS'], 'msg': 'MessageSent', code: responseCodes_1.HttpCodes['OK'], data: friend_message_obj });
                        }
                        else {
                            return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: {} });
                        }
                    }
                    else {
                        return callback(null, { 'status': responseCodes_1.HttpCodes['API_SUCCESS'], 'msg': 'MessageSent', code: responseCodes_1.HttpCodes['OK'], data: friend_message_obj });
                    }
                }
                else {
                    return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: {} });
                }
            }
            catch (error) {
                console.log("error", error);
                return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: {} });
            }
        });
    }
    //remove friend message 
    RemoveFriendMessage(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const application_type = parseInt(req.body.application_type);
                const user_id = req.body.user_id;
                const friend_group_id = req.body.friend_group_id;
                if (!friend_group_id) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'FriendGroupIdRequired', code: responseCodes_1.HttpCodes['BAD_REQUEST'] });
                }
                if (application_type !== 2) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: responseCodes_1.HttpCodes['BAD_REQUEST'] });
                }
                const getFriendGroupInfo = yield models.FriendMessage.findAll({
                    where: { friend_group_id: friend_group_id },
                });
                if (!getFriendGroupInfo || getFriendGroupInfo.length === 0) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'FriendGroupNotFound', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                const getFriendMessage = yield models.FriendMessage.findAll({
                    where: { friend_group_id: friend_group_id },
                });
                if (getFriendMessage) {
                    for (let i = 0; i < getFriendMessage.length; i++) {
                        const senderId = getFriendMessage[i]['sender_id'];
                        const receiverId = getFriendMessage[i]['receiver_id'];
                        const friendMessageId = getFriendMessage[i]['friend_message_id'];
                        // Update sender or receiver based on user_id
                        if (user_id === senderId || user_id === receiverId) {
                            const updateField = user_id === senderId ? 'sender_deleted' : 'receiver_deleted';
                            yield models.FriendMessage.update({ [updateField]: 1 }, { where: { 'friend_group_id': friend_group_id, [updateField === 'sender_deleted' ? 'sender_id' : 'receiver_id']: user_id } });
                            // Get updated message
                            const updatedMessage = yield models.FriendMessage.findOne({
                                where: { 'friend_message_id': friendMessageId },
                            });
                            // Check if both sender and receiver have deleted the message
                            if (updatedMessage.sender_deleted === 1 && updatedMessage.receiver_deleted === 1) {
                                yield models.FriendMessage.destroy({
                                    where: { 'friend_message_id': friendMessageId },
                                });
                            }
                        }
                    }
                    return callback(null, { 'status': responseCodes_1.HttpCodes['API_SUCCESS'], 'msg': 'MessagesRemoved', code: responseCodes_1.HttpCodes['OK'], data: [] });
                }
                else {
                    return callback(null, { 'status': responseCodes_1.HttpCodes['API_SUCCESS'], 'msg': 'NoDataFound', code: responseCodes_1.HttpCodes['OK'], data: [] });
                }
            }
            catch (error) {
                console.log(error.message, "removeFriendMessage");
                return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
            }
        });
    }
}
exports.default = FriendmasterService;
//# sourceMappingURL=friendmaster.services.js.map