"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const models = require('./../models/index');
const common_1 = __importDefault(require("../helpers/common"));
const responseCodes_1 = require("../helpers/responseCodes");
const ejs = require('ejs');
const fs = require('fs');
const bcrypt = require('bcrypt');
const { getEpoch, ComparePassword, UpdateUserFields, fileUploadToS3, deleteImageFromS3, pushEmail } = new common_1.default();
const db = require("../models/index");
const Op = db.Sequelize.Op;
class PreferenceService {
    constructor() {
        this.UpdateRegion = this.UpdateRegion.bind(this);
        this.UpdateLanguageCode = this.UpdateLanguageCode.bind(this);
        this.TransferOwnership = this.TransferOwnership.bind(this);
        this.UpdateEmail = this.UpdateEmail.bind(this);
        this.UpdatePassword = this.UpdatePassword.bind(this);
        this.UpdateName = this.UpdateName.bind(this);
        this.DeleteProfile = this.DeleteProfile.bind(this);
        this.UpdateVoicePreference = this.UpdateVoicePreference.bind(this);
        this.UpdateProfilePicture = this.UpdateProfilePicture.bind(this);
    }
    //update region
    UpdateRegion(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                let user_id = req.body.user_id;
                let region = req.body.region;
                let application_type = parseInt(req.body.application_type);
                if (application_type > 2 || application_type <= 0) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                const updatedUser = yield models.User.update({ region: region }, {
                    where: {
                        user_id: user_id,
                    },
                });
                if (updatedUser[0] === 0) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'UpdateRegionFailed', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                return callback(null, { 'status': responseCodes_1.HttpCodes['API_SUCCESS'], 'msg': 'RegionUpdatedSuccess', code: responseCodes_1.HttpCodes['OK'], data: [] });
            }
            catch (error) {
                console.log(error.message, "UpdateRegion");
                return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'UpdateRegionFailed', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
            }
        });
    }
    //update language code
    UpdateLanguageCode(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                let user_id = req.body.user_id;
                let language_code = req.body.language_code;
                let application_type = parseInt(req.body.application_type);
                if (application_type > 2 || application_type <= 0) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                // Update user data
                const updatedUser = yield models.User.update({ language_code: language_code }, {
                    where: {
                        user_id: user_id,
                    },
                });
                if (updatedUser[0] === 0) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'UpdateLanguageCodeFailed', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                return callback(null, { 'status': responseCodes_1.HttpCodes['API_SUCCESS'], 'msg': 'LanguageCodeUpdated', code: responseCodes_1.HttpCodes['OK'], data: [] });
            }
            catch (error) {
                console.log(error.message, "UpdateLanguage");
                return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'UpdateLanguageCodeFailed', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
            }
        });
    }
    // transfer ownership for device
    TransferOwnership(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                let user_email = req.body.email.toLowerCase();
                let user_id = req.body.user_id;
                let application_type = parseInt(req.body.application_type);
                if (application_type > 2 || application_type <= 0) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                // Check if the user is registered as a premium member
                const checkRegistereAsPremium = yield models.User.findOne({
                    where: {
                        user_id: user_id,
                        subscription_plan: 'register_as_premium'
                    }
                });
                if (!checkRegistereAsPremium) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'NotPremiumMember', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                const checkDeviceRegister = yield models.DeviceRegister.findOne({
                    where: {
                        user_id: user_id
                    }
                });
                if (!checkDeviceRegister) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'deviceNotRegistered', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                const checkUserFromEmail = yield models.User.findOne({
                    where: {
                        user_email: user_email,
                    }
                });
                if (!checkUserFromEmail) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'EmailAddressNotFound', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                const owner_subscription_plan = checkRegistereAsPremium.subscription_plan;
                const owner_subscription_plan_device_type = checkRegistereAsPremium.subscription_plan_device_type;
                const owner_subscribed_on = checkRegistereAsPremium.subscribed_on;
                const owner_email = checkRegistereAsPremium.user_email.toLowerCase();
                const passedEmail = user_email.toLowerCase();
                if (passedEmail === owner_email) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'CantTransferOwnershipToself', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                // Check if the user to whom ownership is being transferred is already a premium member
                const transferOwnerSubscriptionPlan = checkUserFromEmail.subscription_plan;
                if (transferOwnerSubscriptionPlan === 'register_as_premium') {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'AlreadyPremiumMember', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                const transferOwnershipUserId = checkUserFromEmail.user_id;
                // Update device register master entry
                const updateDRMArray = yield models.DeviceRegister.update({ email_address: user_email }, {
                    where: {
                        user_id: transferOwnershipUserId,
                    },
                });
                const updateTransferUserOwnerWhereArray = yield models.User.update({
                    subscription_plan: owner_subscription_plan,
                    subscription_plan_device_type: owner_subscription_plan_device_type,
                    subscribed_on: owner_subscribed_on,
                    is_login_translate: null,
                    login_access_token_translate: null,
                    device_token_translate: null,
                }, {
                    where: {
                        user_id: transferOwnershipUserId,
                    },
                });
                const updateOwnerArray = yield models.User.update({ subscription_plan: 'free' }, {
                    where: {
                        user_id: transferOwnershipUserId,
                    },
                });
                const addTransferOwnershipLog = yield models.TransferOwnership.create({ user_id: user_id, transfer_to_user_id: transferOwnershipUserId, created_date: yield getEpoch(), updated_date: yield getEpoch() });
                if (addTransferOwnershipLog) {
                    const getUpdatedRecord = yield models.User.findOne({
                        where: {
                            user_email: user_email,
                        }
                    });
                    return callback(null, { 'status': responseCodes_1.HttpCodes['API_SUCCESS'], 'msg': 'transferOwnershipupdated', code: responseCodes_1.HttpCodes['OK'], data: getUpdatedRecord });
                }
                else {
                    return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
            }
            catch (error) {
                console.log(error.message, "transferOwnership");
                return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'transferOwnershipFailed', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
            }
        });
    }
    //update email
    UpdateEmail(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const user_id = req.body.user_id;
                const user_email = req.body.email;
                const application_type = parseInt(req.body.application_type);
                if (application_type > 2 || application_type <= 0) {
                    return callback(null, {
                        status: responseCodes_1.HttpCodes['API_FAILURE'],
                        msg: 'Invalidapplicationtype',
                        code: responseCodes_1.HttpCodes['BAD_REQUEST'],
                        data: []
                    });
                }
                const get_userdata = yield models.User.findOne({
                    where: {
                        user_id: user_id,
                    }
                });
                const db_user_email = get_userdata.user_email;
                if (user_email !== db_user_email) {
                    const checkEmailExist = yield models.User.findOne({
                        where: {
                            user_email: user_email,
                        }
                    });
                    if (checkEmailExist) {
                        return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'EmailAlreadyExists', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                    }
                    else {
                        const updates = { user_email: user_email, is_verified: 0 };
                        const updatedUser = yield UpdateUserFields(user_id, updates, application_type);
                        if (updatedUser) {
                            const activation_key = updatedUser.activation_key;
                            const user_name = updatedUser.user_name;
                            const base_url = (process.env.NODE_ENV === 'local') ? 'http://localhost:6012' : 'https://' + process.env.HOST;
                            // Start: Registration Mail content Here
                            const mailData = {
                                user_name: user_name,
                                activation_key: activation_key,
                                baseUrl: base_url,
                            };
                            const templatePath = './views/emailTemplate.ejs';
                            // Read the EJS template file
                            const template = fs.readFileSync(templatePath, 'utf8');
                            const subject = 'Please confirm your email address';
                            try {
                                yield pushEmail(mailData, user_email, subject, template);
                                // Email sent successfully
                                return callback(null, { status: responseCodes_1.HttpCodes.API_SUCCESS, msg: 'EmailUpdated', code: responseCodes_1.HttpCodes.OK, data: [] });
                            }
                            catch (error) {
                                // Error sending email
                                return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'Somethingwentwrong', code: responseCodes_1.HttpCodes.OK, data: [] });
                            }
                        }
                    }
                }
                else {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'SameEmailaddress', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
            }
            catch (error) {
                console.log(error.message, "UpdateEmail");
                return callback(null, {
                    status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'UpdateEmailFailed', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: []
                });
            }
        });
    }
    //update password
    UpdatePassword(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                let user_id = req.body.user_id;
                let old_password = req.body.old_password;
                let user_password = req.body.password;
                let application_type = parseInt(req.body.application_type);
                if (application_type > 2 || application_type <= 0) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                // Check if the user_id exists
                const user = yield models.User.findOne({
                    where: {
                        user_id: user_id,
                    },
                });
                if (!user) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'UserIdNotExist', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                const passwordMatch = yield ComparePassword(old_password, user.user_password);
                if (!passwordMatch) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'passwordNotMatch', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                else {
                    const salt = yield bcrypt.genSalt(10);
                    const hashedPassword = yield bcrypt.hash(user_password, salt);
                    const update_email_result = yield models.User.update({ user_password: hashedPassword }, {
                        where: {
                            user_id: user_id,
                        },
                    });
                    if (update_email_result[0] == 1) {
                        return callback(null, { status: responseCodes_1.HttpCodes['API_SUCCESS'], msg: 'passwordUpdated', code: responseCodes_1.HttpCodes.OK, data: [] });
                    }
                    else {
                        return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'UpdatePasswordFailed', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                    }
                }
            }
            catch (error) {
                console.log(error.message, "UpdatePassword");
                return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'UpdatePasswordFailed', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
            }
        });
    }
    //update name
    UpdateName(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                let user_id = req.body.user_id;
                let user_name = req.body.name;
                let title = req.body.title;
                let application_type = parseInt(req.body.application_type);
                if (application_type > 2 || application_type <= 0) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                const updates = { user_name: user_name, title: title };
                const updatedUser = yield UpdateUserFields(user_id, updates, application_type);
                if (updatedUser) {
                    return callback(null, { status: responseCodes_1.HttpCodes.API_SUCCESS, msg: 'NameUpdated', code: responseCodes_1.HttpCodes.OK, data: [] });
                }
                else {
                    return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
            }
            catch (error) {
                console.log(error.message, "UpdateName");
                return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'UpdateNameFailed', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
            }
        });
    }
    //delete profile 
    DeleteProfile(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                let user_id = req.body.user_id;
                let application_type = parseInt(req.body.application_type);
                if (application_type > 2 || application_type <= 0) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                const updateUserDataArray = {
                    is_login_translate: null,
                    login_access_token_translate: null,
                    device_token_translate: null,
                    is_deleted_translate: 1
                };
                const user = yield models.User.findOne({
                    where: {
                        user_id: user_id,
                        is_deleted_translate: 1
                    },
                });
                if (user) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'AccountAlreadydeleted', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                // Update the user's data
                yield models.User.update(updateUserDataArray, { where: { user_id } });
                return callback(null, { status: responseCodes_1.HttpCodes.API_SUCCESS, msg: 'ProfileDeleted', code: responseCodes_1.HttpCodes.OK, data: [] });
            }
            catch (error) {
                console.log(error.message, "UpdateName");
                return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'ProfileDeleteFailed', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
            }
        });
    }
    //update voice preference
    UpdateVoicePreference(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                let user_id = req.body.user_id;
                let application_type = parseInt(req.body.application_type);
                const voice_preference = req.body.voice_preference;
                if (application_type > 2 || application_type <= 0) {
                    return callback(null, { status: responseCodes_1.HttpCodes.API_FAILURE, msg: 'InvalidApplicationType', code: responseCodes_1.HttpCodes.BAD_REQUEST, data: [] });
                }
                const voiceArray = ['Male', 'Female', 'male', 'female', 'Default', 'default'];
                if (!voiceArray.includes(voice_preference)) {
                    return callback(null, { status: responseCodes_1.HttpCodes.API_FAILURE, msg: 'InvalidVoicePreference', code: responseCodes_1.HttpCodes.BAD_REQUEST, data: [] });
                }
                // Update user voice preference
                const updateData = { voice_preference: voice_preference.toLowerCase() };
                const updatedUser = yield models.User.update(updateData, {
                    where: { user_id }
                });
                if (updatedUser[0] === 1) {
                    return callback(null, {
                        status: responseCodes_1.HttpCodes.API_SUCCESS, msg: 'VoicePreferenceUpdated', code: responseCodes_1.HttpCodes.OK, data: []
                    });
                }
                else {
                    return callback(null, {
                        status: responseCodes_1.HttpCodes.API_FAILURE, msg: 'UpdateVoicePreferenceFailed', code: responseCodes_1.HttpCodes.BAD_REQUEST, data: []
                    });
                }
            }
            catch (error) {
                console.log(error.message, "UpdateVoicePreference");
                return callback(null, {
                    status: responseCodes_1.HttpCodes.API_FAILURE, msg: 'UpdateVoicePreferenceFailed', code: responseCodes_1.HttpCodes.BAD_REQUEST, data: []
                });
            }
        });
    }
    //update profile picture
    UpdateProfilePicture(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                var user_id = req.user;
                console.log(user_id, "user_id");
                const application_type = parseInt(req.body.application_type);
                if (application_type > 2 || application_type <= 0) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                if (!req.file) {
                    return { status: false, msg: 'Please upload user profile picture', data: [] };
                }
                const bucketName = process.env.S3_BUCKET_NAME;
                const folderName = 'profile_pictures/';
                const fileName = `${Date.now()}_${req.file.originalname}`;
                // Upload the file to S3
                const fileBuffer = req.file.buffer;
                const s3UploadResult = yield fileUploadToS3(fileName, bucketName, folderName, fileBuffer);
                if (s3UploadResult.status == true) {
                    const user_profile_picture = s3UploadResult.data;
                    const userData = yield models.User.findOne({
                        where: {
                            user_id: user_id,
                        },
                    });
                    if (userData && userData.profile_picture) {
                        const urlParts = userData.profile_picture.split('/');
                        const objectKey = urlParts[urlParts.length - 1];
                        yield deleteImageFromS3(bucketName, `profile_pictures/${objectKey}`);
                    }
                    const updatedProfile = yield models.User.update({ profile_picture: user_profile_picture }, {
                        where: {
                            user_id: user_id,
                        },
                    });
                    if (updatedProfile[0] == 1) {
                        return callback(null, { 'status': responseCodes_1.HttpCodes['API_SUCCESS'], 'msg': 'profilePictureUpdated', code: responseCodes_1.HttpCodes['OK'], data: s3UploadResult });
                    }
                    else {
                        return callback(null, { status: responseCodes_1.HttpCodes.API_FAILURE, msg: 'FailedtoUpdate', code: responseCodes_1.HttpCodes.BAD_REQUEST, data: [] });
                    }
                }
                else {
                    return callback(null, { status: responseCodes_1.HttpCodes.API_FAILURE, msg: 'FailedtoUpload', code: responseCodes_1.HttpCodes.BAD_REQUEST, data: [] });
                }
            }
            catch (error) {
                console.error('Error:', error);
                return callback(null, { status: responseCodes_1.HttpCodes.API_FAILURE, msg: 'SomeThingWentWrong', code: responseCodes_1.HttpCodes.BAD_REQUEST, data: [] });
            }
        });
    }
    ;
}
exports.default = PreferenceService;
//# sourceMappingURL=preference.services.js.map