"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const models = require('./../models/index');
const common_1 = __importDefault(require("../helpers/common"));
const responseCodes_1 = require("../helpers/responseCodes");
const bcrypt = require('bcrypt');
const { getEpoch, GetUserDataTranslate } = new common_1.default();
const db = require("../models/index");
const Op = db.Sequelize.Op;
class SubscriptionService {
    constructor() {
        this.AddSubscriptionPlan = this.AddSubscriptionPlan.bind(this);
        this.GetServices = this.GetServices.bind(this);
        this.GetServiceFeatures = this.GetServiceFeatures.bind(this);
    }
    //add subscription plan
    AddSubscriptionPlan(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                let user_id = req.body.user_id;
                let subscription_plan_device_type = req.body.subscription_plan_device_type;
                let subscription_plan = req.body.subscription_plan;
                let application_type = parseInt(req.body.application_type);
                if (application_type !== 2) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                const userData = yield GetUserDataTranslate(user_id);
                // Update subscription plan if needed
                if (userData.subscription_plan !== 'register_as_premium') {
                    const updateData = {
                        subscription_plan: subscription_plan.toLowerCase(),
                        subscription_plan_device_type: subscription_plan_device_type.toLowerCase(),
                        subscribed_on: yield getEpoch(),
                        updated_date: yield getEpoch()
                    };
                    const result = yield models.User.update(updateData, {
                        where: {
                            user_id: user_id,
                        },
                    });
                    if (result[0] !== 1) {
                        return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'SomeThingWentWrong', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                    }
                    else {
                        return callback(null, { 'status': responseCodes_1.HttpCodes['API_SUCCESS'], 'msg': 'subscriptionSuccess', code: responseCodes_1.HttpCodes['OK'], data: [] });
                    }
                }
            }
            catch (error) {
                console.log(error.message, "Register");
                return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'subscriptionFailed', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
            }
        });
    }
    //get services
    GetServices(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const orderBy = 'created_date';
                const order = 'ASC';
                const application_type = parseInt(req.query.application_type);
                const user_id = req.body.user_id;
                if (isNaN(application_type) || application_type !== 2) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                const filter = {
                    where: { service_status: 1 },
                    order: [[orderBy, order]],
                };
                const getServiceData = yield models.Services.findAll(filter);
                if (getServiceData.length === 0) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_SUCCESS'], msg: 'NoServicesFound', code: responseCodes_1.HttpCodes['OK'], data: [] });
                }
                return callback(null, { status: responseCodes_1.HttpCodes['API_SUCCESS'], msg: 'ListDeviceServices', code: responseCodes_1.HttpCodes['OK'], data: getServiceData });
            }
            catch (err) {
                console.error('Error fetching device services data:', err);
                return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'ErrorFetchingData', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
            }
        });
    }
    //get service features
    GetServiceFeatures(req, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const orderBy = 'created_date';
                const order = 'ASC';
                const application_type = parseInt(req.query.application_type);
                const user_id = req.body.user_id;
                if (isNaN(application_type) || application_type !== 2) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
                }
                const features = yield models.ServiceFeature.findAll();
                if (!features || features.length === 0) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_SUCCESS'], msg: 'NoServicesFeatureFound', code: responseCodes_1.HttpCodes['OK'], data: [] });
                }
                const services = yield models.Services.findAll({
                    where: { service_status: 1 },
                    include: [
                        {
                            model: models.ServiceFeature,
                            as: 'Features',
                            attributes: ['feature'],
                        },
                    ],
                    order: [[orderBy, order]],
                });
                if (!services || services.length === 0) {
                    return callback(null, { status: responseCodes_1.HttpCodes['API_SUCCESS'], msg: 'NoServicesFound', code: responseCodes_1.HttpCodes['OK'], data: [] });
                }
                const featureData = [];
                features.forEach(feature => {
                    const featureItem = {
                        feature_name: feature.feature,
                    };
                    services.forEach(service => {
                        featureItem[service.service_title] = service.Features.some(feat => feat.feature === feature.feature)
                            ? 1
                            : 0;
                    });
                    featureData.push(featureItem);
                });
                return callback(null, { status: responseCodes_1.HttpCodes['API_SUCCESS'], msg: 'ListFeatures', code: responseCodes_1.HttpCodes['OK'], data: featureData });
            }
            catch (err) {
                console.error('Error fetching device services data:', err);
                return callback(null, { 'status': responseCodes_1.HttpCodes['API_FAILURE'], 'msg': 'ErrorFetchingData', code: responseCodes_1.HttpCodes['BAD_REQUEST'], data: [] });
            }
        });
    }
}
exports.default = SubscriptionService;
//# sourceMappingURL=subscription.services.js.map