import crypto from 'crypto';
import { validationResult } from 'express-validator';
import { HttpCodes } from './responseCodes';
import axios from 'axios';
const bcrypt = require('bcrypt');
const jwt = require('jsonwebtoken');
const models = require('./../models/index');
const { S3Client, PutObjectCommand, DeleteObjectCommand, ListObjectsV2Command } = require('@aws-sdk/client-s3');
const fs = require('fs');
const QRCode = require('qrcode');
const nodemailer = require("nodemailer");
const ejs = require('ejs');
// Define the path to the EJS template
const templatePath = './views/emailTemplate.ejs';
// Read the EJS template file
const template = fs.readFileSync(templatePath, 'utf8');

// Create a Nodemailer transporter using SMTP
const transporter = nodemailer.createTransport({
  host: "email-smtp.eu-west-1.amazonaws.com",
  port: 465 ,
  secure: true, // Set to false if your SMTP server doesn't require TLS/SSL
  auth: {
    user: "AKIA6GV74OWQ2USXHV4R",
    pass: "BIZA1gZQAkXS79p2Ht9mhD1k0KqyajNaR0yeuNDQz8uG",
  },
});

const s3Client = new S3Client({
  region: process.env.S3_BUCKET_REGION,
  credentials: {
    accessKeyId: process.env.S3_BUCKET_KEY,
    secretAccessKey: process.env.S3_BUCKET_SECRET,
  },
});

export default class autorizationController {
  constructor() {
    this.getEpoch = this.getEpoch.bind(this);
    this.validateApiKey = this.validateApiKey.bind(this);
    this.commonResponse = this.commonResponse.bind(this);
    this.GetPagination = this.GetPagination.bind(this);
    this.CheckValidationError = this.CheckValidationError.bind(this);
    this.CheckValidationErrorArray = this.CheckValidationErrorArray.bind(this);
    this.ComparePassword = this.ComparePassword.bind(this);
    this.CreateJwt = this.CreateJwt.bind(this);
    this.VerifyJwt = this.VerifyJwt.bind(this);
    this.VerifyJwtAdminAccount = this.VerifyJwtAdminAccount.bind(this);
    this.generateRandomString = this.generateRandomString.bind(this);
    this.VerifyAccountActive = this.VerifyAccountActive.bind(this);
    this.UpdateUserFields = this.UpdateUserFields.bind(this);
    this.GetUserDataTranslate = this.GetUserDataTranslate.bind(this);
    this.GenerateQR = this.GenerateQR.bind(this);
    this.SendNotification = this.SendNotification.bind(this);
    this.deleteImageFromS3 = this.deleteImageFromS3.bind(this);
    this.pushEmail = this.pushEmail.bind(this);
    this.getUserData = this.getUserData.bind(this);
    this.addEmailSendInBlue = this.addEmailSendInBlue.bind(this);
    this.writeCsvFile = this.writeCsvFile.bind(this);
    this.appVersionCheck = this.appVersionCheck.bind(this);
  }

  async getEpoch() {
    return Math.floor(Date.now() / 1000);
  }

  async GetPagination(limitValue, skipValue) {
    let limit = limitValue ? parseInt(limitValue) : 10;
    let skip = 0;
    if (skipValue && skipValue != -1) {
      skip = (parseInt(skipValue) * limit);
    } else if (skipValue == -1) {
      skip = -1;
    }
    return { limit, skip };
  }

  async commonResponse(res, error, result,req=null) {
    const userLang = req?.headers?.lang || 'en';
    req.setLocale(userLang);
    if (error) {
      res.status(200).json({ status: false, message: res.__("api.errors.SomethingWrong"), code: HttpCodes['BAD_REQUEST'], data: error, total: 0, host:result.host });
    } else {
      if (result && result.status === "false") {
        if (result.flag === 1) {
          res.status(200).json({status:false,message:`${res.__(`api.errors.${result.msg}`)}:${result.name}`,code:result.code,data:result.data,total:result?.total});
        } else {
          res.status(200).json({status:false,message:res.__(`api.errors.${result.msg}`),code:result.code,data:result.data,total:result?.total});
        }
      } else {
        res.status(200).json({ status: true, message: res.__(`api.msg.${result.msg}`), code: result.code, data: result.data, dropDownData: result?.dropDownData, total: result?.total, offset: result.offset,host:result.host });
      }
    }
  }

  // API Authorization
  async validateApiKey(req, res, next) {
    let privateKey = process.env.APIPRIVATEKEY;
    let secretKey = process.env.APISECRETKEY;
    let haskKey = process.env.HASHKEY
    let nonce = req.headers['nonce'];
    let timestamp = req.headers['timestamp'];
    let access_token = req.headers['token'];
    let hmac = crypto.createHmac(haskKey, privateKey);
    let signed = hmac.update(secretKey + timestamp + nonce).digest("hex");
    if (!access_token || !nonce || !timestamp) {
      return res.status(200).json({ message: res.__('api.errors.UnAuthorizedRequest'), code: HttpCodes['UNAUTHORIZED'] });
    }
    else if (access_token != signed) {
      return res.status(200).json({ message: res.__('api.errors.UnAuthorizedRequest'), code: HttpCodes['UNAUTHORIZED'] });
    }
    else {
      next();
    }
  }

  async CheckValidationError(req, res, next) {
    const errors = validationResult(req);
    if (!errors.isEmpty()) {
      return res.status(200).json({ status: false, message: res.__(`api.errors.${errors.array()[0].msg}`), code: HttpCodes['CONTENT_NOT_FOUND'], data: {} });
    } else {
      next();
    }
  }

  async CheckValidationErrorArray(req, res, next) {
    const errors = validationResult(req);
    if (!errors.isEmpty()) {
      return res.status(200).json({ status: false, message: res.__(`api.errors.${errors.array()[0].msg}`), code: HttpCodes['CONTENT_NOT_FOUND'], data: [] });
    } else {
      next();
    }
  }


  async ComparePassword(newPassword, oldPassword) {
    const passwordCompare = await bcrypt.compare(newPassword, oldPassword);
    return passwordCompare;
  }

  async CreateJwt(data) {
    const expiresIn = '24h'; // Token will expire in 2 seconds
    const newToken = jwt.sign(data, process.env.JWTSECRET);
    return newToken;
  }


  async VerifyJwtAdminAccount(req, res, next) {
    try {
      const token = req.headers['authorization'];
      if (!token && token === null && token === undefined) {
        return res.status(200).json({ message: res.__("api.errors.TokenNotProvided"), code: HttpCodes['UNAUTHORIZED'] });
      }
      const decoded = jwt.verify(token, process.env.JWTSECRET);
      if (decoded) {
        req['body']['currentUserId'] = decoded['admin_id'];
        const admin = await models.Admin.findOne({ admin_id: decoded['admin_id'] });
        if (admin && admin !== null && admin !== undefined) {
          if (admin.role_id === 1) {
            return next();
          } else {
            return res.status(200).json({message:res.__("api.errors.NotAdminAccount"),code:HttpCodes['UNAUTHORIZED']});
          }
        } else {
          return res.status(200).json({message:res.__("api.errors.InvalidToken"),code:HttpCodes['UNAUTHORIZED']});
        }
      } else {
        return res.status(200).json({message:res.__("api.errors.InvalidToken"),code:HttpCodes['UNAUTHORIZED']});
      }
    } catch (error) {
      console.log(error.message, "VerifyJwt");
      return res.status(200).json({message:res.__("api.errors.InvalidToken"),code:HttpCodes['UNAUTHORIZED']});
    }
  }

  async VerifyJwt(req, res, next) {
    try {
      const authHeader = req.headers.authorization;
      const token = authHeader && authHeader.split(" ")[1];
      const deviceToken = req.headers.device_token;
      const application_type = parseInt(req.headers.application_type || 2);
      if (!token && token === null && token === undefined) {
        return res.status(200).json({ message: res.__("api.errors.TokenNotProvided"), code: HttpCodes['UNAUTHORIZED'] });
      }
      const decoded = await jwt.verify(token, process.env.JWTSECRET);
      if (decoded) {
        req['body']['currentUserId'] = decoded['user_id'];
        req.body.user_id = decoded.user_id;
        req['user'] = decoded.user_id;
        if (deviceToken) {
          const user_id = decoded.user_id;
          const updateResult = await this.UpdateDeviceToken(user_id, deviceToken, application_type);
          if (updateResult.status === HttpCodes['API_SUCCESS']) {
            console.log("token updated successfully")
          } else {
            console.log("errro while updating token")
          }
        }
        return next();
      } else {
        return res.status(200).json({message:res.__("api.errors.InvalidToken"),code:HttpCodes['UNAUTHORIZED']});
      }
    } catch (error) {
      console.log(error.message, "VerifyJwt");
      return res.status(200).json({message:res.__("api.errors.InvalidToken"),code:HttpCodes['UNAUTHORIZED']});
    }
  }

  async VerifyAccountActive(req, res, next) {
    try {
      const authHeader = req.headers.authorization;
      const login_access_token = authHeader && authHeader.split(" ")[1];
      let user = await models.User.findOne({ where: { user_id: req.body.user_id } });
      if (!user) {
        return res.status(200).json({message:res.__("UserIdNotExist"),code:HttpCodes['UNAUTHORIZED']});
      }
      if ((user.login_access_token_translate || user.login_access_token) !== login_access_token) {
        console.log("errorr????",(user.login_access_token_translate || user.login_access_token) !== login_access_token)
        return res.status(200).json({message:res.__("AccountActiveError"),code:HttpCodes['UNAUTHORIZED']});
      }
      return next();
    } catch (error) {
      console.log(error.message, "VerifyJwt");
      return res.status(200).json({message:res.__("api.errors.InvalidToken"),code:HttpCodes['UNAUTHORIZED']});
    }
  }

  async generateRandomString(length) {
    const characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
    const charactersLength = characters.length;
    let randomString = '';
    for (let i = 0; i < length; i++) {
      const randomIndex = Math.floor(Math.random() * charactersLength);
      randomString += characters.charAt(randomIndex);
    }
    return randomString;
  }

  // Define the common function for updating user fields
  async UpdateUserFields(user_id, updates, application_type) {
    const update_result = await models.User.update(updates, {
      where: {
        user_id: user_id,
      },
    });
    if (update_result[0] > 0) {
      let selectedFields;
      if (application_type === 1) {
        selectedFields=['user_id','user_name','user_email','user_login_type','title','facebook_id','google_plus_id','twitter_id','activation_key','is_verified','is_mymanuplay_app','push_notification','device_token','device_type','is_deleted','status','is_login','login_access_token','created_date','updated_date'];
      } else if (application_type === 2) {
        selectedFields=['user_id','user_name','user_email','user_login_type','title','facebook_id','google_plus_id','twitter_id','activation_key','is_verified','is_translate_app','push_notification','device_token_translate','device_type_translate','is_deleted','status','is_login_translate','login_access_token_translate','created_date','updated_date'];
      }
      const user = await models.User.findOne({
        attributes: selectedFields,
        where: { user_id: user_id }
      });
      return user;
    }
    // Return null if the user was not updated
    return null;
  }


  async GetUserDataTranslate(userId) {
    try {
      const userData = await models.User.findOne({
        attributes:['user_id','user_name','user_email','profile_picture','user_login_type','title','facebook_id','google_plus_id','twitter_id','is_verified','is_translate_app','push_notification','device_token_translate','device_type_translate','is_deleted','status','is_login_translate','login_access_token_translate','created_date','updated_date','language_code','region','subscription_plan','subscribed_on','subscription_plan_device_type','voice_preference',],
        where: {
          user_id: userId,
        },
      });
      return userData ? userData.toJSON() : null;
    } catch (err) {
      console.error('Error fetching user data:', err);
      throw err;
    }
  }

  async GenerateQR(id, data, qrType) {
    try {
      const bucketName = process.env.S3_BUCKET_NAME;
      let folderName, fileName, filePath;
      switch (qrType) {
        case 1:
          folderName = 'usrqrimages/';
          fileName = `usr_${id}_${Date.now()}.png`;
          break;
        case 2:
          folderName = 'grpqrimages/';
          fileName = `grp_${id}_${Date.now()}.png`;
          break;
        default:
          return { error: 'Invalid qrType' };
      }
      filePath = `./public/images/${fileName}`;
      const result = await QRCode.toFile(filePath, data); // Removed JSON.stringify here
      const fileBuffer = fs.readFileSync(filePath);
      // Upload QR code to S3 bucket
      const generatedFile = await this.fileUploadToS3(fileName, bucketName, folderName, fileBuffer);
      // Delete the local file after uploading to S3
      fs.unlinkSync(filePath);
      return generatedFile;
    } catch (error) {
      console.error(error,"eror in qr code>>>>>>>>>>>>>>>");
      return { error: 'QR code generation failed' };
    }
  }

  async fileUploadToS3(files, bucketName, folderName, fileBuffer) {
    try {
      if (files) {
        let params = {
          Bucket: bucketName,
          ACLs: 'public-read',
          Key: folderName + files,
          Body: fileBuffer,
          ContentType: 'image/png',
        };
        const command = new PutObjectCommand(params);
        const response = await s3Client.send(command);
        // const s3BucketURL = `https://${bucketName}.s3.${process.env.S3_BUCKET_REGION}.amazonaws.com/${folderName}${files}`;
        const s3BucketURL = `https://d2neamglna4h3f.cloudfront.net/${folderName}${files}`;
        return { status: true, data: s3BucketURL };
      }
    } catch (error) {
      console.log('Image upload error:', error);
      return { status: false, data: error };
    }
  }

  async documentUploadToS3(files, bucketName, folderName, fileBuffer) {
    try {
      if (files) {
        let params = {
          Bucket: bucketName,
          ACLs: 'public-read',
          Key: folderName + files,
          Body: fileBuffer,
          ContentType: 'application/pdf',
        };
        const command = new PutObjectCommand(params);
        const response = await s3Client.send(command);
        // const s3BucketURL = `https://${bucketName}.s3.${process.env.S3_BUCKET_REGION}.amazonaws.com/${folderName}${files}`;
        const s3BucketURL = `https://d2neamglna4h3f.cloudfront.net/${folderName}${files}`;
        return { status: true, data: s3BucketURL };
      }
    } catch (error) {
      console.log('Document upload error:', error);
      return { status: false, data: error };
    }
  }

  async deleteImageFromS3(bucketName, fileName) {
    try {
      let params = {
        Bucket: bucketName,
        Key: fileName
      }
      const command = new DeleteObjectCommand(params);
      const response = await s3Client.send(command);
      console.log('File deleted successfully:', response);
      return { status: true };
    } catch (error) {
      console.log(error, "image delete error")
      return { status: false, data: error };
    }
  }
  async UploadToS3(files, bucketName, folderName, fileBuffer) {
    try {
      if (files) {
        let params = {
          Bucket: bucketName,
          ACLs: 'public-read',
          Key: folderName + files,
          Body: fileBuffer,
          ContentType: 'image/png',
        };
        const command = new PutObjectCommand(params);
        const response = await s3Client.send(command);
        // const s3BucketURL = `https://${bucketName}.s3.${process.env.S3_BUCKET_REGION}.amazonaws.com/${folderName}${files}`;
        const s3BucketURL = `https://d2neamglna4h3f.cloudfront.net/${folderName}${files}`;
        return { status: true, data: s3BucketURL };
      }
    } catch (error) {
      console.log('Image upload error:', error);
      return { status: false, data: error };
    }
  }
  // Send Android Push Notification
  async SendNotification(receiverDeviceToken, message, title, payload, notificationType) {
    try {
      let notificationJSON = {}
      let headerJSON = {}
      notificationJSON = {
        to: receiverDeviceToken,
        data: {
          title: title,
          body: message,
          response_data: payload,
          notification_type: notificationType
        },
        priority: "high"
      };
      headerJSON = {
        headers: {
          'Authorization': `key=${process.env.FIREBASE_AUTHORIZATION_KEY}`,
          'Content-Type': 'application/json'
        }
      }
      await axios.post('https://fcm.googleapis.com/fcm/send', notificationJSON, headerJSON).then(response => {
        console.log(response.data, "response.data.success >>>>>>>>>>>");
      }).catch(function (error) {
        console.log(error, "axios error >>>>>>>>");
      });
      let resJSON = {
        notificationJSON: notificationJSON
      }
      console.log("resJSONresJSONresJSON",resJSON)
      return resJSON;
    } catch (error) {
      console.log("error", error);
      return error;
    }
  }

  // Send IOS Push Notification
  async sendJunoNotificationIOS(receiverDeviceToken, message, title, payload) {
    try {
      let notificationJSON = {}
      let headerJSON = {}
      notificationJSON = {
        to: receiverDeviceToken,
        notification: {
          body: message,
          title: title,
          response_data: payload
        },
      };
      headerJSON = {
        headers: {
          'Authorization': `key=${process.env.FIREBASE_AUTHORIZATION_KEY}`,
          'Content-Type': 'application/json'
        }
      }
      await axios.post('https://fcm.googleapis.com/fcm/send', notificationJSON, headerJSON).then(response => {
        console.log(response.data.success, "response.data.success ios>>>>>>>>>>>");
      }).catch(function (error) {
        console.log(error, "axios error >>>>>>>>");
      });
      let resJSON = {
        notificationJSON: notificationJSON
      }
      return resJSON;
    } catch (error) {
      console.log("error", error);
      return error;
    }
  }

  async UpdateDeviceToken(user_id, device_token, application_type) {
    try {
      const user = await models.User.findOne({ where: { user_id: user_id } });
      if (!user) {
        return { status: HttpCodes['API_FAILURE'], msg: 'UserNotFound', code: HttpCodes['BAD_REQUEST'], data: [] };
      }
      // Check if the user's device token is different from the new token
      if (application_type == 2) {
        if (user.device_token_translate !== device_token) {
          // Set the previous user's device token to null
          await models.User.update({ device_token_translate: null }, { where: { device_token_translate: device_token } });
        }
      } else {
        if (user.device_token !== device_token) {
          // Set the previous user's device token to null
          await models.User.update({ device_token: null }, { where: { device_token: device_token } });
        }
      }
      let data: any;
      if (application_type == 2) {
        data = {
          device_token_translate: device_token,
          updated_date: await this.getEpoch()
        }
      } else {
        data = {
          device_token: device_token,
          updated_date: await this.getEpoch()
        }
      }
      const updateData = await models.User.update(
        data, { where: { user_id: user_id } }
      );

      if (updateData[0] === 1) {
        return { status: HttpCodes['API_SUCCESS'], msg: 'TokenUpdateSuccess', code: HttpCodes.OK, data: [] };
      } else {
        return { status: HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: HttpCodes['BAD_REQUEST'], data: [] };
      }
    } catch (error) {
      console.log("error", error);
      return { status: HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: HttpCodes['BAD_REQUEST'], data: [] };
    }
  }

   async pushEmail(mailData, emailId, subject, template) {
    try {
      const compiledTemplate = ejs.compile(template);
      // Render the dynamic content using the compiled template
      const renderedTemplate = compiledTemplate(mailData);
      const mailOptions = {
        from: 'noreply@mymanu.com',
        to: emailId,
        subject: subject,
        html: renderedTemplate,
      };
      const info = await transporter.sendMail(mailOptions);
      console.log('Email sent:', info.messageId);
      return true; // Return true to indicate successful email sending
    } catch (error) {
      console.error('Error sending email1:', error);
      return false; // Return false to indicate email sending failure
    }
  }


  async getUserData(userId, applicationType) {
    let attributes = [];
    if (applicationType === 1) {
      attributes = ['user_id', 'user_name', 'user_email', 'profile_picture', 'user_login_type', 'title', 'facebook_id', 'google_plus_id', 'twitter_id', 'is_verified', 'is_mymanuplay_app', 'push_notification', 'device_token', 'device_type', 'is_deleted', 'status', 'is_login', 'is_post_activity', 'login_access_token', 'created_date', 'updated_date', 'language_code',];
    } else if (applicationType === 2) {
      attributes = ['user_id', 'user_name', 'user_email', 'profile_picture', 'user_login_type', 'title', 'facebook_id', 'google_plus_id', 'twitter_id', 'is_verified', 'is_translate_app', 'push_notification', 'device_token_translate', 'device_type_translate', 'is_deleted', 'status', 'is_login_translate', 'login_access_token_translate', 'created_date', 'updated_date', 'language_code'];
    }
    try {
      const userData = await models.User.findOne({
        attributes: ['*'],
        where: { user_id: userId },
      });
      return userData ? userData.toJSON() : null;
    } catch (error) {
      throw error;
    }
  };

  async addEmailSendInBlue(listId, email, username) {
    const SibApiV3Sdk = require('sib-api-v3-sdk');
    let defaultClient = SibApiV3Sdk.ApiClient.instance;
    let apiKey = defaultClient.authentications['api-key'];
    apiKey.apiKey = process.env.SENDIN_BLUE_API_KEY;
    let apiInstance = new SibApiV3Sdk.ContactsApi();
    try {
      const response = await apiInstance.getContactsFromList(listId);
    } catch (error) {
      console.error(error);
    }
    // Create a new contact
    const createContact = new SibApiV3Sdk.CreateContact();
    createContact.email = email;
    try {
      // Add the contact to the list
      const response = await apiInstance.createContact(createContact);
      const contactId = response.id;
      // Add the contact to the specified list
      await apiInstance.addContactToList(listId, { emails: [email], contactIds: [contactId] });
      console.log('Contact added to the list successfully.');
    } catch (error) {
      console.error('Error adding contact to the list:', error);
    }
  }

  async writeCsvFile(buffer, filePath) {
    return new Promise((resolve, reject) => {
      fs.writeFile(filePath, buffer, (err) => {
        if (err) {
          reject(err);
        } else {
          resolve(filePath);
        }
      });
    });
  }


  //middleware to check app is up to date or not

  async appVersionCheck(req, res, next) {
    const appVersion = req.headers.app_version;
    const device_type = req.headers.device_type;
    const application_type = parseInt(req.headers.application_type);

    console.log("????????????????????appVersionCheck", appVersion, device_type)

    // Check if application type is 2, if not, proceed with the request
    if (application_type !== 2) {
        console.log("????????????????????application type is not 2")
        return next();
    }

    // Check if app version is present
    if (!appVersion) {
        console.log("????????????????????appVersion not present")
        // If app version header is not present, proceed with the request
        return next();
    }

    try {
        // Query the database to retrieve the current app version
        const currentVersionData = await models.ManageAppVersions.findOne({
            where: {
                store_type: device_type,
                application_type: application_type
            }
        });

        // Compare the app version from the header with the current version from the database
        if (parseInt(appVersion) < parseInt(currentVersionData.current_version)) {
            return res.status(400).json({ message: 'Please update your app to the latest version.', code: HttpCodes['BAD_REQUEST'] });
        }
        // If the app version matches, proceed with the request
        next();
    } catch (error) {
        // Handle database query errors
        console.error('Error retrieving current app version:', error);
        return res.status(500).json({ message: 'SomeThingWentWrong', code: HttpCodes['BAD_REQUEST'] });
    }
}

}