
import { body } from 'express-validator';
const models = require('./../../models/index');
const { Op } = require("sequelize");


module.exports.UserRegister = [
  body('name').trim().notEmpty().withMessage('UsernameRequired'),
  body('name').trim().isLength({ min: 2 }).withMessage('FullnameMinLengthRequired'),
  body('name').trim().isLength({ max: 30 }).withMessage('FullnameMaxLengthRequired'),
  body('application_type').trim().notEmpty().withMessage('ApplicationTypeRequired'),
  body('device_type').trim().notEmpty().withMessage('DeviceTypeRequired'),
  body('password').trim().notEmpty().withMessage('PasswordRequired'),
  body('password').trim().isLength({ min: 8 }).withMessage('PasswordMinLengthRequired'),
  body('password').matches(/^(?=.*\d)(?=.*[a-z])(?=.*[A-Z])(?=.*[\W_]).{8,}$/).withMessage('PasswordComplexityRequired'),
  // body('password').matches(/^(?=.*\d)(?=.*[a-z])(?=.*[A-Z])(?=.*[!@#$%^&*]).{8,}$/).withMessage('PasswordComplexityRequired'),
  body('email').trim().notEmpty().withMessage('UserEmailRequired'),
  body('email').trim().isEmail().withMessage('ValidEmailFormat'),
  body('email').trim().custom(async (value, { req }) => {
    return new Promise<void>((resolve, reject) => {
      return models.User.findOne({
        where: {
          user_email: { [Op.eq]: value },
          status: { [Op.eq]: 1 }
        }
      }).then(user => {
        if (user && user !== null && user !== undefined) {
          return reject();
        } else {
          return resolve();
        }
      }).catch((err) => {
        return reject();
      });
    });
  }).withMessage('ExistUser')
];
module.exports.UserLogin = [
  body('email').trim().notEmpty().withMessage('UserEmailRequired'),
  body('email').trim().isEmail().withMessage('ValidEmailFormat'),
  body('password').trim().notEmpty().withMessage('PasswordRequired'),
  body('application_type').trim().notEmpty().withMessage('ApplicationTypeRequired'),
  body('device_type').trim().notEmpty().withMessage('Device type is required'),
];
module.exports.email = [
  body('email').trim().notEmpty().withMessage('UserEmailRequired'),
  body('email').trim().isEmail().withMessage('ValidEmailFormat'),
];
module.exports.resetPassword = [
  body('email').trim().notEmpty().withMessage('UserEmailRequired'),
  body('email').trim().isEmail().withMessage('ValidEmailFormat'),
  body('password').trim().notEmpty().withMessage('PasswordRequired'),
  body('password').trim().isLength({ min: 8 }).withMessage('PasswordMinLengthRequired'),
  body('password').matches(/^(?=.*\d)(?=.*[a-z])(?=.*[A-Z])(?=.*[\W_]).{8,}$/).withMessage('PasswordComplexityRequired'),
  // body('password').matches(/^(?=.*\d)(?=.*[a-z])(?=.*[A-Z])(?=.*[!@#$%^&*]).{8,}$/).withMessage('PasswordComplexityRequired'),
];
module.exports.UserLogout = [
  body('application_type').trim().notEmpty().withMessage('ApplicationTypeRequired')
];

 