'use strict';
import {
  Model
} from 'sequelize';
module.exports = (sequelize, DataTypes) => {
  class FriendMessage extends Model {
    /**
     * Helper method for defining associations.
     * This method is not a part of Sequelize lifecycle.
     * The `models/index` file will call this method automatically.
     */
    static associate(models) {
      // define association here
      FriendMessage.belongsTo(models.User, { as: 'sender', foreignKey: 'sender_id' });
      FriendMessage.belongsTo(models.User, { as: 'receiver', foreignKey: 'receiver_id' });
      FriendMessage.belongsTo(models.FriendGroup, { foreignKey: 'friend_group_id', as: 'group' });
      FriendMessage.belongsTo(FriendMessage, {
        as: 'reply',
        foreignKey: 'reply_message_id', 
    });
    }
  }
  FriendMessage.init({
    friend_message_id: {
      allowNull: false,
      autoIncrement: true,
      primaryKey: true,
      type: DataTypes.INTEGER
    },
    friend_group_id: {
      type: DataTypes.INTEGER,
      allowNull: false,
    },
    sender_id: {
      type: DataTypes.INTEGER,
      allowNull: false,
    },
    receiver_id: {
      type: DataTypes.INTEGER,
      allowNull: false,
    },
    message: {
      type: DataTypes.TEXT,
      allowNull: true,
    },
    sender_deleted: {
      type: DataTypes.INTEGER,
      allowNull: false,
      defaultValue: 0
      // 0 = not deleted, 1 = deleted
    },
    receiver_deleted: {
      type: DataTypes.INTEGER,
      allowNull: false,
      defaultValue: 0
      // 0 = not deleted, 1 = deleted
    },
    reply_message_id: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    created_date: {
      type: DataTypes.INTEGER,
      allowNull: false,
    },
    updated_date: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    language_code: {
      type: DataTypes.STRING,
      allowNull: false,
    },
    receiver_message:
    {
      type: DataTypes.TEXT,
      allowNull: true,
    },
    receiver_language_code: {
      type: DataTypes.STRING,
      allowNull: false,
    },
  }, {
    sequelize,
    modelName: "FriendMessage",
    tableName: 'friend_message',
    timestamps: false
  });
  return FriendMessage;
};