'use strict';
import {
  Model
} from 'sequelize';

module.exports = (sequelize, DataTypes) => {
  class User extends Model {
    /**
     * Helper method for defining associations.
     * This method is not a part of Sequelize lifecycle.
     * The `models/index` file will call this method automatically.
     */
    static associate(models) {
      User.hasMany(models.TransferOwnership, { as: 'userId',foreignKey: 'user_id' });
      User.hasMany(models.TransferOwnership, {as: 'transferToUserId',foreignKey: 'transfer_to_user_id'});
      
      User.hasMany(models.FriendMaster,{as: 'inviteFromUser',foreignKey: 'invite_from_id'});
      User.hasMany(models.FriendMaster, {as: 'inviteToUser',foreignKey: 'invite_to_id'});
      User.hasMany(models.GroupMember, {foreignKey: 'user_id'});
      User.hasMany(models.GroupMaster, {as: 'ownerInfo',foreignKey: 'group_owner_id'});
      User.hasMany(models.GroupMessage, { as: 'userInfo',foreignKey: 'user_id' });
      User.hasMany(models.GroupMessage, { as: 'senderInfo',foreignKey: 'sender_id' });
      User.hasMany(models.FriendMessage, { as: 'sender',foreignKey: 'sender_id' });
      User.hasMany(models.FriendMessage, { as: 'receiver',foreignKey: 'receiver_id' });
      User.hasMany(models.FriendGroup, { as: 'member',foreignKey: 'member_id' });
      User.hasMany(models.FriendGroup, { as: 'owner',foreignKey: 'owner_id' });

    }
  }
  User.init({
    user_id: {
      type: DataTypes.INTEGER,
      allowNull: false,
      primaryKey: true,
      autoIncrement: true,
    },
    user_name: {
      type: DataTypes.STRING(255),
      allowNull: true,
    },
    user_email: {
      type: DataTypes.STRING(255),
      allowNull: true,
    },
    user_password: {
      type: DataTypes.STRING(255),
      allowNull: true,
    },
    profile_picture: {
      type: DataTypes.STRING(255),
      allowNull: true,
    },
    user_login_type: {
      type: DataTypes.INTEGER,
      allowNull: false,
      defaultValue:0
    },
    title: {
      type: DataTypes.STRING(255),
      allowNull: true,
    },
    registered_from: {
      type: DataTypes.STRING(10),
      allowNull: true,
    },
    facebook_id: {
      type: DataTypes.STRING(255),
      allowNull: true,
    },
    google_plus_id: {
      type: DataTypes.STRING(255),
      allowNull: true,
    },
    twitter_id: {
      type: DataTypes.STRING(255),
      allowNull: true,
    },
    activation_key: {
      type: DataTypes.STRING(255),
      allowNull: true,
    },
    is_verified: {
      type: DataTypes.INTEGER,
      allowNull: true,
      defaultValue:0
    },
    is_translate_app: {
      type: DataTypes.INTEGER,
      allowNull: true,
      defaultValue:0
    },
    is_mymanuplay_app: {
      type: DataTypes.INTEGER,
      allowNull: true,
      defaultValue:0
    },
    push_notification: {
      type: DataTypes.INTEGER,
      allowNull: true,
      defaultValue:1
    },
    device_token: {
      type: DataTypes.STRING(255),
      allowNull: true,
    },
    device_token_translate: {
      type: DataTypes.STRING(255),
      allowNull: true,
    },
    device_type: {
      type: DataTypes.INTEGER,
      allowNull: true,
      defaultValue:0
    },
    device_type_translate: {
      type: DataTypes.INTEGER,
      allowNull: true,
      defaultValue:0
    },
    is_deleted: {
      type: DataTypes.INTEGER,
      allowNull: true,
      defaultValue:1
    },
    status: {
      type: DataTypes.INTEGER,
      allowNull: true,
      defaultValue:1
    },
    is_login: {
      type: DataTypes.INTEGER, // Use the BOOLEAN data type for representing a boolean value
      allowNull: true,
    },
    is_login_translate: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    login_access_token: {
      type: DataTypes.STRING(255),
      allowNull: true,
    },
    login_access_token_translate: {
      type: DataTypes.STRING(255),
      allowNull: true,
    },
    is_post_activity: {
      type: DataTypes.INTEGER,
      allowNull: true,
      defaultValue:0
    },
    block_for_chat: {
      type: DataTypes.INTEGER,
      allowNull: true,
      defaultValue:1
    },
    language_code: {
      type: DataTypes.STRING(255),
      allowNull: true,
    },
    region:{
      type: DataTypes.STRING(255),
      allowNull: true,
    },
    user_qr_image: {
      type: DataTypes.STRING(255),
      allowNull: true,
    },
    subscription_plan: {
      type: DataTypes.STRING(255),
      allowNull: true,
    },
    subscription_plan_device_type: {
      type: DataTypes.STRING(255),
      allowNull: true,
    },
    subscribed_on: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    voice_preference: {
      type: DataTypes.STRING(255),
      allowNull: true,
    },
    created_date: {
      type: DataTypes.INTEGER,
      allowNull: false,
    },
    updated_date: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    is_deleted_translate:{
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    otp:{
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    mymanuplay_user_type: {
      type: DataTypes.INTEGER,
      allowNull: false,
      defaultValue:0,  // [ 0 = Not confirmed Yet, 1 = Broadcaster OR Creator, 2 = Listener  ],
    }
  }, {
    sequelize,
    modelName: 'User',
    tableName: "user_registration",
    timestamps: false,
  });
  return User;
};