const path = require('path')
import GroupmasterController from "../../controllers/groupmaster.controller";
import commonHelper from "../../helpers/common";
import * as GroupmasterValidation from '../../helpers/validation/groupmaster.validation';
const { createGroup, ListGroup, GroupInfo, GetGroupMessages, UpdateGroup, RemoveGroup, RemoveGroupImage, addGroupMember, removeGroupMember, StoreGroupMessages ,UpdateGroupName,UpdateGroupImage,UpdateGroupType,RemoveGroupMessages} = new GroupmasterController();
const multer = require('multer');
const storage = multer.memoryStorage();
const upload = multer({ storage: storage });
const { CheckValidationError, VerifyJwt, VerifyAccountActive } = new commonHelper();

module.exports = function (router) {
    //create group
    router.post('/create-group', upload.single('group_image'), VerifyJwt, VerifyAccountActive, GroupmasterValidation['createGroup'], CheckValidationError, createGroup);
    // list group
    router.get('/list-group', VerifyJwt, VerifyAccountActive, CheckValidationError, ListGroup);
    //group info
    router.get('/group-info', VerifyJwt, VerifyAccountActive, CheckValidationError, GroupInfo);
    //group message
    router.get('/group-messages', VerifyJwt, VerifyAccountActive, CheckValidationError, GetGroupMessages);
    //update group 
    router.post('/update-group', upload.single('group_image'), VerifyJwt, VerifyAccountActive, GroupmasterValidation['UpdateGroup'], CheckValidationError, UpdateGroup);
    //remove group
    router.post('/remove-group', VerifyJwt, VerifyAccountActive, CheckValidationError, RemoveGroup);
    //remove group image
    router.post('/remove-group-image', VerifyJwt, VerifyAccountActive, CheckValidationError, RemoveGroupImage);
    router.post('/remove-group-member', VerifyJwt, VerifyAccountActive,GroupmasterValidation['Member'],CheckValidationError,  removeGroupMember);
    router.post('/add-group-member', VerifyJwt, VerifyAccountActive, GroupmasterValidation['Member'], CheckValidationError, addGroupMember);
    //send group message
    router.post('/store-group-messages', upload.any(), VerifyJwt, VerifyAccountActive, GroupmasterValidation['StoreGroupMessages'],CheckValidationError, StoreGroupMessages);
    //update name of group
    router.post('/update-group-name', VerifyJwt, VerifyAccountActive,  GroupmasterValidation['UpdateGroupName'],CheckValidationError,UpdateGroupName);
    //update group image
    router.post('/update-group-image', upload.single('group_image'), VerifyJwt, VerifyAccountActive, GroupmasterValidation['UpdateGroupImage'],CheckValidationError,  UpdateGroupImage);
    //update group type
    router.post('/update-group-type',  VerifyJwt, VerifyAccountActive, GroupmasterValidation['UpdateGroupType'],CheckValidationError,  UpdateGroupType);
    //remove group messages
    router.post('/remove-group-messages', VerifyJwt, VerifyAccountActive, GroupmasterValidation['RemoveGroupMessages'], CheckValidationError, RemoveGroupMessages);
}