"use strict";
const models = require('./../models/index');
import commonHelper from "../helpers/common";
import { HttpCodes } from "../helpers/responseCodes";
const { getEpoch, SendNotification, fileUploadToS3, GenerateQR, deleteImageFromS3, sendJunoNotificationIOS } = new commonHelper();
const db = require("../models/index");
const Op = db.Sequelize.Op;
const fs = require('fs');
const { Sequelize } = require('sequelize'); // Import Sequelize object

export default class GroupmasterService {
    constructor() {
        this.createGroup = this.createGroup.bind(this);
        this.ListGroup = this.ListGroup.bind(this);
        this.GroupInfo = this.GroupInfo.bind(this);
        this.GetGroupMessages = this.GetGroupMessages.bind(this);
        this.UpdateGroup = this.UpdateGroup.bind(this);
        this.RemoveGroup = this.RemoveGroup.bind(this);
        this.RemoveGroupImage = this.RemoveGroupImage.bind(this);
        this.addGroupMember = this.addGroupMember.bind(this);
        this.removeGroupMember = this.removeGroupMember.bind(this);
        this.StoreGroupMessages = this.StoreGroupMessages.bind(this);
        this.UpdateGroupName = this.UpdateGroupName.bind(this);
        this.UpdateGroupImage = this.UpdateGroupImage.bind(this);
        this.UpdateGroupType = this.UpdateGroupType.bind(this);
        this.RemoveGroupMessages = this.RemoveGroupMessages.bind(this);
    }
    //create group
    async createGroup(req, callback) {
        try {
            const user_id = req.user;
            const group_name = req.body.group_name;
            const application_type = parseInt(req.body.application_type);
            const group_type = parseInt(req.body.group_type);
            const group_member_id = req.body.group_member_id;
            const qrType = 2;  // for group qr 
            if (application_type !== 2) {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: HttpCodes['BAD_REQUEST'], data: [] });
            }
            if (group_type > 2 || group_type <= 0) {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidGroupType', code: HttpCodes['BAD_REQUEST'], data: [] });
            }
            const bucketName = process.env.S3_BUCKET_NAME;
            const folderName = 'group_files/';
            let groupImageValue = null;
            let groupDBData = {};
            if (req.file) {
                const fileName = `${Date.now()}_${req.file.originalname}`;
                const uploadGroupImage = await fileUploadToS3(fileName, bucketName, folderName, req.file.buffer);
                if (!uploadGroupImage) {
                    return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'UploadProperImage', code: HttpCodes['BAD_REQUEST'], data: [] });
                }
                groupImageValue = uploadGroupImage.data;
            }
            let insertGroup = await models.GroupMaster.create({
                group_name: group_name,
                group_image: groupImageValue ? groupImageValue : '',
                group_owner_id: user_id,
                group_type: group_type,
                created_date: await getEpoch(),
                updated_date: await getEpoch(),
            });
            let memberIds = [];
            if (insertGroup) {
                if (group_member_id) {
                    memberIds = group_member_id.split(",").map(id => parseInt(id.trim(), 10));
                    if (memberIds?.length > 0) {
                        let bulkArr = [];
                        await Promise.all(
                            memberIds?.map(async (memberId) => {
                                bulkArr.push({
                                    group_id: insertGroup?.group_id,
                                    user_id: memberId,
                                    created_date: await getEpoch(),
                                    updated_date: await getEpoch(),
                                });
                            })
                        );
                        try {
                            const insertedMembers = await models.GroupMember.bulkCreate(bulkArr);
                        } catch (error) {
                            console.log(error, "error while bulk insert")
                        }
                    }
                }
                const getGroupData = await models.GroupMaster.findOne({
                    where: { group_id: insertGroup.group_id }
                });
                const groupOwnerData = await models.User.findOne({
                    attributes: ['user_name'],
                    where: { user_id: user_id }
                });
                const groupOwnerName = groupOwnerData ? groupOwnerData.user_name : '';
                // Send notifications to the newly added members
                for (const memberId of memberIds) {
                    const getUserInfo = await models.User.findOne({
                        attributes: ['device_type_translate', 'device_token_translate'],
                        where: { user_id: memberId }
                    });
                    if (getUserInfo) {
                        const { device_type_translate, device_token_translate } = getUserInfo;
                        const receiverDeviceType = getUserInfo.device_type_translate;
                        const receiverDeviceToken = getUserInfo.device_token_translate;
                        if (receiverDeviceToken) {
                            const message = `${groupOwnerName} has added you to the ${group_name} group.`;
                            const title = 'Notification';
                            const notificationType = 'group_create';
                            const payloadData = {
                                type: 'group_create',
                                message,
                                group_id: getGroupData.group_id,
                                group_name,
                                group_type,
                            };
                            const payload = JSON.stringify(payloadData);
                            if (receiverDeviceType === 1) {
                                try {
                                    await SendNotification(receiverDeviceToken, message, title, payload, notificationType);
                                } catch (error) {
                                    console.error('Error sending Android notification:', error);
                                }
                            } else if (receiverDeviceType === 2) {
                                sendJunoNotificationIOS(receiverDeviceToken, message, title, payload); // Implement this function accordingly
                            }
                        } else {
                            console.error(`User with ID ${memberId} does not have a valid device token. Skipping notification.`);
                        }
                    } else {
                        console.error(`User with ID ${memberId} not found in the database. Skipping notification.`);
                    }
                }
                const groupOwnerId = getGroupData.group_owner_id;
                const groupInfo = {
                    group_id: getGroupData.group_id,
                    group_name: getGroupData.group_name,
                    group_owner_id: getGroupData.group_owner_id,
                    created_date: getGroupData.created_date,
                    updated_date: getGroupData.updated_date,
                };
                // const groupDataInfo = JSON.stringify(groupInfo);
                const groupDataInfo = JSON.stringify(groupInfo);
                const generatedFile = await GenerateQR(getGroupData.group_id, groupDataInfo, qrType);
                if ('status' in generatedFile && generatedFile.status) {
                    const qrCodeURL = generatedFile.data;
                    const updateGroupQR = await models.GroupMaster.update(
                        { group_qr_image: qrCodeURL },
                        { where: { group_id: getGroupData.group_id } }
                    );
                    if (updateGroupQR[0] === 1) {
                        const getGroupMembers = await models.GroupMember.findAll({
                            where: {
                                group_id: insertGroup.group_id,
                            },
                            include: [
                                {
                                    model: models.User,
                                    attributes: ['user_id', 'profile_picture', 'user_name', 'language_code']
                                }
                            ]
                        });
                        const memberInfo = getGroupMembers.map(member => {
                            return {
                                id: member.id,
                                group_id: member.group_id,
                                user_id: member.user_id,
                                ...member.User?.dataValues
                            };
                        });
                        const groupData = {
                            group_id: getGroupData.group_id,
                            group_name: getGroupData.group_name,
                            group_owner_id: getGroupData.group_owner_id,
                            created_date: getGroupData.created_date,
                            updated_date: getGroupData.updated_date,
                            group_image: groupImageValue,
                            group_qr_image: qrCodeURL,
                            memberInfo: memberInfo
                        };
                        groupDBData['groupData'] = groupData;
                        groupDBData['QR_code'] = generatedFile;
                        return callback(null, { status: HttpCodes['API_SUCCESS'], msg: 'GroupCreatedSuccess', code: HttpCodes.OK, data: groupData });
                    } else {
                        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: HttpCodes['BAD_REQUEST'], data: [] });
                    }
                } else {
                    return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'QRNotGenerated', code: HttpCodes['BAD_REQUEST'], data: [] });
                }
            } else {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: HttpCodes['BAD_REQUEST'], data: [] });
            }
        } catch (error) {
            console.log(error, 'error.....');
            return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: HttpCodes['BAD_REQUEST'], data: [] });
        }
    }
    //list group
    async ListGroup(req, callback) {
        try {
            const application_type = parseInt(req.query.application_type);
            const user_id = req.body.user_id;
            let filter = req.query.filter;
            if (!filter) {
                filter = 0;
            }
            if (isNaN(application_type) || application_type !== 2) {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: HttpCodes['BAD_REQUEST'], data: [] });
            }
            let groups = [];
            if (filter == 3) {
                const tempGroups = await models.GroupMaster.findAll({
                    include: [
                        {
                            model: models.GroupMember,
                            as: 'memberInfo',
                            include: [
                                {
                                    model: models.User,
                                    attributes: ['user_id', 'profile_picture', 'user_name', 'language_code', 'subscription_plan', 'subscription_plan_device_type']
                                },
                            ],
                            required: false // This might be true or false based on your use case
                        },
                        {
                            model: models.User,
                            as: 'ownerInfo',
                            attributes: ['user_id', 'subscription_plan', 'user_name', 'profile_picture', 'language_code', 'subscription_plan_device_type'],
                            // where: { user_id: Sequelize.col('GroupMaster.group_owner_id') },
                            required: false
                        },
                    ],
                    order: [['group_id', 'DESC']],
                });
                groups = tempGroups.filter(ele => (ele.group_owner_id == user_id) || (ele.memberInfo.some(member => (member.user_id === user_id))));
            }
            if (filter == 0) {
                const tempGroups = await models.GroupMaster.findAll({
                    // where: {
                    //     group_type: 1,
                    // },
                    order: [['group_id', 'DESC']],
                    include: [
                        {
                            model: models.GroupMember,
                            as: 'memberInfo',
                            include: [
                                {
                                    model: models.User,
                                    attributes: ['user_id', 'profile_picture', 'user_name', 'language_code', 'subscription_plan', 'subscription_plan_device_type']
                                },
                            ],
                            required: false // This might be true or false based on your use case
                        },
                        {
                            model: models.User,
                            as: 'ownerInfo',
                            attributes: ['user_id', 'subscription_plan', 'user_name', 'subscription_plan_device_type', 'profile_picture', 'language_code',],
                            // where: { user_id: Sequelize.col('GroupMaster.group_owner_id') },
                            required: false
                        },
                    ],
                });
                groups = tempGroups.filter(ele => ele.group_type === 1 || (ele.group_type === 2 && ele.group_owner_id == user_id) || (ele.group_type === 2 && ele.memberInfo.some(member => (member.user_id === user_id))));
            } else if (filter == 1) {
                groups = await models.GroupMaster.findAll({
                    where: {
                        group_type: 1,
                    },
                    include: [
                        {
                            model: models.GroupMember,
                            as: 'memberInfo',
                            include: [
                                {
                                    model: models.User,
                                    attributes: ['user_id', 'profile_picture', 'user_name', 'language_code', 'subscription_plan', 'subscription_plan_device_type']
                                },
                            ],
                            required: false // This might be true or false based on your use case
                        },
                        {
                            model: models.User,
                            as: 'ownerInfo',
                            attributes: ['user_id', 'subscription_plan', 'user_name', 'subscription_plan_device_type', 'profile_picture', 'language_code',],
                            // where: { user_id: Sequelize.col('GroupMaster.group_owner_id') },
                            required: false
                        },
                    ],
                    order: [['group_id', 'DESC']],
                });
            } else if (filter == 2) {
                const tempGroups = await models.GroupMaster.findAll({
                    where: {
                        group_type: 2,
                    },
                    include: [
                        {
                            model: models.GroupMember,
                            as: 'memberInfo',
                            where: { user_id: user_id },
                            include: [
                                {
                                    model: models.User,
                                    attributes: ['user_id', 'profile_picture', 'user_name', 'language_code', 'subscription_plan', 'subscription_plan_device_type']
                                },
                            ],
                            required: false // This might be true or false based on your use case
                        },
                        {
                            model: models.User,
                            as: 'ownerInfo',
                            attributes: ['user_id', 'subscription_plan', 'user_name', 'profile_picture', 'language_code', 'subscription_plan_device_type'],
                            // where: { user_id: Sequelize.col('GroupMaster.group_owner_id') },
                            required: false
                        },
                    ],
                    order: [['group_id', 'DESC']],
                });
                groups = tempGroups.filter(ele => ele.group_owner_id === user_id || ele.memberInfo.some(member => member.user_id === user_id));
            }
            const groupData = groups.map(async (group) => {
                const groupInfo = {
                    group_id: group._id,
                    group_owner_id: group.group_owner_id,
                    group_name: group.group_name,
                    group_image: group.group_image || '',
                    group_type: group.group_type,
                    group_qr_code: group.group_qr_code || '',
                    group_subscription_plan: '',
                    group_subscription_plan_device_type: '',
                    memberInfo: [],
                };
                // Get owner information
                const owner = await models.User.findOne({ where: { user_id: group.group_owner_id } });
                if (owner) {
                    groupInfo.group_subscription_plan = owner.subscription_plan || '';
                    groupInfo.group_subscription_plan_device_type = owner.subscription_plan_device_type || '';
                }
            });
            return callback(null, { 'status': HttpCodes['API_SUCCESS'], 'msg': 'GroupList', code: HttpCodes.OK, data: groups });
        } catch (error) {
            console.log(error, 'error.....');
            return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'ApiFailed', code: HttpCodes["BAD_REQUEST"], data: [] });
        }
    }
    //group info
    async GroupInfo(req, callback) {
        try {
            const application_type = parseInt(req.query.application_type);
            const group_id = parseInt(req.query.group_id);
            const user_id = req.body.user_id;
            if (isNaN(application_type) || application_type !== 2) {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: HttpCodes['BAD_REQUEST'], data: [] });
            }
            const groups = await models.GroupMaster.findAll({
                where: { group_id: group_id },
                include: [
                    {
                        model: models.GroupMember,
                        as: 'memberInfo',
                        include: [
                            {
                                model: models.User,
                                attributes: ['user_id', 'profile_picture', 'user_name', 'language_code', 'subscription_plan', 'subscription_plan_device_type']
                            },
                        ],
                        required: false
                    },
                    {
                        model: models.User,
                        as: 'ownerInfo',
                        attributes: ['user_id', 'subscription_plan', 'user_name', 'subscription_plan_device_type', 'profile_picture', 'language_code'],
                        required: false
                    },
                ],
                order: [['group_id', 'DESC']],
            });
            let groupMemberArray = [];
            let getData = await models.GroupMember.findAll({ where: { group_id: group_id } });
            let group_type = groups[0].group_type;
            groupMemberArray.push(groups[0].group_owner_id);
            if (group_type === 2) {
                for (let i = 0; i < getData.length; i++) {
                    groupMemberArray.push(getData[i].user_id);
                }
                const isUserInGroup = groupMemberArray.some(memberId => memberId === user_id);
                if (!isUserInGroup) {
                    return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'NoLongerInGroup', code: HttpCodes['BAD_REQUEST'], data: [] });
                } else {
                    return callback(null, { 'status': HttpCodes['API_SUCCESS'], 'msg': 'GroupList', code: HttpCodes.OK, data: groups });
                }
            } else {
                return callback(null, { 'status': HttpCodes['API_SUCCESS'], 'msg': 'GroupList', code: HttpCodes.OK, data: groups });
            }
        } catch (error) {
            console.log(error, 'error.....');
            return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'ApiFailed', code: HttpCodes["BAD_REQUEST"], data: [] });
        }
    }
    //get group message
    async GetGroupMessages(req, callback) {
        try {
            const application_type = parseInt(req.query.application_type);
            const group_id = parseInt(req.query.group_id);
            const user_id = req.body.user_id;
            let offset = req.body.offset || 0;
            if (isNaN(application_type) || application_type !== 2) {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: HttpCodes['BAD_REQUEST'], data: [] });
            }
            const getGroupInfo = await models.GroupMessage.findAll({
                where: {
                    [Op.and]: [
                        {
                            [Op.not]: {
                                [Op.or]: [
                                    { is_deleted: 1 },
                                    { public_deleted_flag: 1 }
                                ]
                            }
                        },
                        {
                            group_id: group_id,
                            user_id: user_id
                        }
                    ]
                },
                include: [
                    {
                        model: models.User,
                        as: 'senderInfo',
                        attributes: ['user_id', 'profile_picture', 'user_name', 'language_code'],
                        required: false
                    },
                    {
                        model: models.GroupMessage, // Assuming the model name is GroupMessage
                        as: 'reply',
                        attributes: ['group_message_id', 'group_message', 'created_date'], // Add other attributes as needed
                        include: [
                            {
                                model: models.User,
                                as: 'senderInfo',
                                attributes: ['user_id', 'profile_picture', 'user_name', 'language_code'],
                                required: false
                            }
                        ],
                        required: false
                    }
                ],
                order: [['created_date', 'ASC']],
            });
            if (getGroupInfo.length > 0) {
                return callback(null, { status: HttpCodes['API_SUCCESS'], msg: 'GroupMessages', code: HttpCodes.OK, data: getGroupInfo });
            }
            return callback(null, { status: HttpCodes['API_SUCCESS'], msg: 'NoDataFound', code: HttpCodes['OK'], data: [] });
        } catch (error) {
            console.log(error, 'error.....');
            return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'SomeThingWentWrong', code: HttpCodes['BAD_REQUEST'], data: [] });
        }
    }
    //update group 
    async UpdateGroup(req, callback) {
        try {
            const user_id = req.user;
            const group_name = req.body.group_name;
            const application_type = parseInt(req.body.application_type);
            const group_type = parseInt(req.body.group_type);
            const group_member_id = req.body.group_member_id;
            const group_id = parseInt(req.body.group_id);
            if (application_type !== 2) {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: HttpCodes['BAD_REQUEST'], data: [] });
            }
            if (group_type > 2 || group_type <= 0) {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidGroupType', code: HttpCodes['BAD_REQUEST'], data: [] });
            }
            const getGroupData = await models.GroupMaster.findOne({
                where: { group_id }
            });
            if (!getGroupData) {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'GroupReferenceIdDoesNotExist', code: HttpCodes['BAD_REQUEST'], data: [] });
            }
            const checkUserOwnGroup = await models.GroupMaster.findOne({
                where: { group_id, group_owner_id: user_id }
            });
            if (!checkUserOwnGroup) {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'UserReferenceIdNotBelongsToGroupReferenceId', code: HttpCodes['BAD_REQUEST'], data: [] });
            }
            const dbGroupImage = getGroupData.group_image;
            const dbGroupQR = getGroupData.group_qr_image;
            let uploadGroupImage = dbGroupImage;
            if (req.file) {
                const fileName = `${Date.now()}_${req.file.originalname}`;
                uploadGroupImage = await fileUploadToS3(fileName, process.env.S3_BUCKET_NAME, 'group_files/', req.file.buffer);
                if (!uploadGroupImage) {
                    return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'UploadProperImage', code: HttpCodes['BAD_REQUEST'], data: [] });
                }
                if (dbGroupImage) {
                    const urlParts = dbGroupImage.split('/');
                    const objectKey = urlParts[urlParts.length - 1];
                    // Delete the old group image from S3
                    const deleteImageResult = await deleteImageFromS3(process.env.S3_BUCKET_NAME, `group_files/${objectKey}`);
                    if (!deleteImageResult.status) {
                        console.error('Error deleting old group image:', deleteImageResult.data);
                    }
                }
            }
            let groupImageValue = uploadGroupImage ? uploadGroupImage.data : null;
            const updateGroup = await models.GroupMaster.update(
                {
                    group_name,
                    group_image: groupImageValue,
                    group_owner_id: user_id,
                    group_type,
                    updated_date: await getEpoch(),
                }, {
                where: { group_id }
            });
            const grpMemberArray = await models.GroupMember.findAll({
                where: { group_id: group_id }
            });
            if (grpMemberArray.length > 0) {
                await models.GroupMember.destroy({ where: { group_id: group_id } });
            }
            if (updateGroup[0] === 1) {
                if (group_member_id) {
                    const memberIds = group_member_id.split(",").map(id => parseInt(id.trim(), 10));
                    if (memberIds?.length > 0) {
                        let bulkArr = [];
                        await Promise.all(
                            memberIds?.map(async (memberId) => {
                                bulkArr.push({
                                    group_id: group_id,
                                    user_id: memberId,
                                    created_date: await getEpoch(),
                                    updated_date: await getEpoch(),
                                });
                            })
                        );
                        try {
                            const insertedMembers = await models.GroupMember.bulkCreate(bulkArr);
                        } catch (error) {
                            console.log(error, "error while bulk insert")
                        }
                    }
                }
                const groupOwnerData = await models.User.findOne({
                    attributes: ['user_name'],
                    where: { user_id: user_id }
                });
                const groupOwnerName = groupOwnerData ? groupOwnerData.user_name : '';
                if (group_member_id) {
                    const grpMember = group_member_id.split(',').map(memberId => parseInt(memberId));
                    for (const memberId of grpMember) {
                        if (!grpMemberArray.includes(memberId)) {
                            // Get user information of the group member
                            const getUserInfo = await models.User.findOne({
                                attributes: ['device_type_translate', 'device_token_translate'],
                                where: { user_id: memberId }
                            });
                            if (getUserInfo) {
                                // Send notification to the group member
                                const { device_type_translate, device_token_translate } = getUserInfo;
                                const receiverDeviceType = getUserInfo.device_type_translate;
                                const receiverDeviceToken = getUserInfo.device_token_translate;
                                if (receiverDeviceToken) {
                                    const message = `${groupOwnerName} has added you to the ${getGroupData.group_name} group.`;
                                    const title = 'Notification';
                                    const notificationType = 'group_create';
                                    const payloadData = {
                                        type: 'group_create',
                                        message,
                                        group_id,
                                        group_name: getGroupData.group_name,
                                        group_type: getGroupData.group_type,
                                    };
                                    const payload = JSON.stringify(payloadData);
                                    // Send Android Notification
                                    if (receiverDeviceType === 1) {
                                        // sendJunoNotificationAndroid(receiverDeviceToken, message, title, payload, notificationType); // Implement this function accordingly
                                        try {
                                            await SendNotification(receiverDeviceToken, message, title, payload, notificationType);
                                        } catch (error) {
                                            console.error('Error sending Android notification:', error);
                                        }
                                    } else if (receiverDeviceType === 2) {
                                        sendJunoNotificationIOS(receiverDeviceToken, message, title, payload); // Implement this function accordingly
                                    }
                                } else {
                                    console.error(`User with ID ${memberId} does not have a valid device token. Skipping notification.`);
                                }
                            } else {
                                console.error(`User with ID ${memberId} not found in the database. Skipping notification.`);
                            }
                        }
                    }
                }
                return callback(null, { status: HttpCodes['API_SUCCESS'], msg: 'GroupDataUpdateSuccess', code: HttpCodes.OK, data: [] });
            } else {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: HttpCodes['BAD_REQUEST'], data: [] });
            }
        } catch (error) {
            console.log(error, 'error.....');
            return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: HttpCodes['BAD_REQUEST'], data: [] });
        }
    }
    //remove group
    async RemoveGroup(req, callback) {
        try {
            const group_id = req.body.group_id;
            const user_id = req.body.user_id;
            const application_type = parseInt(req.body.application_type);
            // Check if application type is valid or not
            if (application_type !== 2) {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: HttpCodes['BAD_REQUEST'], data: [] });
            }
            const getGroupData = await models.GroupMaster.findOne({
                where: { group_id: group_id }
            });
            if (!getGroupData) {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'GroupReferenceIdDoesNotExist', code: HttpCodes['BAD_REQUEST'], data: [] });
            }
            const checkUserOwnGroup = await models.GroupMaster.findOne({
                where: { group_id: group_id, group_owner_id: user_id }
            });
            if (!checkUserOwnGroup) {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'UserReferenceIdNotBelongsToGroupReferenceId', code: HttpCodes['BAD_REQUEST'], data: [] });
            }
            const dbGroupImage = getGroupData.group_image;
            const dbGroupQR = getGroupData.group_qr_image;
            if (dbGroupImage) {
                const urlParts = dbGroupImage.split('/');
                const objectKey = urlParts[urlParts.length - 1];
                await deleteImageFromS3(process.env.S3_BUCKET_NAME, `group_files/${objectKey}`);
            }
            if (dbGroupQR) {
                const urlPartsQr = dbGroupQR.split('/');
                const objectKeyQr = urlPartsQr[urlPartsQr.length - 1];
                await deleteImageFromS3(process.env.S3_BUCKET_NAME, `grpqrimages/${objectKeyQr}`);
            }
            const grpMemberArray = await models.GroupMember.findAll({
                where: { group_id: group_id }
            });
            if (grpMemberArray.length > 0) {
                await models.GroupMember.destroy({ where: { group_id: group_id } });
            }
            const removeGroupInfo = await models.GroupMaster.destroy({
                where: { group_id: group_id }
            });
            if (removeGroupInfo) {
                return callback(null, { status: HttpCodes['API_SUCCESS'], msg: 'GroupDeletedSuccessfully', code: HttpCodes.OK, data: [] });
            } else {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: HttpCodes['BAD_REQUEST'], data: [] });
            }
        } catch (error) {
            console.log(error, 'error.....');
            return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: HttpCodes['BAD_REQUEST'], data: [] });
        }
    }
    //remove group image
    async RemoveGroupImage(req, callback) {
        try {
            const group_id = req.body.group_id;
            const user_id = req.body.user_id;
            const application_type = parseInt(req.body.application_type);
            // Check if application type is valid or not
            if (application_type !== 2) {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: HttpCodes['BAD_REQUEST'], data: [] });
            }
            const getGroupData = await models.GroupMaster.findOne({
                where: { group_id: group_id }
            });
            if (!getGroupData) {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'GroupReferenceIdDoesNotExist', code: HttpCodes['BAD_REQUEST'], data: [] });
            }
            const checkUserOwnGroup = await models.GroupMaster.findOne({
                where: { group_id: group_id, group_owner_id: user_id }
            });
            if (!checkUserOwnGroup) {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'UserReferenceIdNotBelongsToGroupReferenceId', code: HttpCodes['BAD_REQUEST'], data: [] });
            }
            const dbGroupImage = getGroupData.group_image;
            if (!dbGroupImage) {
                return callback(null, { status: HttpCodes['API_SUCCESS'], msg: 'NoImageFound', code: HttpCodes.OK, data: [] });
            } else {
                const urlParts = dbGroupImage.split('/');
                const objectKey = urlParts[urlParts.length - 1];
                const deleteImageResult = await deleteImageFromS3(process.env.S3_BUCKET_NAME, `group_files/${objectKey}`);
                if (deleteImageResult) {
                    const updateGroup = await models.GroupMaster.update({
                        group_image: '',
                        updated_date: await getEpoch(),
                    }, {
                        where: { group_id: group_id }
                    });
                    if (updateGroup[0] === 1) {
                        return callback(null, { status: HttpCodes['API_SUCCESS'], msg: 'GroupImageRemovedSuccessfully', code: HttpCodes.OK, data: [] });
                    } else {
                        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: HttpCodes['BAD_REQUEST'], data: [] });
                    }
                } else {
                    return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: HttpCodes['BAD_REQUEST'], data: [] });
                }
            }
        } catch (error) {
            console.log(error, 'error.....');
            return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: HttpCodes['BAD_REQUEST'], data: [] });
        }
    }
    //add group member
    async addGroupMember(req, callback) {
        try {
            const user_id = req.user;
            const application_type = parseInt(req.body.application_type);
            const group_member_id = req.body.group_member_id; // Renamed to plural for clarity
            const group_id = parseInt(req.body.group_id);
            const memberIds = group_member_id.split(",").map(id => parseInt(id.trim(), 10));
            // Check if all member IDs exist in the user table
            const existingUsers = await models.User.findAll({
                where: { user_id: { [Op.in]: memberIds } }
            });
            if (existingUsers.length !== memberIds.length) {
                return callback(null, { status: HttpCodes["API_FAILURE"], msg: "UserDoesNotExist", code: HttpCodes["BAD_REQUEST"], data: [], });
            }
            if (application_type !== 2) {
                return callback(null, { status: HttpCodes["API_FAILURE"], msg: "InvalidApplicationType", code: HttpCodes["BAD_REQUEST"], data: [], });
            }
            // Get group data
            const groupData = await models.GroupMaster.findOne({
                where: { group_id: group_id },
            });
            if (!groupData) {
                return callback(null, { status: HttpCodes["API_FAILURE"], msg: "GroupReferenceIdDoesNotExist", code: HttpCodes["BAD_REQUEST"], data: [], });
            }
            // Check if user is the group owner
            if (group_member_id.includes(groupData.group_owner_id.toString())) {
                const groupOwner = await models.User.findOne({
                    where: { user_id: groupData.group_owner_id },
                });
                return callback(null, {
                    status: HttpCodes["API_FAILURE"], msg: "GroupOwner", code: HttpCodes["BAD_REQUEST"], data: [], name: groupOwner.user_name, flag: 1,
                });
            }
            const existingMembers = await models.GroupMember.findAll({
                where: {
                    user_id: { [Op.in]: memberIds },
                    group_id: group_id,
                },
                include: [{ model: models.User, attributes: ['user_id', 'user_name'] }],
            });
            if (existingMembers.length > 0) {
                const alreadyMemberInfo = existingMembers.map(member => ({
                    user_id: member.user_id,
                    user_name: member.User.user_name,
                }));
                const alreadyMemberNames = alreadyMemberInfo.map(member => member.user_name).join(', ');
                return callback(null, {
                    status: HttpCodes["API_FAILURE"], msg: 'AlreadyMember', code: HttpCodes["BAD_REQUEST"], data: [], name: alreadyMemberNames, flag: 1,
                });
            }
            // Get group owner's subscription plan
            const ownerInfo = await models.User.findOne({
                where: { user_id: groupData.group_owner_id },
            });
            const userSubscriptionPlan = ownerInfo.subscription_plan;
            // if (userSubscriptionPlan !== "premium") {
            //     const countMembers = await models.GroupMember.count({
            //         where: { group_id: group_id },
            //     });

            //     if (countMembers >= 3) {
            //         return callback(null, {
            //             status: HttpCodes["API_FAILURE"],
            //             msg: "MemberLimit",
            //             code: HttpCodes["BAD_REQUEST"],
            //             data: [],
            //         });
            //     }
            // }
            let insertedMembers: any;
            if (group_member_id) {
                const memberIds = [...new Set(group_member_id.split(",").map(id => parseInt(id.trim(), 10)))];
                if (memberIds?.length > 0) {
                    let bulkArr = [];
                    await Promise.all(
                        memberIds?.map(async (memberId) => {
                            bulkArr.push({
                                group_id: group_id,
                                user_id: memberId,
                                created_date: await getEpoch(),
                                updated_date: await getEpoch(),
                            });
                        })
                    );
                    try {
                        insertedMembers = await models.GroupMember.bulkCreate(bulkArr);

                    } catch (error) {
                        console.log(error, "error while bulk insert")
                    }
                }
            }
            // Send notifications to the newly added members
            if (insertedMembers?.length > 0) {
                const groupOwnerName = ownerInfo.user_name; // Assuming you have ownerInfo defined
                const getGroupData = groupData; // Assuming you have getGroupData defined
                for (const memberId of memberIds) {
                    const getUserInfo = await models.User.findOne({
                        attributes: ['device_type_translate', 'device_token_translate'],
                        where: { user_id: memberId }
                    });
                    if (getUserInfo && user_id !== memberId) {
                        const { device_type_translate, device_token_translate } = getUserInfo;
                        const receiverDeviceType = getUserInfo.device_type_translate;
                        const receiverDeviceToken = getUserInfo.device_token_translate;
                        if (receiverDeviceToken) {
                            const message = `${groupOwnerName} has added you to the ${getGroupData.group_name} group.`;
                            const title = 'Notification';
                            const notificationType = 'group_create';
                            const payloadData = {
                                type: 'group_create',
                                message,
                                group_id,
                                group_name: getGroupData.group_name,
                                group_type: getGroupData.group_type,
                            };
                            const payload = JSON.stringify(payloadData);
                            if (receiverDeviceType === 1) {
                                try {
                                    await SendNotification(receiverDeviceToken, message, title, payload, notificationType);
                                } catch (error) {
                                    console.error('Error sending Android notification:', error);
                                }
                            } else if (receiverDeviceType === 2) {
                                sendJunoNotificationIOS(receiverDeviceToken, message, title, payload); // Implement this function accordingly
                            }
                        } else {
                            console.error(`User with ID ${memberId} does not have a valid device token. Skipping notification.`);
                        }
                    } else {
                        console.error(`User with ID ${memberId} not found in the database. Skipping notification.`);
                    }
                }
                return callback(null, { status: HttpCodes["API_SUCCESS"], msg: "MemberAdded", code: HttpCodes.OK, data: [], });
            }
        } catch (error) {
            console.log(error, "error.....");
            return callback(null, {
                status: HttpCodes["API_FAILURE"], msg: "SomeThingWentWrong", code: HttpCodes["BAD_REQUEST"], data: [],
            });
        }
    }
    //remove group member
    async removeGroupMember(req, callback) {
        try {
            const user_id = req.body.user_id;
            const group_id = req.body.group_id;
            const application_type = parseInt(req.body.application_type);
            const group_member_id = parseInt(req.body.group_member_id);
            if (application_type !== 2) {
                return callback(null, {
                    status: HttpCodes["API_FAILURE"], msg: "InvalidApplicationType", code: HttpCodes["BAD_REQUEST"], data: [],
                });
            }
            // Get group data
            const groupData = await models.GroupMaster.findOne({
                where: { group_id: group_id },
            });
            if (!groupData) {
                return callback(null, {
                    status: HttpCodes["API_FAILURE"], msg: "GroupReferenceIdDoesNotExist", code: HttpCodes["BAD_REQUEST"], data: [],
                });
            }
            // Get the existing group member data
            const existingGroupMember = await models.GroupMember.findOne({
                where: { group_id: group_id, user_id: group_member_id },
            });
            if (!existingGroupMember) {
                return callback(null, {
                    status: HttpCodes["API_FAILURE"], msg: "GroupMemberNotFound", code: HttpCodes["BAD_REQUEST"], data: [],
                });
            }
            // Check if user is the group owner
            if (user_id === existingGroupMember.group_owner_id) {
                return callback(null, {
                    status: HttpCodes["API_FAILURE"], msg: "GroupOwnerCannotBeUpdated", code: HttpCodes["BAD_REQUEST"], data: [],
                });
            }
            // Check if the target group member exists
            const targetGroupMember = await models.GroupMember.findOne({
                where: { user_id: group_member_id },
            });
            if (!targetGroupMember) {
                return callback(null, {
                    status: HttpCodes["API_FAILURE"], msg: "NotAmember", code: HttpCodes["BAD_REQUEST"], data: [],
                });
            }
            // Update the group member
            const removeGroupMember = await models.GroupMember.destroy(
                { where: { user_id: group_member_id } }
            );
            if (removeGroupMember) {
                return callback(null, {
                    status: HttpCodes["API_SUCCESS"], msg: "RemoveMember", code: HttpCodes.OK, data: removeGroupMember,
                });
            }
        } catch (error) {
            console.log(error, "error.....");
            return callback(null, {
                status: HttpCodes["API_FAILURE"], msg: "SomethingWentWrong", code: HttpCodes["BAD_REQUEST"], data: [],
            });
        }
    }
    //store group message 
    async StoreGroupMessages(req, callback) {
        try {
            const user_id = req.body.user_id;
            const group_id = req.body.group_id;
            const group_message = req.body.group_message;
            const application_type = parseInt(req.body.application_type);
            let reply_message_id = req.body.reply_message_id;
            let language_code = req.body.language_code;
            let tags = req.body.tags;
            if (application_type !== 2) {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: HttpCodes['BAD_REQUEST'], data: {} });
            }
            if (!reply_message_id || reply_message_id === '') {
                reply_message_id = null;
            }
            if (!tags || tags === '') {
                tags = '[]';
            }
            let groupMemberArray = [];
            let newgroupMemberArray = [];
            let getGroupData = await models.GroupMaster.findOne({ where: { group_id: group_id } });
            if (getGroupData) {
                let getData = await models.GroupMember.findAll({ where: { group_id: group_id } });
                let group_type = getGroupData.group_type;
                groupMemberArray.push(getGroupData.group_owner_id);
                if (getData.length >= 0) {
                    for (let i = 0; i < getData.length; i++) {
                        groupMemberArray.push(getData[i].user_id);
                    }
                }
                if (group_type === 2) {
                    const isUserInGroup = groupMemberArray.some(memberId => memberId === user_id);
                    if (!isUserInGroup) {
                        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'NoLongerInGroup', code: HttpCodes['BAD_REQUEST'], data: {} });
                    }
                }
                let insertedMessages = [];
                for (const messageObj of group_message) {
                    const { group_message, language_code } = messageObj;
                    const memberId = messageObj.user_id;
                    const insertGroupMessageArray = {
                        group_id,
                        user_id: memberId,
                        sender_id: req.body.user_id,
                        group_message,
                        application_type,
                        language_code: language_code || '',
                        reply_message_id: reply_message_id,
                        tags: tags || '',
                        created_date: await getEpoch(),
                        updated_date: await getEpoch()
                    };
                    const insertGroupMessage = await models.GroupMessage.create(insertGroupMessageArray);
                    const senderInfo = await models.GroupMessage.findOne({
                        where: {
                            group_message_id: insertGroupMessage.group_message_id // Use the inserted message ID
                        },
                        include: [
                            {
                                model: models.User,
                                as: 'senderInfo',
                                attributes: ['user_id', 'profile_picture', 'user_name', 'language_code'],
                                required: false
                            },
                        ],
                    });
                    const reply = reply_message_id
                        ? await models.GroupMessage.findOne({
                            attributes: ['group_message_id', 'group_message', 'created_date'], // Specify the attributes you want
                            where: { group_message_id: reply_message_id },
                            include: [
                                {
                                    model: models.User,
                                    as: 'senderInfo',
                                    attributes: ['user_id', 'profile_picture', 'user_name', 'language_code'],
                                    required: false
                                }
                            ]
                        })
                        : null;
                    insertGroupMessage.dataValues.senderInfo = senderInfo.senderInfo; // Add senderInfo to the insertGroupMessage
                    insertGroupMessage.dataValues.reply = reply; // Add senderInfo to the insertGroupMessage
                    insertedMessages.push(insertGroupMessage);
                }
                if (insertedMessages.length > 0) {
                    newgroupMemberArray.push(getGroupData.group_owner_id);
                    for (let i = 0; i < getData.length; i++) {
                        newgroupMemberArray.push(getData[i].user_id);
                    }
                    const getsenderData = await models.User.findOne({
                        attributes: ['user_name'],
                        where: { user_id: user_id }
                    });
                    const dbUserName = getsenderData ? getsenderData.user_name : '';
                    // Assuming newgroupMemberArray is the array you want to filter
                    let filteredMemberArray = newgroupMemberArray.filter(member => member !== user_id);
                    if (filteredMemberArray || filteredMemberArray.length >= 0) {
                        for (const member of filteredMemberArray) {
                            const getUserInfo = await models.User.findOne({
                                attributes: ['device_type_translate', 'device_token_translate'],
                                where: { user_id: member } // Use user_id property
                            });
                            if (getUserInfo) {
                                // Send notification to the group member
                                const receiverDeviceType = getUserInfo.device_type_translate;
                                const receiverDeviceToken = getUserInfo.device_token_translate;
                                if (receiverDeviceToken) {
                                    const message = `${dbUserName} posted in the ${getGroupData.group_name} group`;
                                    const title = 'Group Message';
                                    const notificationType = 'group_message';
                                    const payloadData = {
                                        type: 'group_chat',
                                        message,
                                        group_name: getGroupData.group_name,
                                        group_type: getGroupData.group_type,
                                        group_id
                                    };
                                    const payload = JSON.stringify(payloadData);
                                    // Send Android Notification
                                    if (receiverDeviceType === 1) {
                                        // sendJunoNotificationAndroid(receiverDeviceToken, message, title, payload, notificationType); // Implement this function accordingly
                                        try {
                                            await SendNotification(receiverDeviceToken, message, title, payload, notificationType);
                                        } catch (error) {
                                            console.error('Error sending Android notification:', error);
                                        }
                                    } else if (receiverDeviceType === 2) {

                                        sendJunoNotificationIOS(receiverDeviceToken, message, title, payload); // Implement this function accordingly
                                    }
                                } else {
                                    console.error(`User with ID ${member} does not have a valid device token. Skipping notification.`);
                                }
                            } else {
                                console.error(`User with ID ${member} not found in the database. Skipping notification.`);
                            }
                        }
                    }
                    return callback(null, {
                        status: HttpCodes["API_SUCCESS"], msg: "GroupMsgSuccesss", code: HttpCodes.OK, data: insertedMessages,
                    });
                } else {
                    return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: HttpCodes['BAD_REQUEST'], data: {} });
                }
            } else {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'GroupReferenceDoesNotExist', code: HttpCodes['BAD_REQUEST'], data: {} });
            }
        } catch (error) {
            console.log("error in store", error)
            return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: HttpCodes['BAD_REQUEST'], data: {} });
        }
    }
    //update group name
    async UpdateGroupName(req, callback) {
        try {
            const user_id = req.user;
            const group_name = req.body.group_name;
            const application_type = parseInt(req.body.application_type);
            const group_id = parseInt(req.body.group_id);
            if (application_type !== 2) {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: HttpCodes['BAD_REQUEST'], data: [] });
            }
            const getGroupData = await models.GroupMaster.findOne({
                where: { group_id }
            });
            if (!getGroupData) {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'GroupReferenceDoesNotExist', code: HttpCodes['BAD_REQUEST'], data: [] });
            }
            const updateGroup = await models.GroupMaster.update(
                {
                    group_name,
                    updated_date: await getEpoch(),
                }, {
                where: { group_id }
            });
            if (updateGroup[0] === 1) {
                return callback(null, { status: HttpCodes['API_SUCCESS'], msg: 'GroupUpdateNameSuccess', code: HttpCodes.OK, data: [] });
            } else {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: HttpCodes['BAD_REQUEST'], data: [] });
            }
        } catch (error) {
            console.log(error, 'error.....');
            return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: HttpCodes['BAD_REQUEST'], data: [] });
        }
    }
    //update group image
    async UpdateGroupImage(req, callback) {
        try {
            const user_id = req.user;
            const application_type = parseInt(req.body.application_type);
            const group_id = parseInt(req.body.group_id);
            if (application_type !== 2) {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: HttpCodes['BAD_REQUEST'], data: {} });
            }
            const getGroupData = await models.GroupMaster.findOne({
                where: { group_id }
            });
            if (!getGroupData) {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'GroupReferenceDoesNotExist', code: HttpCodes['BAD_REQUEST'], data: {} });
            }
            const dbGroupImage = getGroupData.group_image;
            const dbGroupQR = getGroupData.group_qr_image;
            let groupImage = {};
            // const dbGroupMemberId = getGroupData.group_member_id;
            let uploadGroupImage = dbGroupImage;
            if (req.file) {
                const fileName = `${Date.now()}_${req.file.originalname}`;
                uploadGroupImage = await fileUploadToS3(fileName, process.env.S3_BUCKET_NAME, 'group_files/', req.file.buffer);
                if (!uploadGroupImage) {
                    return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'UploadProperImage', code: HttpCodes['BAD_REQUEST'], data: {} });
                }
                if (dbGroupImage) {
                    const urlParts = dbGroupImage.split('/');
                    const objectKey = urlParts[urlParts.length - 1];
                    // Delete the old group image from S3
                    const deleteImageResult = await deleteImageFromS3(process.env.S3_BUCKET_NAME, `group_files/${objectKey}`);
                    if (!deleteImageResult.status) {
                        console.error('Error deleting old group image:', deleteImageResult.data);
                    }
                }
            }
            let groupImageValue = uploadGroupImage ? uploadGroupImage.data : '';
            const updateGroup = await models.GroupMaster.update(
                {
                    group_image: groupImageValue,
                    group_owner_id: user_id,
                    updated_date: await getEpoch(),
                }, {
                where: { group_id }
            });
            groupImage['group_image'] = groupImageValue;
            if (updateGroup[0] === 1) {
                return callback(null, { status: HttpCodes['API_SUCCESS'], msg: 'GroupImageUpdateSuccess', code: HttpCodes.OK, data: groupImage });
            } else {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: HttpCodes['BAD_REQUEST'], data: {} });
            }
        } catch (error) {
            console.log(error, 'error.....');
            return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: HttpCodes['BAD_REQUEST'], data: {} });
        }
    }
    //update group type
    async UpdateGroupType(req, callback) {
        try {
            const user_id = req.user;
            const application_type = parseInt(req.body.application_type);
            const group_id = parseInt(req.body.group_id);
            const group_type = parseInt(req.body.group_type);
            if (application_type !== 2) {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: HttpCodes['BAD_REQUEST'], data: [] });
            }
            if (group_type > 2 || group_type <= 0) {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidGroupType', code: HttpCodes['BAD_REQUEST'], data: [] });
            }
            const getGroupData = await models.GroupMaster.findOne({
                where: { group_id }
            });
            if (!getGroupData) {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'GroupReferenceDoesNotExist', code: HttpCodes['BAD_REQUEST'], data: [] });
            }
            const checkUserOwnGroup = await models.GroupMaster.findOne({
                where: { group_id, group_owner_id: user_id }
            });
            if (!checkUserOwnGroup) {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'NotgroupOwner', code: HttpCodes['BAD_REQUEST'], data: [] });
            }
            const updateGroup = await models.GroupMaster.update(
                {
                    group_type,
                    updated_date: await getEpoch(),
                }, {
                where: { group_id }
            });
            if (updateGroup[0] === 1) {
                return callback(null, { status: HttpCodes['API_SUCCESS'], msg: 'GroupUpdateTypeSuccess', code: HttpCodes.OK, data: [] });
            } else {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: HttpCodes['BAD_REQUEST'], data: [] });
            }
        } catch (error) {
            console.log(error, 'error.....');
            return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'SomeThingWentWrong', code: HttpCodes['BAD_REQUEST'], data: [] });
        }
    }
    //remove group message 
    async RemoveGroupMessages(req, callback) {
        try {
            const application_type = parseInt(req.body.application_type);
            const user_id = req.body.user_id;
            const group_id = req.body.group_id;
            if (!group_id) {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'groupIdRequired', code: HttpCodes['BAD_REQUEST'] });
            }
            // Check if application type is valid
            if (application_type > 2 || application_type <= 0) {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: HttpCodes['BAD_REQUEST'] });
            }
            // Get group info
            const getGroupInfo = await models.GroupMaster.findOne({ where: { 'group_id': group_id } });
            if (!getGroupInfo) {
                return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'GroupReferenceIdDoesNotExist', code: HttpCodes['BAD_REQUEST'], data: [] });
            }
            const groupType = getGroupInfo.group_type;
            const groupOwner = getGroupInfo.group_owner_id;
            if (groupType === 2) {
                const getTableData = await models.GroupMessage.findAll({ where: { 'group_id': group_id, 'user_id': user_id } });
                if (getTableData && getTableData.length > 0) {
                    await models.GroupMessage.update({ 'is_deleted': 1 }, { where: { 'group_id': group_id, 'user_id': user_id } });
                    return callback(null, { 'status': HttpCodes['API_SUCCESS'], 'msg': 'GroupMessageRemoved', code: HttpCodes['OK'], data: [] });
                } else {
                    return callback(null, { 'status': HttpCodes['API_SUCCESS'], 'msg': 'NoGroupMessageFound', code: HttpCodes['OK'], data: [] });
                }
            } else {
                const getTableData = await models.GroupMessage.findAll({ where: { 'group_id': group_id } });
                if (!getTableData || getTableData.length == 0) {
                    return callback(null, { 'status': HttpCodes['API_SUCCESS'], 'msg': 'NoGroupMessageFound', code: HttpCodes['OK'], data: [] });
                }
                const updateArray = {};
                if (groupOwner === user_id) {
                    updateArray['is_deleted'] = 1;
                } else {
                    updateArray['public_deleted_flag'] = 1;
                }
                if (getGroupInfo.group_member_id) {
                    updateArray['is_deleted'] = 1;
                }
                await models.GroupMessage.update(updateArray, { where: { 'group_id': group_id } });
                return callback(null, { 'status': HttpCodes['API_SUCCESS'], 'msg': 'GroupMessageRemoved', code: HttpCodes['OK'], data: [] });
            }
        } catch (error) {
            console.error(error.message, 'removeGroupMessage');
            return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'SomeThingWentWrong', code: HttpCodes['BAD_REQUEST'], data: [] });
        }
    }
}