
"use strict";
const models = require('./../models/index');
import { HttpCodes } from "../helpers/responseCodes";
const db = require("../models/index");
const Op = db.Sequelize.Op;

export default class DeviceService {
  constructor() {
    this.GetPhraseCategory = this.GetPhraseCategory.bind(this);
    this.GetPhrases = this.GetPhrases.bind(this);
  }
  //get pharse category
  async GetPhraseCategory(req, callback) {
    try {
      let user_id = req.body.user_id;
      let application_type = parseInt(req.query.application_type);
      const orderBy = 'created_date';
      const order = 'ASC';
      let phrase_from = req.query.phrase_from;
      let phrase_to = req.query.phrase_to;
      const getUserLang = req.headers['lang'] || 'en';
      //validation check for user enter out of language in array
      const supportedLanguages = ['am', 'ar', 'bg', 'ca', 'cs', 'da', 'de', 'el',
        'en', 'es', 'fa', 'fi', 'fr', 'ga', 'ha', 'he', 'hu', 'id', 'ig', 'it', 'ja', 'ko', 'ku', 'lt',
        'lv', 'ms', 'nb', 'nl', 'pa', 'pl', 'prs', 'ps', 'pt', 'ro', 'ru', 'sk', 'sq', 'sv', 'sw',
        'th', 'ti', 'tr', 'uk', 'ur', 'vi', 'yo', 'zh'];
      const userLang = supportedLanguages.includes(getUserLang)
        ? getUserLang
        : 'en';
      //validation for from language
      const phraserFomLang = supportedLanguages.includes(phrase_from)
        ? phrase_from
        : 'en';
      //validation for to language
      const phraseToLang = supportedLanguages.includes(phrase_to)
        ? phrase_to
        : 'en';
      if (application_type !== 2) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      const getphrasesCategory = await models.PhrasesCategory.findAll({
        order: [[orderBy, order]],
      });
      const phrasesCategory = getphrasesCategory.map((phrase) => ({
        phrase_cat_id: phrase.phrase_cat_id,
        phrase_category: phrase[`phrase_category_${userLang}`],
        phrase_from: phrase[`phrase_category_${phraserFomLang}`],
        phrase_to: phrase[`phrase_category_${phraseToLang}`],
        phrase_image: phrase.phrase_image,
        created_date: phrase.created_date,
        updated_date: phrase.updated_date
      }))
      if (!phrasesCategory || phrasesCategory.length == 0) {
        return callback(null, { status: HttpCodes['API_SUCCESS'], msg: 'NoDataFound', code: HttpCodes['OK'], data: [] });
      }
      return callback(null, { 'status': HttpCodes['API_SUCCESS'], 'msg': 'PhraseCategory', code: HttpCodes['OK'], data: phrasesCategory });
    } catch (error) {
      console.log(error.message, "Register");
      return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'SomeThingWentWrong', code: HttpCodes['BAD_REQUEST'], data: [] });
    }
  }
  //get phrases
  async GetPhrases(req, callback) {
    const mylang = []
    try {
      let user_id = req.body.user_id;
      let application_type = parseInt(req.query.application_type);
      let category_id = parseInt(req.query.category_id);
      let phrase_from = req.query.phrase_from;
      let phrase_to = req.query.phrase_to;
      const getUserLang = req.headers['lang'] || 'en';
      //validation check for user enter out of language in array
      const supportedLanguages = ['am', 'ar', 'bg', 'ca', 'cs', 'da', 'de', 'el',
        'en', 'es', 'fa', 'fi', 'fr', 'ga', 'ha', 'he', 'hu', 'id', 'ig', 'it', 'ja', 'ko', 'ku', 'lt',
        'lv', 'ms', 'nb', 'nl', 'pa', 'pl', 'prs', 'ps', 'pt', 'ro', 'ru', 'sk', 'sq', 'sv', 'sw',
        'th', 'ti', 'tr', 'uk', 'ur', 'vi', 'yo', 'zh'];
      const userLang = supportedLanguages.includes(getUserLang)
        ? getUserLang
        : 'en';
      //validation for from language
      const phraserFomLang = supportedLanguages.includes(phrase_from)
        ? phrase_from
        : 'en';
      //validation for to language
      const phraseToLang = supportedLanguages.includes(phrase_to)
        ? phrase_to
        : 'en';
      if (isNaN(category_id) || !Number.isInteger(category_id)) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidCategoryId', code: HttpCodes['BAD_REQUEST'] });
      }
      const orderBy = 'created_date';
      const order = 'ASC';
      let offsetValue = req.query.offset;
      offsetValue = parseInt(offsetValue);
      if (isNaN(offsetValue)) {
        offsetValue = 0;
      }
      if (application_type !== 2) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      const phrasesCategory = await models.PhrasesCategory.findOne({
        where: { phrase_cat_id: category_id },
      });
      if (!phrasesCategory) {
        return callback(null, { status: HttpCodes['API_SUCCESS'], msg: 'NoDataFound', code: HttpCodes['OK'], data: [] });
      }
      // Get pharase data
      const getSubCategory = await models.PhrasesSubCategory.findAll({
        where: { phrase_cat_id: category_id },
      });
      const phraseData = [];
      if (getSubCategory.length > 0) {
        for (const subCategory of getSubCategory) {
          const subCategoryId = subCategory.phrase_sub_cat_id;
          const getPhrases = await models.Phrases.findAll({
            where: { phrase_sub_cat_id: subCategoryId },
          });
          const phraseList = getPhrases.map((phrase) => ({
            phrase_id: phrase.phrase_id,
            phrase: phrase[`phrases_${userLang}`],
            phrase_from: phrase[`phrases_${phraserFomLang}`],
            phrase_to: phrase[`phrases_${phraseToLang}`]
          }));
          phraseData.push({
            sub_category_name: subCategory[`sub_category_${userLang}`],
            phrase_sub_cat_id: subCategory.phrase_sub_cat_id,
            sub_category: phraseList,
          });
        }
        return callback(null, { status: HttpCodes['API_SUCCESS'], msg: 'PhraseList', code: HttpCodes['OK'], data: phraseData });
      } else {
        return callback(null, { status: HttpCodes['API_SUCCESS'], msg: 'NoDataFound', code: HttpCodes['OK'], data: [] });
      }
    } catch (error) {
      console.log(error.message, "Register");
      return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'SomeThingWentWrong', code: HttpCodes['BAD_REQUEST'], data: [] });
    }
  }
}