"use strict";
const models = require('./../models/index');
import commonHelper from "../helpers/common";
import { HttpCodes } from "../helpers/responseCodes";
const ejs = require('ejs');
const fs = require('fs');
const bcrypt = require('bcrypt');
const { getEpoch, ComparePassword, UpdateUserFields, fileUploadToS3, deleteImageFromS3, pushEmail } = new commonHelper();
const db = require("../models/index");
const Op = db.Sequelize.Op;
export default class PreferenceService {
  constructor() {
    this.UpdateRegion = this.UpdateRegion.bind(this);
    this.UpdateLanguageCode = this.UpdateLanguageCode.bind(this);
    this.TransferOwnership = this.TransferOwnership.bind(this);
    this.UpdateEmail = this.UpdateEmail.bind(this);
    this.UpdatePassword = this.UpdatePassword.bind(this);
    this.UpdateName = this.UpdateName.bind(this);
    this.DeleteProfile = this.DeleteProfile.bind(this);
    this.UpdateVoicePreference = this.UpdateVoicePreference.bind(this);
    this.UpdateProfilePicture = this.UpdateProfilePicture.bind(this);
  }
  //update region
  async UpdateRegion(req, callback) {
    try {
      let user_id = req.body.user_id;
      let region = req.body.region;
      let application_type = parseInt(req.body.application_type);
      if (application_type > 2 || application_type <= 0) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      const updatedUser = await models.User.update(
        { region: region },
        {
          where: {
            user_id: user_id,
          },
        }
      );
      if (updatedUser[0] === 0) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'UpdateRegionFailed', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      return callback(null, { 'status': HttpCodes['API_SUCCESS'], 'msg': 'RegionUpdatedSuccess', code: HttpCodes['OK'], data: [] });
    } catch (error) {
      console.log(error.message, "UpdateRegion");
      return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'UpdateRegionFailed', code: HttpCodes['BAD_REQUEST'], data: [] });
    }
  }
  //update language code
  async UpdateLanguageCode(req, callback) {
    try {
      let user_id = req.body.user_id;
      let language_code = req.body.language_code;
      let application_type = parseInt(req.body.application_type);
      if (application_type > 2 || application_type <= 0) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      // Update user data
      const updatedUser = await models.User.update(
        { language_code: language_code },
        {
          where: {
            user_id: user_id,
          },
        }
      );
      if (updatedUser[0] === 0) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'UpdateLanguageCodeFailed', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      return callback(null, { 'status': HttpCodes['API_SUCCESS'], 'msg': 'LanguageCodeUpdated', code: HttpCodes['OK'], data: [] });
    } catch (error) {
      console.log(error.message, "UpdateLanguage");
      return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'UpdateLanguageCodeFailed', code: HttpCodes['BAD_REQUEST'], data: [] });
    }
  }
  // transfer ownership for device
  async TransferOwnership(req, callback) {
    try {
      let user_email = req.body.email.toLowerCase();
      let user_id = req.body.user_id;
      let application_type = parseInt(req.body.application_type);
      if (application_type > 2 || application_type <= 0) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      // Check if the user is registered as a premium member
      const checkRegistereAsPremium = await models.User.findOne({
        where: {
          user_id: user_id,
          subscription_plan: 'register_as_premium'
        }
      });
      if (!checkRegistereAsPremium) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'NotPremiumMember', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      const checkDeviceRegister = await models.DeviceRegister.findOne({
        where: {
          user_id: user_id
        }
      });
      if (!checkDeviceRegister) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'deviceNotRegistered', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      const checkUserFromEmail = await models.User.findOne({
        where: {
          user_email: user_email,
        }
      });
      if (!checkUserFromEmail) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'EmailAddressNotFound', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      const owner_subscription_plan = checkRegistereAsPremium.subscription_plan;
      const owner_subscription_plan_device_type = checkRegistereAsPremium.subscription_plan_device_type;
      const owner_subscribed_on = checkRegistereAsPremium.subscribed_on;
      const owner_email = checkRegistereAsPremium.user_email.toLowerCase();
      const passedEmail = user_email.toLowerCase();
      if (passedEmail === owner_email) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'CantTransferOwnershipToself', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      // Check if the user to whom ownership is being transferred is already a premium member
      const transferOwnerSubscriptionPlan = checkUserFromEmail.subscription_plan;
      if (transferOwnerSubscriptionPlan === 'register_as_premium') {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'AlreadyPremiumMember', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      const transferOwnershipUserId = checkUserFromEmail.user_id;
      // Update device register master entry
      const updateDRMArray = await models.DeviceRegister.update(
        { email_address: user_email },
        {
          where: {
            user_id: transferOwnershipUserId,
          },
        }
      );
      const updateTransferUserOwnerWhereArray = await models.User.update(
        {
          subscription_plan: owner_subscription_plan,
          subscription_plan_device_type: owner_subscription_plan_device_type,
          subscribed_on: owner_subscribed_on,
          is_login_translate: null,
          login_access_token_translate: null,
          device_token_translate: null,
        },
        {
          where: {
            user_id: transferOwnershipUserId,
          },
        }
      );
      const updateOwnerArray = await models.User.update(
        { subscription_plan: 'free' },
        {
          where: {
            user_id: transferOwnershipUserId,
          },
        }
      );
      const addTransferOwnershipLog = await models.TransferOwnership.create({ user_id: user_id, transfer_to_user_id: transferOwnershipUserId, created_date: await getEpoch(), updated_date: await getEpoch() });
      if (addTransferOwnershipLog) {
        const getUpdatedRecord = await models.User.findOne({
          where: {
            user_email: user_email,
          }
        });
        return callback(null, { 'status': HttpCodes['API_SUCCESS'], 'msg': 'transferOwnershipupdated', code: HttpCodes['OK'], data: getUpdatedRecord });
      } else {
        return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'SomeThingWentWrong', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
    } catch (error) {
      console.log(error.message, "transferOwnership");
      return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'transferOwnershipFailed', code: HttpCodes['BAD_REQUEST'], data: [] });
    }
  }
  //update email
  async UpdateEmail(req, callback) {
    try {
      const user_id = req.body.user_id;
      const user_email = req.body.email;
      const application_type = parseInt(req.body.application_type);
      if (application_type > 2 || application_type <= 0) {
        return callback(null, {
          status: HttpCodes['API_FAILURE'],
          msg: 'Invalidapplicationtype',
          code: HttpCodes['BAD_REQUEST'],
          data: []
        });
      }
      const get_userdata = await models.User.findOne({
        where: {
          user_id: user_id,
        }
      });
      const db_user_email = get_userdata.user_email;
      if (user_email !== db_user_email) {
        const checkEmailExist = await models.User.findOne({
          where: {
            user_email: user_email,
          }
        });
        if (checkEmailExist) {
          return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'EmailAlreadyExists', code: HttpCodes['BAD_REQUEST'], data: [] });
        } else {
          const updates = { user_email: user_email, is_verified: 0 };
          const updatedUser = await UpdateUserFields(user_id, updates, application_type);
          if (updatedUser) {
            const activation_key = updatedUser.activation_key;
            const user_name = updatedUser.user_name;
            const base_url = (process.env.NODE_ENV === 'local') ? 'http://localhost:6012' : 'https://' + process.env.HOST;
            // Start: Registration Mail content Here
            const mailData = {
              user_name: user_name,
              activation_key: activation_key,
              baseUrl: base_url,
            };
            const templatePath = './views/emailTemplate.ejs';
            // Read the EJS template file
            const template = fs.readFileSync(templatePath, 'utf8');
            const subject = 'Please confirm your email address';
            try {
              await pushEmail(mailData, user_email, subject, template);
              // Email sent successfully
              return callback(null, { status: HttpCodes.API_SUCCESS, msg: 'EmailUpdated', code: HttpCodes.OK, data: [] });
            } catch (error) {
              // Error sending email
              return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'Somethingwentwrong', code: HttpCodes.OK, data: [] });
            }
          }
        }
      } else {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'SameEmailaddress', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
    } catch (error) {
      console.log(error.message, "UpdateEmail");
      return callback(null, {
        status: HttpCodes['API_FAILURE'], msg: 'UpdateEmailFailed', code: HttpCodes['BAD_REQUEST'], data: []
      });
    }
  }
  //update password
  async UpdatePassword(req, callback) {
    try {
      let user_id = req.body.user_id;
      let old_password = req.body.old_password;
      let user_password = req.body.password;
      let application_type = parseInt(req.body.application_type);
      if (application_type > 2 || application_type <= 0) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      // Check if the user_id exists
      const user = await models.User.findOne({
        where: {
          user_id: user_id,
        },
      });
      if (!user) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'UserIdNotExist', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      const passwordMatch = await ComparePassword(old_password, user.user_password);
      if (!passwordMatch) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'passwordNotMatch', code: HttpCodes['BAD_REQUEST'], data: [] });
      } else {
        const salt = await bcrypt.genSalt(10);
        const hashedPassword = await bcrypt.hash(user_password, salt);
        const update_email_result = await models.User.update(
          { user_password: hashedPassword },
          {
            where: {
              user_id: user_id,
            },
          }
        );
        if (update_email_result[0] == 1) {
          return callback(null, { status: HttpCodes['API_SUCCESS'], msg: 'passwordUpdated', code: HttpCodes.OK, data: [] });
        } else {
          return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'UpdatePasswordFailed', code: HttpCodes['BAD_REQUEST'], data: [] });
        }
      }
    } catch (error) {
      console.log(error.message, "UpdatePassword");
      return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'UpdatePasswordFailed', code: HttpCodes['BAD_REQUEST'], data: [] });
    }
  }
  //update name
  async UpdateName(req, callback) {
    try {
      let user_id = req.body.user_id;
      let user_name = req.body.name;
      let title = req.body.title;
      let application_type = parseInt(req.body.application_type);
      if (application_type > 2 || application_type <= 0) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      const updates = { user_name: user_name, title: title };
      const updatedUser = await UpdateUserFields(user_id, updates, application_type);
      if (updatedUser) {
        return callback(null, { status: HttpCodes.API_SUCCESS, msg: 'NameUpdated', code: HttpCodes.OK, data: [] });
      } else {
        return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'SomeThingWentWrong', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
    } catch (error) {
      console.log(error.message, "UpdateName");
      return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'UpdateNameFailed', code: HttpCodes['BAD_REQUEST'], data: [] });
    }
  }
  //delete profile 
  async DeleteProfile(req, callback) {
    try {
      let user_id = req.body.user_id;
      let application_type = parseInt(req.body.application_type);
      if (application_type > 2 || application_type <= 0) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      const updateUserDataArray = {
        is_login_translate: null,
        login_access_token_translate: null,
        device_token_translate: null,
        is_deleted_translate: 1
      };
      const user = await models.User.findOne({
        where: {
          user_id: user_id,
          is_deleted_translate: 1
        },
      });
      if (user) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'AccountAlreadydeleted', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      // Update the user's data
      await models.User.update(updateUserDataArray, { where: { user_id } });
      return callback(null, { status: HttpCodes.API_SUCCESS, msg: 'ProfileDeleted', code: HttpCodes.OK, data: [] });
    } catch (error) {
      console.log(error.message, "UpdateName");
      return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'ProfileDeleteFailed', code: HttpCodes['BAD_REQUEST'], data: [] });
    }
  }
  //update voice preference
  async UpdateVoicePreference(req, callback) {
    try {
      let user_id = req.body.user_id;
      let application_type = parseInt(req.body.application_type);
      const voice_preference = req.body.voice_preference;
      if (application_type > 2 || application_type <= 0) {
        return callback(null, { status: HttpCodes.API_FAILURE, msg: 'InvalidApplicationType', code: HttpCodes.BAD_REQUEST, data: [] });
      }
      const voiceArray = ['Male', 'Female', 'male', 'female', 'Default', 'default'];
      if (!voiceArray.includes(voice_preference)) {
        return callback(null, { status: HttpCodes.API_FAILURE, msg: 'InvalidVoicePreference', code: HttpCodes.BAD_REQUEST, data: [] });
      }
      // Update user voice preference
      const updateData = { voice_preference: voice_preference.toLowerCase() };
      const updatedUser = await models.User.update(updateData, {
        where: { user_id }
      });
      if (updatedUser[0] === 1) {
        return callback(null, {
          status: HttpCodes.API_SUCCESS, msg: 'VoicePreferenceUpdated', code: HttpCodes.OK, data: []
        });
      } else {
        return callback(null, {
          status: HttpCodes.API_FAILURE, msg: 'UpdateVoicePreferenceFailed', code: HttpCodes.BAD_REQUEST, data: []
        });
      }
    } catch (error) {
      console.log(error.message, "UpdateVoicePreference");
      return callback(null, {
        status: HttpCodes.API_FAILURE, msg: 'UpdateVoicePreferenceFailed', code: HttpCodes.BAD_REQUEST, data: []
      });
    }
  }
  //update profile picture
  async UpdateProfilePicture(req, callback) {
    try {
      var user_id = req.user;
      console.log(user_id, "user_id")
      const application_type = parseInt(req.body.application_type);
      if (application_type > 2 || application_type <= 0) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      if (!req.file) {
        return { status: false, msg: 'Please upload user profile picture', data: [] };
      }
      const bucketName = process.env.S3_BUCKET_NAME;
      const folderName = 'profile_pictures/';
      const fileName = `${Date.now()}_${req.file.originalname}`;
      // Upload the file to S3
      const fileBuffer = req.file.buffer;
      const s3UploadResult = await fileUploadToS3(fileName, bucketName, folderName, fileBuffer);
      if (s3UploadResult.status == true) {
        const user_profile_picture = s3UploadResult.data;
        const userData = await models.User.findOne({
          where: {
            user_id: user_id,
          },
        });
        if (userData && userData.profile_picture) {
          const urlParts = userData.profile_picture.split('/');
          const objectKey = urlParts[urlParts.length - 1];
          await deleteImageFromS3(bucketName, `profile_pictures/${objectKey}`);
        }
        const updatedProfile = await models.User.update(
          { profile_picture: user_profile_picture },
          {
            where: {
              user_id: user_id,
            },
          }
        );
        if (updatedProfile[0] == 1) {
          return callback(null, { 'status': HttpCodes['API_SUCCESS'], 'msg': 'profilePictureUpdated', code: HttpCodes['OK'], data: s3UploadResult });
        } else {
          return callback(null, { status: HttpCodes.API_FAILURE, msg: 'FailedtoUpdate', code: HttpCodes.BAD_REQUEST, data: [] });
        }
      } else {
        return callback(null, { status: HttpCodes.API_FAILURE, msg: 'FailedtoUpload', code: HttpCodes.BAD_REQUEST, data: [] });
      }
    } catch (error) {
      console.error('Error:', error);
      return callback(null, { status: HttpCodes.API_FAILURE, msg: 'SomeThingWentWrong', code: HttpCodes.BAD_REQUEST, data: [] });
    }
  };
}