"use strict";
const models = require('./../models/index');
import commonHelper from "../helpers/common";
import { HttpCodes } from "../helpers/responseCodes";
const bcrypt = require('bcrypt');
const { getEpoch, GetUserDataTranslate } = new commonHelper();
const db = require("../models/index");
const Op = db.Sequelize.Op;

export default class SubscriptionService {

  constructor() {
    this.AddSubscriptionPlan = this.AddSubscriptionPlan.bind(this);
    this.GetServices = this.GetServices.bind(this);
    this.GetServiceFeatures = this.GetServiceFeatures.bind(this);
  }
  //add subscription plan
  async AddSubscriptionPlan(req, callback) {
    try {
      let user_id = req.body.user_id;
      let subscription_plan_device_type = req.body.subscription_plan_device_type;
      let subscription_plan = req.body.subscription_plan;
      let application_type = parseInt(req.body.application_type);
      if (application_type !== 2) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      const userData = await GetUserDataTranslate(user_id);
      // Update subscription plan if needed
      if (userData.subscription_plan !== 'register_as_premium') {
        const updateData = {
          subscription_plan: subscription_plan.toLowerCase(),
          subscription_plan_device_type: subscription_plan_device_type.toLowerCase(),
          subscribed_on: await getEpoch(),
          updated_date: await getEpoch()
        };
        const result = await models.User.update(updateData, {
          where: {
            user_id: user_id,
          },
        });
        if (result[0] !== 1) {
          return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'SomeThingWentWrong', code: HttpCodes['BAD_REQUEST'], data: [] });
        } else {
          return callback(null, { 'status': HttpCodes['API_SUCCESS'], 'msg': 'subscriptionSuccess', code: HttpCodes['OK'], data: [] });
        }
      }
    } catch (error) {
      console.log(error.message, "Register");
      return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'subscriptionFailed', code: HttpCodes['BAD_REQUEST'], data: [] });
    }
  }
  //get services
  async GetServices(req, callback) {
    try {
      const orderBy = 'created_date';
      const order = 'ASC';
      const application_type = parseInt(req.query.application_type);
      const user_id = req.body.user_id;
      if (isNaN(application_type) || application_type !== 2) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      const filter = {
        where: { service_status: 1 },
        order: [[orderBy, order]],
      };
      const getServiceData = await models.Services.findAll(filter);
      if (getServiceData.length === 0) {
        return callback(null, { status: HttpCodes['API_SUCCESS'], msg: 'NoServicesFound', code: HttpCodes['OK'], data: [] });
      }
      return callback(null, { status: HttpCodes['API_SUCCESS'], msg: 'ListDeviceServices', code: HttpCodes['OK'], data: getServiceData });
    } catch (err) {
      console.error('Error fetching device services data:', err);
      return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'ErrorFetchingData', code: HttpCodes['BAD_REQUEST'], data: [] });
    }
  }
  //get service features
  async GetServiceFeatures(req, callback) {
    try {
      const orderBy = 'created_date';
      const order = 'ASC';
      const application_type = parseInt(req.query.application_type);
      const user_id = req.body.user_id;
      if (isNaN(application_type) || application_type !== 2) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      const features = await models.ServiceFeature.findAll();
      if (!features || features.length === 0) {
        return callback(null, { status: HttpCodes['API_SUCCESS'], msg: 'NoServicesFeatureFound', code: HttpCodes['OK'], data: [] });
      }
      const services = await models.Services.findAll({
        where: { service_status: 1 },
        include: [
          {
            model: models.ServiceFeature,
            as: 'Features',
            attributes: ['feature'],
          },
        ],
        order: [[orderBy, order]],
      });
      if (!services || services.length === 0) {
        return callback(null, { status: HttpCodes['API_SUCCESS'], msg: 'NoServicesFound', code: HttpCodes['OK'], data: [] });
      }
      const featureData = [];
      features.forEach(feature => {
        const featureItem = {
          feature_name: feature.feature,
        };
        services.forEach(service => {
          featureItem[service.service_title] = service.Features.some(
            feat => feat.feature === feature.feature
          )
            ? 1
            : 0;
        });
        featureData.push(featureItem);
      });
      return callback(null, { status: HttpCodes['API_SUCCESS'], msg: 'ListFeatures', code: HttpCodes['OK'], data: featureData });
    } catch (err) {
      console.error('Error fetching device services data:', err);
      return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'ErrorFetchingData', code: HttpCodes['BAD_REQUEST'], data: [] });
    }
  }
}