"use strict";
const models = require('./../models/index');
import commonHelper from "../helpers/common";
import { HttpCodes } from "../helpers/responseCodes";
const bcrypt = require('bcrypt');
const fs = require('fs');
import { Sequelize } from 'sequelize';
const { getEpoch, ComparePassword, CreateJwt, generateRandomString, pushEmail, getUserData, addEmailSendInBlue } = new commonHelper();
const db = require("../models/index");
const Op = db.Sequelize.Op;

export default class UserService {
  checkDataMissing: boolean;
  checkType: number;
  user_id: any;

  constructor() {
    this.UserRegister = this.UserRegister.bind(this);
    this.ActivateAccount = this.ActivateAccount.bind(this);
    this.ResendActivation = this.ResendActivation.bind(this);
    this.UserLogin = this.UserLogin.bind(this);
    this.ForgotPassword = this.ForgotPassword.bind(this);
    this.ResetPassword = this.ResetPassword.bind(this);
    this.Logout = this.Logout.bind(this);
  }
  //register user as per application type for mujuno(apptype = 2) and mymanu play (apptype = 1)
  async UserRegister(req, callback) {
    let user_name = req.body.name;
    let user_email = req.body.email.toLowerCase();
    let user_password = req.body.password;
    let device_type = req.body.device_type;
    let device_token = req.body.device_token;
    let application_type = req.body.application_type;
    application_type = parseInt(application_type);
    if (application_type > 2 || application_type <= 0) {
      return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: HttpCodes['BAD_REQUEST'], data: [] });
    }
    let device_token_translate, device_type_translate;
    if (application_type === 1) {
      if (!device_token) {
        device_token = null;
      }
      device_token_translate = null;
      device_type_translate = 0;
    }
    if (application_type === 2) {
      if (!device_token) {
        device_token_translate = null;
      } else {
        device_token_translate = device_token;
      }
      device_token = null;
      device_type_translate = device_type;
    }
    try {
      const activation_key = await generateRandomString(40);
      const salt = await bcrypt.genSalt(10);
      const hashedPassword = await bcrypt.hash(user_password, salt);
      let checkType, user_id, is_translate_app, is_mymanuplay_app, registered_from;
      if (application_type === 1) {
        checkType = 1;
        is_translate_app = 0;
        is_mymanuplay_app = 1;
        registered_from = 1;
      }
      else if (application_type === 2) {
        checkType = 2;
        is_translate_app = 1;
        is_mymanuplay_app = 0;
        registered_from = 2;
      } else {
        is_translate_app = 0;
        is_mymanuplay_app = 0;
        registered_from = 0;
      }
      const user_data = {
        user_name: user_name,
        user_email: user_email,
        user_password: hashedPassword,
        registered_from: registered_from,
        device_type: device_type,
        device_type_translate: device_type_translate,
        device_token: device_token,
        device_token_translate: device_token_translate,
        activation_key: activation_key,
        is_translate_app: is_translate_app,
        is_mymanuplay_app: is_mymanuplay_app,
        language_code: '',
        profile_picture: '',
        created_date: await getEpoch()
      };
      const lowercaseEmail = user_email.toLowerCase();

      const userCount = await models.User.count({
        where: {
          user_email: lowercaseEmail,
        },
      });
      // const userCount = await this.checkEmailExist(lowercaseEmail, checkType);
      if (userCount > 0) {
        const checkUser = await models.User.findAll({
          where: {
            user_email: Sequelize.where(Sequelize.fn('LOWER', Sequelize.col('user_email')), Sequelize.fn('LOWER', user_email))
          },
        });
        if (checkUser.length > 0) {
          const user_db_email = checkUser[0].user_email;
          const user_db_id = checkUser[0].user_id;
          const is_mymanuplay_app_db = checkUser[0].is_mymanuplay_app;
          const is_translate_app_db = checkUser[0].is_translate_app;
          const device_token_db = checkUser[0].device_token;
          const device_token_translate_db = checkUser[0].device_token;
          // const dbIsDeletedTranslate = checkUser[0].is_deleted_translate;
          if (user_db_email.toLowerCase() === user_email.toLowerCase()) {
            if (application_type === 1 && is_mymanuplay_app_db === 1) {
              return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'EmailAccountAlreadyExists', code: HttpCodes.ALREADY_EXIST, data: [] });
            }
            else {
              if (application_type === 1) {
                if (!device_token) {
                  device_token = device_token_db;
                } else {
                  device_token = device_token;
                }
                const updateData = {
                  is_mymanuplay_app: 1,
                  is_translate_app: is_translate_app_db,
                  device_type: device_type,
                  device_token: device_token,
                  updated_date: await getEpoch(),
                };
                this.user_id = await models.User.update(updateData, {
                  where: { user_id: user_db_id },
                });
              }
            }
            if (application_type === 2 && is_translate_app_db === 1) {
              return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'EmailAccountAlreadyExists', code: HttpCodes.ALREADY_EXIST, data: [] });
            } else {
              if (application_type === 2) {
                let device_token_translate;
                if (device_token === '') {
                  device_token_translate = device_token_translate_db;
                } else {
                  device_token_translate = device_token;
                }
                const updateData = {
                  is_translate_app: 1,
                  device_type_translate: device_type_translate,
                  device_token_translate: device_token_translate,
                  updated_date: await getEpoch(),
                  user_name: user_name,
                  user_password: hashedPassword,
                };
                this.user_id = await models.User.update(updateData, {
                  where: { user_id: user_db_id },
                });
              }
            }
            const UserData = await getUserData(user_db_id, application_type);
            if (application_type === 1) {
              await addEmailSendInBlue(process.env.MYMANUPLAY_LIST_ID, user_email, user_name);
            } else if (application_type === 2) {
              await addEmailSendInBlue(process.env.MYJUNO_LIST_ID, user_email, user_name);
            }
            if (application_type === 2 && is_translate_app_db === 1) {
              return callback(null, { status: HttpCodes.API_SUCCESS, msg: 'RegisteredSuccess', code: HttpCodes.OK, data: [] });
            }
            return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'EmailAlreadyExists', code: HttpCodes.ALREADY_EXIST, data: [] });
          } else {
            this.user_id = await models.User.create(user_data);
          }
        }
      } else {
        this.user_id = await models.User.create(user_data);
      }
      if (this.user_id && userCount === 0) {
        if (application_type === 1) {
          await addEmailSendInBlue(process.env.MYMANUPLAY_LIST_ID, user_email, user_name);
        } else if (application_type === 2) {
          await addEmailSendInBlue(process.env.MYJUNO_LIST_ID, user_email, user_name);
        } else {
          console.log("application_type is not equal to 2");
        }
        const base_url = (process.env.NODE_ENV === 'local') ? 'http://localhost:6012' : 'https://' + process.env.HOST;
        const UserData = await getUserData(this.user_id['user_id'], application_type);
        const reset_key = `<a href='${base_url}/activate-account?user_id=${user_id}&activation_key=${activation_key}'>Click Here</a>`;
        // Start: Registration Mail content Here
        const mailData = {
          user_name: user_name,
          activation_key: activation_key,
          baseUrl: base_url,
        };
        const templatePath = './views/emailTemplate.ejs';
        // Read the EJS template file
        const template = fs.readFileSync(templatePath, 'utf8')
        const subject = 'Please confirm your email address';
        try {
          await pushEmail(mailData, user_email, subject, template);
          // Email sent successfully
          return callback(null, { status: HttpCodes.API_SUCCESS, msg: 'VerifyAccount', code: HttpCodes.OK, data: [] });
        } catch (error) {
          // Error sending email
          return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'SomethingWentWrong', code: HttpCodes.OK, data: [] });
        }
        // End: Registration Mail content Here
      }
    } catch (error) {
      console.error(error);
      return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'RegisterFailed', code: HttpCodes['BAD_REQUEST'], data: [] });
    }
  }
  //activate your account
  async ActivateAccount(req, callback) {
    try {
      const activation_key = req.query.activation_key;
      if (activation_key) {
        const data = await models.User.findAll({
          where: { activation_key },
        });
        if (data.length > 0) {
          const db_activation_key = data[0].activation_key;
          if (activation_key === db_activation_key) {
            const new_activation_key = await generateRandomString(40);
            const varify_data = {
              activation_key: new_activation_key,
              is_verified: 1,
            };
            await models.User.update(varify_data, {
              where: { activation_key: db_activation_key },
            });
            return callback(null, { 'status': HttpCodes['API_SUCCESS'], 'msg': 'EmailVerifiedSuccess', code: HttpCodes.OK, data: [] });
          } else {
            const new_activation_key = await generateRandomString(40);
            const varify_data = {
              activation_key: new_activation_key,
            };
            await models.User.update(varify_data, {
              where: {activation_key: db_activation_key },
            });
            return callback(null, { 'status': HttpCodes['API_SUCCESS'], 'msg': 'AccountAlreadyVerified', code: HttpCodes.OK, data: [] });
          }
        } else {
          return callback(null, { 'status': HttpCodes['CONTENT_NOT_FOUND'], 'msg': 'ActivationKeyNotFound', code: HttpCodes['BAD_REQUEST'], data: [] });
        }
      } else {
        return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'SomethingWentWrong', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
    } catch (error) {
      console.error(error);
      return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'ActivationFailed ', code: HttpCodes['BAD_REQUEST'], data: [] });
    }
  }
  //resend activation 
  async ResendActivation(req, callback) {
    try {
      let user_email = req.body.email.toLowerCase();
      let application_type = parseInt(req.body.application_type);
      if (!user_email) {
        return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'InvalidEmail', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      if (application_type > 2 || application_type <= 0) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      let checkEmailExist = await models.User.findOne({
        where: Sequelize.where(Sequelize.fn('LOWER', Sequelize.col('user_email')), user_email)
      });
      if (checkEmailExist.is_deleted == 0) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'AccountNotExist', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      else {
        const base_url = (process.env.NODE_ENV === 'local') ? 'http://localhost:6012' : 'https://' + process.env.HOST;
        const data = await models.User.findAll({
          where: {
            user_email: Sequelize.where(Sequelize.fn('LOWER', Sequelize.col('user_email')), Sequelize.fn('LOWER', req.body.email))
          },
        });
        const username = data[0].user_name;
        const user_email = data[0].user_email;
        const activation_key = data[0].activation_key;
        // Start: Registration Mail content Here
        const mailData = {
          user_name: username,
          activation_key: activation_key,
          baseUrl: base_url
        };
        const templatePath = './views/emailTemplate.ejs';
        // Read the EJS template file
        const template = fs.readFileSync(templatePath, 'utf8')
        const subject = 'Please confirm your email address';
        const mail_success = await pushEmail(mailData, user_email, subject, template);
        // Assuming you have a function to send emails
        if (mail_success) {
          return callback(null, { status: HttpCodes.API_SUCCESS, msg: 'VerifyAccount', code: HttpCodes.OK, data: [] });
        } else {
          return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'somethingWentWrong', code: HttpCodes.OK, data: [] });
        }
      }
    }
    catch (error) {
      console.error('error while resending activation link', error);
      return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'SomeThingWentWrong', code: HttpCodes["BAD_REQUEST"], data: [] });
    }
  }
  //user login function for both mymanu play & myjuno users
  async UserLogin(req, callback) {
    try {
      let user_email = req.body.email.toLowerCase();
      let user_password = req.body.password;
      let device_type = req.body.device_type;
      let device_token = req.body.device_token;
      let application_type = parseInt(req.body.application_type);
      let application_version = req.body.application_version;
      if (application_type > 2 || application_type <= 0) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: HttpCodes['BAD_REQUEST'], data: null });
      }
      if (!user_email) {
        return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'InvalidEmail', code: HttpCodes['BAD_REQUEST'], data: null });
      }
      if (application_type === 2) {
        if (!application_version || application_version === '') {
          return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'NewVersion', code: HttpCodes['BAD_REQUEST'], data: [] });
        }
        if (device_type === 1 && application_version < 10) {
          return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'NewVersion', code: HttpCodes['BAD_REQUEST'], data: [] });
        }
        if (device_type === 2 && application_version < 32) {
          return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'NewVersion', code: HttpCodes['BAD_REQUEST'], data: [] });
        }
      }
      let user = await models.User.findOne({ where: Sequelize.where(Sequelize.fn('LOWER', Sequelize.col('user_email')), user_email) });
      if (!user) {
        return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'EmailNotRegister', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      let userId = user.user_id;
      if (user.is_deleted == 0) {
        console.log("No data found");
        return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'AccountNotExist', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      if (application_type > 2 || application_type <= 0) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      let isDeletedTranslate = user.is_deleted_translate;
      if (isDeletedTranslate == 1 && application_type == 2) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'AccountNotExist', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      if (user.is_verified == 0) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'VerifyAccount', code: HttpCodes['VERIFY'], data: [] });
      }
      let login_fetch_Access_token = user.login_access_token || user.login_access_token_translate;
      let login_time = {};
      if (!login_fetch_Access_token) {
        login_fetch_Access_token = await CreateJwt({ user_id: user.user_id });
      }
      if (application_type == 1) {
        login_time = {
          is_login: await getEpoch(),
          device_type: device_type,
          device_token: device_token,
          login_access_token: login_fetch_Access_token,
          is_mymanuplay_app: 1
        };
      } else if (application_type == 2) {
        login_time = {
          is_login_translate: await getEpoch(),
          device_type_translate: device_type,
          device_token_translate: device_token,
          login_access_token_translate: login_fetch_Access_token,
          is_translate_app: 1
        };
      }
      const result = await models.User.update(login_time, {
        where: { user_id: userId },
      });
      let UserData = [];
      if (application_type === 1) {
        UserData = await models.User.findAll({
          attributes: ['user_id', 'user_name', 'user_email', 'profile_picture', 'user_login_type', 'title', 'facebook_id', 'google_plus_id', 'twitter_id', 'is_verified', 'is_translate_app', 'push_notification', 'device_token', 'device_type', 'is_deleted', 'status', 'is_login_translate', 'login_access_token_translate', 'login_access_token', 'created_date', 'updated_date', 'language_code', 'region', 'subscription_plan', 'subscribed_on', 'subscription_plan_device_type', 'voice_preference', 'mymanuplay_user_type'],
          where: {
            user_email: Sequelize.where(Sequelize.fn('LOWER', Sequelize.col('user_email')), Sequelize.fn('LOWER', user_email))
          },
        });
        let musicProviderData = [];
        UserData = UserData.map(user => ({
          ...user.dataValues,
          music_provider: musicProviderData,
        }));
      }
      if (application_type === 2) {
        UserData = await models.User.findAll({
          attributes: ['user_id', 'user_name', 'user_email', 'profile_picture', 'user_login_type', 'title', 'facebook_id', 'google_plus_id', 'twitter_id', 'is_verified', 'is_mymanuplay_app', 'push_notification', 'device_token_translate', 'device_type_translate', 'is_deleted', 'status', 'is_login', 'login_access_token', 'login_access_token_translate', 'is_post_activity', 'created_date', 'updated_date', 'language_code', 'region', 'is_deleted_translate', 'subscribed_on', 'subscription_plan', 'voice_preference'],
          where: {
            user_email: Sequelize.where(Sequelize.fn('LOWER', Sequelize.col('user_email')), Sequelize.fn('LOWER', user_email))
          },
        });
        UserData = UserData.map(user => ({
          ...user.dataValues,
          xmpp_password: 'mymanuplay@translate',
        }));
      }
      const serialNumber = await models.DeviceRegister.findAll({
        where: {
          user_id: userId
        }
      });
      let serial_number = '';
      let translate_device_type = '';
      if (serialNumber.length > 0) {
        serial_number = serialNumber[0].serial_number;
        translate_device_type = serialNumber[0].device_type;
      }
      UserData[0].serial_number = serial_number;
      UserData[0].translate_device_type = translate_device_type;
      UserData[0].region = UserData[0].region || '';
      UserData[0].subscription_plan = UserData[0].subscription_plan || '';
      UserData[0].subscribed_on = UserData[0].subscribed_on == '' ? null : parseInt(UserData[0].subscribed_on);
      const passwordMatch = await ComparePassword(user_password, user.user_password);

      console.log(">>>>>>>>>>passwordMatch",user_password,user.user_password)

      if (passwordMatch) {
        console.log(">matched")

        return callback(null, { 'status': HttpCodes['API_SUCCESS'], 'msg': 'Login', code: HttpCodes['OK'], data: UserData });
      } else {
        console.log(">not matched")

        return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'LoginInvalidValue', code: HttpCodes['UNAUTHORIZED'], data: [] });
      }
    } catch (error) {
      console.log(error.message, "error in Login>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>");
      return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'LoginFailed', code: HttpCodes['BAD_REQUEST'], data: [] });
    }
  }
  //forgot password function for both mymanu play & myjuno users
  async ForgotPassword(req, callback) {
    try {
      let user_email = req.body.email.toLowerCase();
      let application_type = req.body.application_type;
      if (!user_email) {
        return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'InvalidEmail', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      let checkEmailExist = await models.User.findOne({
        where: Sequelize.where(Sequelize.fn('LOWER', Sequelize.col('user_email')), user_email),
      });
      if (!checkEmailExist) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'AccountNotExist', code: HttpCodes['BAD_REQUEST'], data: [] });
      } else {
        if (checkEmailExist.is_deleted_translate == 1 && application_type == 2) {
          return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'AccountDeleted', code: HttpCodes['BAD_REQUEST'], data: [] });
        }
        if (checkEmailExist.is_deleted == 0 && application_type == 1) {
          return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'AccountDeleted', code: HttpCodes['BAD_REQUEST'], data: [] });
        }
        let user_id = checkEmailExist.user_id;
        const newOTP = Math.floor(100000 + Math.random() * 900000);
        await models.User.update({ otp: newOTP }, { where: { user_id: user_id } });
        const base_url = (process.env.NODE_ENV === 'local') ? 'http://localhost:6012' : 'https://' + process.env.HOST;
        // Start: Registration Mail content Here
        const mailData = {
          user_name: checkEmailExist.user_name,
          otp: newOTP,
          baseUrl: base_url,
        };
        const templatePath = './views/forgotPassword.ejs';
        // Read the EJS template file
        const template = fs.readFileSync(templatePath, 'utf8')
        const subject = 'OTP Verification for Password Reset';
        try {
          await pushEmail(mailData, user_email, subject, template);
          // Email sent successfully
          return callback(null, { status: HttpCodes.API_SUCCESS, msg: 'OTPSent', code: HttpCodes.OK, data: [] });
        } catch (error) {
          // Error sending email
          return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'somethingWentWrong', code: HttpCodes.OK, data: [] });
        }
      }
    } catch (error) {
      console.error('error while forgot password', error);
      return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'SomethingWentWrong', code: HttpCodes.OK, data: [] });
    }
  }
  //Reset password function for both mymanu play & myjuno users
  async ResetPassword(req, callback) {
    try {
      let user_email = req.body.email.toLowerCase();
      let user_password = req.body.password;
      let otp = parseInt(req.body.otp);
      let checkEmailExist = await models.User.findOne({
        where: Sequelize.where(Sequelize.fn('LOWER', Sequelize.col('user_email')), user_email)
      });
      if (!checkEmailExist) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'AccountNotExist', code: HttpCodes['BAD_REQUEST'], data: [] });
      } else {
        if (checkEmailExist.is_deleted_translate == 1) {
          return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'AccountDeleted', code: HttpCodes['BAD_REQUEST'], data: [] });
        }
        let user_id = checkEmailExist.user_id;
        const salt = await bcrypt.genSalt(10);
        const hashedPassword = await bcrypt.hash(user_password, salt);
        if (otp !== checkEmailExist.otp) {
          return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'InvalidOTP', code: HttpCodes['BAD_REQUEST'], data: [] });
        }
        try {
          await models.User.update({ user_password: hashedPassword }, { where: { user_id: user_id } });
          return callback(null, { status: HttpCodes.API_SUCCESS, msg: 'PasswordChanged', code: HttpCodes.OK, data: [] });
        } catch (error) {
          console.error('Error updating password:', error);
          return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'FailedUpdatePassword', code: HttpCodes['BAD_REQUEST'], data: [] });
        }
      }
    } catch (error) {
      return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'FailedUpdatePassword', code: HttpCodes['INTERNAL_SERVER_ERROR'], data: [] });
    }
  }
  //Logout function for both mymanu play & myjuno users
  async Logout(req, callback) {
    try {
      let application_type = parseInt(req.body.application_type);
      let user_id = req.body.user_id;
      if (application_type > 2 || application_type <= 0) {
        return callback(null, {
          status: HttpCodes['API_FAILURE'], msg: 'InvalidApplicationType', code: HttpCodes['BAD_REQUEST'], data: []
        });
      }
      // Check if the user_id exists
      const user = await models.User.findOne({
        where: {
          user_id: user_id,
        },
      });
      if (!user) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'UserIdNotExist', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      // Check if the user is already logged out
      const isLoginColumn = application_type === 1 ? 'is_login' : 'is_login_translate';
      const isLoggedOut = user[isLoginColumn] === null;
      if (isLoggedOut) {
        return callback(null, { status: HttpCodes['API_FAILURE'], msg: 'AlreadyLoggedOut', code: HttpCodes['BAD_REQUEST'], data: [] });
      }
      const updateData = {};
      updateData[isLoginColumn] = null;
      updateData[isLoginColumn === 'is_login' ? 'login_access_token' : 'login_access_token_translate'] = null;
      updateData[isLoginColumn === 'is_login' ? 'device_token' : 'device_token_translate'] = null; // Update device_token and token_translate fields
      // Update user's is_login and login_access_token
      await models.User.update(updateData, { where: { user_id: user_id }, });
      return callback(null, {
        status: HttpCodes.API_SUCCESS, msg: 'Logout', code: HttpCodes.OK, data: [],
      });
    } catch (error) {
      console.error('Error while Logout:', error);
      return callback(null, { 'status': HttpCodes['API_FAILURE'], 'msg': 'SomeThingWentWrong', code: HttpCodes["BAD_REQUEST"], data: [] });
    }
  }
}