const socketManager = require('./helpers/socket-manager');

const rootSocket = (io) => {
	io.use(async (socket, next) => {
		const userId = socket?.handshake?.query?.userId;
		console.log("userId",socket?.handshake);
		if (!userId) {
			return next(new Error('Invalid userId'));
		}
		socket.request.userId = userId;
		next();
	});

	io.on('connection', (socket) => {
		const userId = socket.request.userId;
		console.log('User connected:', socket.id);
		console.log('User userId:', userId);
		socketManager.userAdd(socket, userId);
		// Listen for the 'join-room' event from the client to join a room
		socket.on('join-room', (data) => {
			const groupId = data.groupId;
			// Join the socket to the group room
			socket.join(groupId);
			// Get the number of users connected to the room
			const room = io.sockets.adapter.rooms.get(groupId);
			const numUsersInRoom = room ? room.size : 0;
			console.log(`Number of users in room ${groupId}: ${numUsersInRoom}`);
			io.to(groupId).emit('num-users-in-room', {
				groupId: groupId,
				numUsersInRoom: numUsersInRoom
			});
		});

		socket.on('disconnect', () => {
			console.log("disconnect");
			socketManager.userRemove(socket, userId);
		});

		socket.on('connect_error', (error) => {
			console.error('Connection error:', error);
		});

		socket.on('error', (err) => {
			console.error('Socket Error', err);
			if (err && err.message === 'unauthorized event') {
				socket.disconnect();
			}
		});

		socket.on('send-message', async (data) => {
			try {
				console.log('send-message:', data);
				// If 'data' is a string, attempt to parse it as JSON
				if (typeof data === 'string') {
					data = JSON.parse(data);
				}
				const messages = data.message;
				if (!Array.isArray(messages)) {
					console.error('Invalid message format:', messages);
					return;
				}
				// Broadcast the message to the specified group
				for (const translation of messages) {
					// console.log("translation", translation);
					// console.log("socketIds>>>>>",translation.user_id);
					let socketIds = socketManager.userSocketIds(translation.user_id);
					console.log("socketIds>>>>>", socketIds);
					if (socketIds.length) {
						socketIds.forEach(socketId => socketManager.emit(io, socketId, 'reciever-message-result-'+translation.group_id, translation));
					}
				}
			} catch (error) {
				console.error('An error occurred:', error);
			}
		});

		socket.on('send-friend-message', async (data) => {
			try {
				console.log('send-friend-message:', data);

				// If 'data' is a string, attempt to parse it as JSON
				if (typeof data === 'string') {
					data = JSON.parse(data);
				}

				let socketIds = socketManager.userSocketIds(data.receiver_id);

				console.log("socketIds>>>>>frinds ", socketIds);
				if (socketIds.length) {
					console.log("socketIds> ");

					socketIds.forEach(socketId => socketManager.emit(io, socketId, 'get-friend-message-result-'+data.friend_group_id, data));
				}
				let socketIdsUser = socketManager.userSocketIds(data.user_id);

				console.log("socketIds>>>>>frinds ", socketIdsUser);
				if (socketIdsUser.length) {
					console.log("socketIds> ", socketIdsUser);

					socketIdsUser.forEach(socketId => socketManager.emit(io, socketId, 'get-friend-message-result-'+data.friend_group_id, data));
				}

			} catch (error) {
				console.error('An error occurred:', error);
			}
		});

		socket.on('send-socket-typing', async (data) => {
			try {
				console.log('send-socket-typing:', data);

				// If 'data' is a string, attempt to parse it as JSON
				if (typeof data === 'string') {
					data = JSON.parse(data);
				}
				let groupMemberIds = [];
				if (typeof data.groupMemberIds === 'string') {
					groupMemberIds = data.groupMemberIds.split(',');
				}else{
					console.error('Invalid groupMemberIds format (pass comma seprated string):', data.groupMemberIds);
					return;
				}

				console.warn('groupMemberIds',groupMemberIds);


				// Broadcast the message to the specified group
				for (const memberIds of groupMemberIds) {
					console.warn('memberIds',memberIds);
					
					let socketIds = socketManager.userSocketIds(memberIds);
					console.log("socketIds>>>>>", socketIds);
					if (socketIds.length) {
						socketIds.forEach(socketId => socketManager.emit(io, socketId, 'get-typing-result-'+data.groupId, data));
					}
				}


			} catch (error) {
				console.error('An error occurred:', error);
			}
		});

		// setInterval(() => {
		// 	console.log('socketUsers', socketManager.users());
		// }, 10000);

		// Broadcasting connected socket IDs
		const connectedSocketIds = socketManager.userSocketIds();
		io.emit('connectedSocketIds', connectedSocketIds);
	});
};

module.exports = rootSocket;